"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var AnalyticsService = /** @class */ (function () {
    function AnalyticsService(messageFactory, uploader) {
        this.messageFactory = messageFactory;
        this.uploader = uploader;
    }
    AnalyticsService.prototype.sendHeartBeat = function () {
        console.log('HeartBeat message');
        var hb = this.messageFactory.buildHeartBeatMessage();
        return this.uploader.sendScreenView(hb);
    };
    AnalyticsService.prototype.sendDeviceSignature = function (value) {
        console.log('Device Signature');
        var ds = this.messageFactory.buildSignature(value, 'Device');
        return this.uploader.sendEvent(ds);
    };
    AnalyticsService.prototype.sendLocalSignature = function (value) {
        console.log('Local Signature');
        var ds = this.messageFactory.buildSignature(value, 'Local');
        return this.uploader.sendEvent(ds);
    };
    AnalyticsService.prototype.sendRemoteSignature = function (value) {
        console.log('Remote Signature');
        var ds = this.messageFactory.buildSignature(value, 'Remote');
        return this.uploader.sendEvent(ds);
    };
    AnalyticsService.prototype.sendOneShotSignature = function (value) {
        console.log('ONESHOT Signature');
        var ds = this.messageFactory.buildSignature(value, 'ONESHOT');
        return this.uploader.sendEvent(ds);
    };
    AnalyticsService.prototype.sendCadesSignature = function (okCount) {
        console.log("SignatureFormat Cades " + okCount);
        var csf = this.messageFactory.buildSignatureFormat(okCount, 'Cades');
        return this.uploader.sendEvent(csf);
    };
    AnalyticsService.prototype.sendPadesSignature = function (okCount) {
        console.log("SignatureFormat Pades " + okCount);
        var psf = this.messageFactory.buildSignatureFormat(okCount, 'Pades');
        return this.uploader.sendEvent(psf);
    };
    AnalyticsService.prototype.sendXadesSignature = function (okCount) {
        console.log("SignatureFormat Xades " + okCount);
        var xsf = this.messageFactory.buildSignatureFormat(okCount, 'Xades');
        return this.uploader.sendEvent(xsf);
    };
    AnalyticsService.prototype.sendCustomDeviceSignature = function (okCount, atr) {
        console.log("Custom Device Signature " + okCount);
        var cds = this.messageFactory.buildCustomDeviceSignature(okCount, atr);
        return this.uploader.sendEvent(cds);
    };
    AnalyticsService.prototype.sendCertificateCommonName = function (issuerCN, okSignatures) {
        console.log("Certificate common name " + issuerCN + ", signatures " + okSignatures);
        var ccn = this.messageFactory.buildCertificateCommonName(issuerCN, okSignatures);
        return this.uploader.sendEvent(ccn);
    };
    AnalyticsService.prototype.sendCertificateData = function (stored) {
        var messages = this.messageFactory.buildCertificateAnalyticsMessages(stored);
        var promises = [];
        for (var i = 0; i < messages.length; i++) {
            promises.push(this.uploader.sendEvent(messages[i]));
        }
        return Promise.all(promises);
    };
    AnalyticsService.prototype.sendTimestamp = function (okCount) {
        console.log("Timestamp " + okCount);
        var t = this.messageFactory.buildTimestamp(okCount);
        return this.uploader.sendEvent(t);
    };
    AnalyticsService.prototype.sendVerification = function (count) {
        console.log("Verification " + count);
        var t = this.messageFactory.buildVerification(count);
        return this.uploader.sendEvent(t);
    };
    AnalyticsService.prototype.sendGoSignWeb = function (type) {
        console.log("GoSignWeb " + type);
        var t = this.messageFactory.buildGoSignWeb(type);
        return this.uploader.sendEvent(t);
    };
    AnalyticsService.prototype.setLogged = function (logged) {
        console.log("Logged " + logged);
        return this.uploader.setLogged(logged);
    };
    AnalyticsService.prototype.setIsPRO = function (isPRO) {
        console.log("PRO " + isPRO);
        return this.uploader.setIsPRO(isPRO);
    };
    AnalyticsService.prototype.setCustomization = function (customization) {
        console.log("customization " + customization);
        return this.uploader.setCustomization(customization);
    };
    AnalyticsService.prototype.sendGeneric = function (category, action, label, value) {
        console.log("Generic " + category + " " + action + " " + label + " " + value);
        var t = this.messageFactory.buildGeneric(category, action, label, value);
        return this.uploader.sendEvent(t);
    };
    return AnalyticsService;
}());
exports.AnalyticsService = AnalyticsService;
//# sourceMappingURL=AnalyticsService.js.map