"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var MessageFactory = /** @class */ (function () {
    function MessageFactory(uaBuilder) {
        this.uaBuilder = uaBuilder;
    }
    MessageFactory.prototype.buildHeartBeatMessage = function () {
        return {
            type: 'screenview',
            an: this.uaBuilder.appName,
            av: this.uaBuilder.appVersion,
            ua: this.uaBuilder.build(),
            fl: this.uaBuilder.installationType,
            aiid: this.uaBuilder.architectureString,
            cd: 'MainWindow',
        };
    };
    MessageFactory.prototype.buildSignature = function (count, sourceType) {
        return {
            type: 'event',
            ec: 'devices',
            ea: 'used',
            el: sourceType,
            ev: count,
        };
    };
    MessageFactory.prototype.buildCustomDeviceSignature = function (count, atr) {
        return {
            type: 'event',
            ec: 'CustomDeviceSignatures',
            ea: atr,
            el: 'CustomDeviceSignatures',
            ev: count,
        };
    };
    MessageFactory.prototype.buildCertificateCommonName = function (issuerCN, okSignatures) {
        return {
            type: 'event',
            ec: 'SignatureCertificate',
            ea: issuerCN,
            el: 'SignatureCertificate',
            ev: okSignatures,
        };
    };
    MessageFactory.prototype.buildSignatureFormat = function (count, signatureFormat) {
        return {
            type: 'event',
            ec: 'SignatureFormat',
            ea: 'completed',
            el: signatureFormat,
            ev: count,
        };
    };
    MessageFactory.prototype.buildTimestamp = function (count) {
        return {
            type: 'event',
            ec: 'mark',
            ea: 'completed',
            el: 'Marks',
            ev: count,
        };
    };
    MessageFactory.prototype.buildVerification = function (count) {
        return {
            type: 'event',
            ec: 'verification',
            ea: 'completed',
            el: 'Verifications',
            ev: count,
        };
    };
    MessageFactory.prototype.buildGoSignWeb = function (type) {
        return {
            type: 'event',
            ec: 'gosign',
            ea: 'completed',
            el: type,
            ev: 1,
        };
    };
    MessageFactory.prototype.buildGeneric = function (category, action, label, value) {
        return {
            type: 'event',
            ec: category,
            ea: action,
            el: label,
            ev: value,
        };
    };
    MessageFactory.prototype.buildCertificateAnalyticsMessages = function (stored) {
        var messages = [];
        var current = stored;
        if (current.isDigitalSignature) {
            messages.push(this.buildUserCertificates(current.vendor, 'DigitalSignature'));
        }
        if (current.isRao) {
            messages.push(this.buildUserCertificates(current.vendor, 'RAO'));
        }
        if (current.isCns) {
            messages.push(this.buildUserCertificates(current.vendor, 'CNS'));
        }
        if (current.isAuth) {
            messages.push(this.buildUserCertificates(current.vendor, 'Auth'));
        }
        if (current.isRole) {
            messages.push(this.buildUserCertificates(current.vendor, 'Auth'));
        }
        messages.push(this.buildCertificateExpiration(current.cn, current.expDate));
        return messages;
    };
    MessageFactory.prototype.buildUserCertificates = function (vendor, type) {
        return {
            type: 'event',
            ec: 'UserCertificates',
            ea: vendor,
            el: 'SignatureCertificate',
            ev: type,
        };
    };
    MessageFactory.prototype.buildCertificateExpiration = function (cn, expDate) {
        return {
            type: 'event',
            ec: 'Certificate Expiration Date',
            ea: cn,
            el: expDate,
            ev: 1,
        };
    };
    return MessageFactory;
}());
exports.MessageFactory = MessageFactory;
//# sourceMappingURL=MessageFactory.js.map