"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var env_1 = require("../../environments/env");
var lodash_1 = require("lodash");
var os = require('os');
var UaBuilder = /** @class */ (function () {
    function UaBuilder() {
    }
    Object.defineProperty(UaBuilder.prototype, "osName", {
        get: function () {
            var osName = 'unknown';
            switch (os.platform()) {
                case 'darwin':
                    osName = 'Macintosh; Intel Mac OS X';
                    break;
                case 'linux':
                    osName = 'Linux';
                    break;
                case 'win32':
                    osName = 'Windows NT';
                    break;
            }
            return osName;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UaBuilder.prototype, "appVersion", {
        get: function () {
            return env_1.env.npm_package_version;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UaBuilder.prototype, "osVersion", {
        get: function () {
            return os.version();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UaBuilder.prototype, "osRelease", {
        get: function () {
            var _a, _b;
            var s = (_a = os.release()) !== null && _a !== void 0 ? _a : '';
            var matchArray = s.match(/^\d{2}.\d/);
            return (_b = lodash_1.get(matchArray, 0)) !== null && _b !== void 0 ? _b : '';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UaBuilder.prototype, "appName", {
        get: function () {
            return 'GoSign Desktop';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UaBuilder.prototype, "architectureString", {
        get: function () {
            var bit = 'unknown';
            switch (os.arch()) {
                case 'ia32':
                    bit = '32';
                    break;
                case 'x32':
                    bit = '32';
                    break;
                case 'x64':
                    bit = '64';
                    break;
            }
            return "ARCHITETTURA OS LOCALE: " + bit + " bit";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UaBuilder.prototype, "osFullString", {
        get: function () {
            if (lodash_1.isEmpty(this.osRelease)) {
                return this.osName;
            }
            return this.osName + " " + this.osRelease;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UaBuilder.prototype, "installationType", {
        /**
         * tipo installazione nel parametro "versione flash"
         */
        get: function () {
            switch (os.platform()) {
                case 'darwin':
                    return 'install.mac.peruser';
                case 'linux':
                    return 'install.linux.peruser';
                case 'win32':
                    return 'install.win.peruser';
                default:
                    return 'install.win.peruser';
            }
        },
        enumerable: true,
        configurable: true
    });
    UaBuilder.prototype.build = function () {
        return this.appName + "/" + this.appVersion + " (" + this.osFullString + ")";
        // return 'Dike GoSign/7.3.5 (Macintosh; Intel Mac OS X 10_12)';
        // app.name
        // os.release ->
    };
    return UaBuilder;
}());
exports.UaBuilder = UaBuilder;
//# sourceMappingURL=UaBuilder.js.map