"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var AnalyticsService_1 = require("./AnalyticsService");
var MessageFactory_1 = require("./MessageFactory");
var UaBuilder_1 = require("./UaBuilder");
var Uploader_1 = require("./Uploader");
var lodash_1 = require("lodash");
var date_fns_1 = require("date-fns");
var ScreenViewMessageEntity = /** @class */ (function () {
    function ScreenViewMessageEntity() {
    }
    return ScreenViewMessageEntity;
}());
exports.ScreenViewMessageEntity = ScreenViewMessageEntity;
function produceAnalyticsService(optionDatabase) {
    return new AnalyticsService_1.AnalyticsService(new MessageFactory_1.MessageFactory(new UaBuilder_1.UaBuilder()), new Uploader_1.Uploader(optionDatabase));
}
exports.produceAnalyticsService = produceAnalyticsService;
function mapVendor(c) {
    var value = lodash_1.get(c, 'x509.issuerDN', '');
    var retVal = 'OTHER';
    if (new RegExp('Infocert').test(value)) {
        retVal = 'INFOCERT';
    }
    else if (new RegExp('Aruba').test(value)) {
        retVal = 'ARUBA';
    }
    else if (new RegExp('Namirial').test(value)) {
        retVal = 'NAMIRIAL';
    }
    else if (new RegExp('Postecom|Postecert').test(value)) {
        retVal = 'POSTECOM';
    }
    else if (new RegExp('IT Trust Technologies CA|Telecom').test(value)) {
        retVal = 'ITTECHNOLOGIES';
    }
    return retVal;
}
function isRao(c) {
    var subjectDN = lodash_1.get(c, 'x509.subjectDN', '');
    return new RegExp('description=RAO').test(subjectDN);
}
function isCns(c) {
    return new RegExp('CNS').test(lodash_1.get(c, 'sc_data.CKAID', ''));
}
function mapExpDate(notAfter) {
    var result = lodash_1.attempt(function (arg) {
        var val = date_fns_1.parseISO(arg);
        return date_fns_1.format(val, 'yyyy/MM');
    }, notAfter);
    if (lodash_1.isError(result)) {
        return 'invalid expdate';
    }
    return result;
}
var keyUsages = {
    KU_DIGITAL_SIGNATURE: 0x80,
    KU_NON_REPUDIATION: 0x40,
    KU_KEY_ENCIPHERMENT: 0x20,
    KU_DATA_ENCIPHERMENT: 0x10,
    KU_KEY_AGREEMENT: 0x08,
    KU_KEY_CERT_SIGN: 0x04,
    KU_CRL_SIGN: 0x02,
};
function mapDigitalSignature(c) {
    var keyUsage = lodash_1.get(c, 'x509.keyUsage', '0x00');
    var parsed = parseInt(keyUsage, 16);
    return (parsed & keyUsages.KU_DIGITAL_SIGNATURE) === keyUsages.KU_DIGITAL_SIGNATURE;
}
var CertificateAnalyticsEntity = /** @class */ (function () {
    function CertificateAnalyticsEntity() {
    }
    CertificateAnalyticsEntity.fromCertificate = function (c) {
        return {
            ski: c.x509.ski,
            vendor: mapVendor(c),
            isDigitalSignature: mapDigitalSignature(c),
            isRole: !lodash_1.isEmpty(lodash_1.get(c, 'x509.title')),
            isRao: isRao(c),
            isCns: isCns(c),
            isAuth: !isCns(c),
            cn: lodash_1.get(c, 'x509.issuerCN', 'unknown'),
            expDate: mapExpDate(lodash_1.get(c, 'x509.validNotAfter')),
        };
    };
    return CertificateAnalyticsEntity;
}());
exports.CertificateAnalyticsEntity = CertificateAnalyticsEntity;
//# sourceMappingURL=index.js.map