"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var flows_1 = require("@ice/dike-core-js/lib/types/flows");
var operators_1 = require("rxjs/operators");
var rxjs_1 = require("rxjs");
var model_1 = require("../model");
var logger_1 = require("../logger");
var GenericFsm = /** @class */ (function () {
    function GenericFsm(flowType, coreArg) {
        this.logger = console;
        this.flowType = flowType;
        this.core = coreArg;
    }
    GenericFsm.of = function (flowType, coreArg) {
        return new GenericFsm(flowType, coreArg);
    };
    GenericFsm.checkErrors = function (value) {
        return value.state_data && value.state_data.result < 0;
    };
    GenericFsm.prototype.setLogger = function (logger) {
        this.logger = logger;
        return this;
    };
    GenericFsm.prototype.init = function () {
        var _this = this;
        this.logger.info("Initializing generic fsm for " + this.flowType);
        return this.core.flowStart(this.flowType).then(function (flow) {
            _this.flow = flow;
            return flow;
        });
    };
    GenericFsm.prototype.send = function (flowEvent, json) {
        this.logger.info("Sending  '" + flows_1.FlowEvent[flowEvent] + "', to fsm of type " + flows_1.FlowType[this.flowType] + ": %s", logger_1.safeJsonStringify(json));
        return this.flow.send(flowEvent, json);
    };
    GenericFsm.prototype.nextState = function () {
        return this.flow.FlowData$.pipe(operators_1.mergeMap(function (value) {
            return GenericFsm.checkErrors(value)
                ? rxjs_1.throwError(model_1.DikeError.of(value.state_data.result, value.state_data.message))
                : rxjs_1.of(value);
        }), operators_1.first()).toPromise();
    };
    return GenericFsm;
}());
exports.GenericFsm = GenericFsm;
var FsmRegistry = /** @class */ (function () {
    function FsmRegistry() {
        this.genericsFSMs = new Map();
    }
    FsmRegistry.getInstance = function () {
        return this.instance;
    };
    FsmRegistry.prototype.set = function (flowType, instance) {
        this.genericsFSMs.set(flows_1.FlowType[flowType], instance);
    };
    FsmRegistry.prototype.get = function (flowType) {
        return this.genericsFSMs.get(flows_1.FlowType[flowType]);
    };
    FsmRegistry.instance = new FsmRegistry();
    return FsmRegistry;
}());
exports.FsmRegistry = FsmRegistry;
//# sourceMappingURL=genericFsm.js.map