"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var dikeClients_1 = require("../dikeClients");
var lodash_1 = require("lodash");
var request_1 = require("../shared/request");
var electron_1 = require("electron");
var uuid_1 = require("uuid");
var model_1 = require("../model");
var DikeErrors_1 = require("../shared/DikeErrors");
var Util = require("util");
var fs = require('fs');
var path = require('path');
var GetCertificateList = /** @class */ (function () {
    function GetCertificateList() {
    }
    GetCertificateList.prototype.handleRequest = function (body) {
        console.log('Requesting certificate history list');
        return dikeClients_1.DikeClients.getInstance()
            .chronoGetCertificates()
            .then(function (value) { return ({
            certificatechronology: lodash_1.map(value.certificatechronology, function (value1) {
                return request_1.CoreCertificateData.fromCertificateData(value1);
            }),
        }); });
    };
    return GetCertificateList;
}());
exports.GetCertificateList = GetCertificateList;
var OsOpenCertificate = /** @class */ (function () {
    function OsOpenCertificate() {
    }
    OsOpenCertificate.prototype.handleRequest = function (body) {
        var _this = this;
        console.log('Saving and opening certificate PEM');
        return dikeClients_1.DikeClients.getInstance()
            .chronoGetCertificates()
            .then(function (value) {
            var found = lodash_1.find(value.certificatechronology, function (cert) { return cert.certid === body.certid; });
            if (lodash_1.isNil(found)) {
                console.error("Cannot find certificate with certid " + body.certid);
                return Promise.reject(model_1.DikeError.of(DikeErrors_1.DikeErrors.CANNOT_FIND_CERTIFICATE, "Cannot find certificate with id " + body.certid));
            }
            var temp = electron_1.app.getPath('temp');
            if (lodash_1.isNil(temp)) {
                return Promise.reject(model_1.DikeError.of(DikeErrors_1.DikeErrors.CANNOT_RETRIEVE_TEMP_FOLDER, 'Cannot retrieve temp folder'));
            }
            var filename = uuid_1.v4() + ".cer";
            var tmpPath = path.join(temp, filename);
            console.log("Storing certificate PEM file in " + tmpPath);
            return _this.storeFile(tmpPath, found.pem).then(function () { return ({
                opened: electron_1.shell.openPath(tmpPath),
            }); });
        });
    };
    OsOpenCertificate.prototype.storeFile = function (path, pem) {
        var writefile = Util.promisify(fs.writeFile);
        return writefile(path, pem);
    };
    return OsOpenCertificate;
}());
exports.OsOpenCertificate = OsOpenCertificate;
var RemoveCertificate = /** @class */ (function () {
    function RemoveCertificate() {
    }
    RemoveCertificate.prototype.handleRequest = function (body) {
        console.log('Removing certificate from history list');
        return dikeClients_1.DikeClients.getInstance().chronoRemoveCertificate(body.certid);
    };
    return RemoveCertificate;
}());
exports.RemoveCertificate = RemoveCertificate;
//# sourceMappingURL=CertificateHistoryHandlers.js.map