"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var dikeClients_1 = require("../dikeClients");
var lodash_1 = require("lodash");
var Analytics_1 = require("../Analytics");
var logger_1 = require("../logger");
var model_1 = require("../model");
var DikeErrors_1 = require("../shared/DikeErrors");
var electron_1 = require("electron");
var uuid_1 = require("uuid");
var Util = require("util");
var https = require("https");
var node_fetch_1 = require("node-fetch");
var fs = require('fs');
var path = require('path');
var logger = logger_1.provideLogger('DeviceHandlers');
var DeviceListChannel = /** @class */ (function () {
    function DeviceListChannel(certificateDatabase, analyticsEventHandler) {
        this.certificateDatabase = certificateDatabase;
        this.analyticsEventHandler = analyticsEventHandler;
    }
    DeviceListChannel.prototype.handleRequest = function (body) {
        var _this = this;
        logger.info("Listing devices: %s", JSON.stringify(body));
        var instance = dikeClients_1.DikeClients.getInstance();
        return instance.getDevices(body.forceRescan).then(function (value) {
            var certificates = lodash_1.flatMap(value.readers, function (reader) { return reader.certificates; });
            var certs = lodash_1.map(certificates, function (c) { return Analytics_1.CertificateAnalyticsEntity.fromCertificate(c); });
            _this.sendStatistics(certs);
            return value;
        });
    };
    DeviceListChannel.prototype.sendStatistics = function (certs) {
        var _this = this;
        return Promise.allSettled(certs.map(function (cert) {
            return _this.certificateDatabase.save(cert).then(function (value) {
                if (value.upsert) {
                    return _this.analyticsEventHandler.sendCertificateData(value.data);
                }
                else {
                    logger.info("Certificate with ski " + cert.ski + " already sent");
                    return Promise.resolve([]);
                }
            });
        }));
    };
    return DeviceListChannel;
}());
exports.DeviceListChannel = DeviceListChannel;
var DeviceTestPinChannel = /** @class */ (function () {
    function DeviceTestPinChannel() {
    }
    DeviceTestPinChannel.prototype.handleRequest = function (body) {
        logger.info("TestPin %s", logger_1.safeJsonStringify(body));
        var instance = dikeClients_1.DikeClients.getInstance();
        return instance.deviceTestPin(body.deviceIndex, body.pin);
    };
    return DeviceTestPinChannel;
}());
exports.DeviceTestPinChannel = DeviceTestPinChannel;
var DeviceChangePinChannel = /** @class */ (function () {
    function DeviceChangePinChannel() {
    }
    DeviceChangePinChannel.prototype.handleRequest = function (body) {
        logger.info("ChangePin %s", logger_1.safeJsonStringify(body));
        var instance = dikeClients_1.DikeClients.getInstance();
        return instance.deviceChangePin(body.deviceIndex, body.oldPin, body.newPin);
    };
    return DeviceChangePinChannel;
}());
exports.DeviceChangePinChannel = DeviceChangePinChannel;
var DeviceUnlockPinChannel = /** @class */ (function () {
    function DeviceUnlockPinChannel() {
    }
    DeviceUnlockPinChannel.prototype.handleRequest = function (body) {
        logger.info("DeviceUnlockPin %s", logger_1.safeJsonStringify(body));
        var instance = dikeClients_1.DikeClients.getInstance();
        return instance.deviceUnlockPin(body.deviceIndex, body.puk, body.newPin);
    };
    return DeviceUnlockPinChannel;
}());
exports.DeviceUnlockPinChannel = DeviceUnlockPinChannel;
var DeviceUnlockCEPinChannel = /** @class */ (function () {
    function DeviceUnlockCEPinChannel() {
    }
    DeviceUnlockCEPinChannel.prototype.handleRequest = function (body) {
        logger.info("DeviceUnlockCEPin %s", logger_1.safeJsonStringify(body));
        var instance = dikeClients_1.DikeClients.getInstance();
        return instance.deviceUnlockCEPin(body.deviceIndex, body.puk, body.newPin);
    };
    return DeviceUnlockCEPinChannel;
}());
exports.DeviceUnlockCEPinChannel = DeviceUnlockCEPinChannel;
var DeviceActivateChannel = /** @class */ (function () {
    function DeviceActivateChannel() {
    }
    DeviceActivateChannel.prototype.handleRequest = function (body) {
        logger.info("DeviceActivate %s", logger_1.safeJsonStringify(body));
        var instance = dikeClients_1.DikeClients.getInstance();
        return instance.deviceActivate(body.deviceIndex, body.puk, body.pin);
    };
    return DeviceActivateChannel;
}());
exports.DeviceActivateChannel = DeviceActivateChannel;
var DeviceActivateCEChannel = /** @class */ (function () {
    function DeviceActivateCEChannel() {
    }
    DeviceActivateCEChannel.prototype.handleRequest = function (body) {
        logger.info("DeviceActivateCE %s", logger_1.safeJsonStringify(body));
        var instance = dikeClients_1.DikeClients.getInstance();
        return instance.deviceActivateCE(body.deviceIndex, body.puk, body.pin, body.uuid);
    };
    return DeviceActivateCEChannel;
}());
exports.DeviceActivateCEChannel = DeviceActivateCEChannel;
var SendCEOTP = /** @class */ (function () {
    function SendCEOTP() {
    }
    SendCEOTP.prototype.handleRequest = function (_a) {
        var _this = this;
        var baseUrl = _a.baseUrl, tokenSn = _a.tokenSn, tokenUuid = _a.tokenUuid;
        console.log("🚀 ~ handleRequest ~ baseUrl", { baseUrl: baseUrl, tokenSn: tokenSn, tokenUuid: tokenUuid });
        var agent = new https.Agent({
            rejectUnauthorized: false,
        });
        return new Promise(function (resolve, reject) { return __awaiter(_this, void 0, void 0, function () {
            var response, data, error_1;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        _a.trys.push([0, 2, , 3]);
                        return [4 /*yield*/, node_fetch_1.default(baseUrl + "otp-request", {
                                method: "POST",
                                body: JSON.stringify({ tokenSn: tokenSn, tokenUuid: tokenUuid }),
                                headers: { 'Content-Type': 'application/json' },
                                agent: agent
                            }).then(function (response) {
                                return response.json();
                            })];
                    case 1:
                        response = _a.sent();
                        console.log(response);
                        data = __assign(__assign({}, response), { tokenUUID: tokenUuid });
                        console.log(data);
                        resolve(data);
                        return [3 /*break*/, 3];
                    case 2:
                        error_1 = _a.sent();
                        console.error(error_1);
                        reject(error_1);
                        return [3 /*break*/, 3];
                    case 3: return [2 /*return*/];
                }
            });
        }); });
    };
    return SendCEOTP;
}());
exports.SendCEOTP = SendCEOTP;
var AuthorizeCE = /** @class */ (function () {
    function AuthorizeCE() {
    }
    AuthorizeCE.prototype.handleRequest = function (_a) {
        var _this = this;
        var baseUrl = _a.baseUrl, tokenSn = _a.tokenSn, otpCode = _a.otpCode;
        console.log("🚀 ~ handleRequest ~ baseUrl", { baseUrl: baseUrl, tokenSn: tokenSn, otpCode: otpCode });
        var agent = new https.Agent({
            rejectUnauthorized: false,
        });
        return new Promise(function (resolve, reject) { return __awaiter(_this, void 0, void 0, function () {
            var response, error_2;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        _a.trys.push([0, 2, , 3]);
                        return [4 /*yield*/, node_fetch_1.default(baseUrl + "authorize", {
                                method: "POST",
                                headers: {
                                    'Content-Type': 'application/json',
                                    'X-Auth-TokenSN': tokenSn,
                                    'X-Auth-OTP': otpCode
                                },
                                agent: agent
                            }).then(function (response) {
                                return response.json();
                            })];
                    case 1:
                        response = _a.sent();
                        console.log(response);
                        resolve(response);
                        return [3 /*break*/, 3];
                    case 2:
                        error_2 = _a.sent();
                        console.error(error_2);
                        reject(error_2);
                        return [3 /*break*/, 3];
                    case 3: return [2 /*return*/];
                }
            });
        }); });
    };
    return AuthorizeCE;
}());
exports.AuthorizeCE = AuthorizeCE;
var AdminSecretCE = /** @class */ (function () {
    function AdminSecretCE() {
    }
    AdminSecretCE.prototype.handleRequest = function (_a) {
        var _this = this;
        var baseUrl = _a.baseUrl, token = _a.token;
        console.log("🚀 ~ handleRequest ~ baseUrl", { baseUrl: baseUrl, token: token });
        var agent = new https.Agent({
            rejectUnauthorized: false,
        });
        return new Promise(function (resolve, reject) { return __awaiter(_this, void 0, void 0, function () {
            var response, error_3;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        _a.trys.push([0, 2, , 3]);
                        return [4 /*yield*/, node_fetch_1.default(baseUrl + "token/admin-secrets", {
                                method: "GET",
                                headers: {
                                    'Content-Type': 'application/json',
                                    'X-Auth-Token': token
                                },
                                agent: agent
                            }).then(function (response) {
                                return response.json();
                            })];
                    case 1:
                        response = _a.sent();
                        console.log(response);
                        resolve(response);
                        return [3 /*break*/, 3];
                    case 2:
                        error_3 = _a.sent();
                        console.error(error_3);
                        reject(error_3);
                        return [3 /*break*/, 3];
                    case 3: return [2 /*return*/];
                }
            });
        }); });
    };
    return AdminSecretCE;
}());
exports.AdminSecretCE = AdminSecretCE;
var DoublePinChannel = /** @class */ (function () {
    function DoublePinChannel() {
    }
    DoublePinChannel.prototype.handleRequest = function (body) {
        logger.info("DoublePin %s", logger_1.safeJsonStringify(body));
        var instance = dikeClients_1.DikeClients.getInstance();
        return instance.deviceSetDoublePin(body.index, body.enabled);
    };
    return DoublePinChannel;
}());
exports.DoublePinChannel = DoublePinChannel;
var AddP12Channel = /** @class */ (function () {
    function AddP12Channel() {
    }
    AddP12Channel.prototype.handleRequest = function (body) {
        logger.info('AddP12Channel %s', JSON.stringify(body));
        var instance = dikeClients_1.DikeClients.getInstance();
        return instance.addPkcs12File(body.path, body.password, body.force);
    };
    return AddP12Channel;
}());
exports.AddP12Channel = AddP12Channel;
var RemoveP12Channel = /** @class */ (function () {
    function RemoveP12Channel() {
    }
    RemoveP12Channel.prototype.handleRequest = function (body) {
        logger.info('RemoveP12Channel %s', JSON.stringify(body));
        var instance = dikeClients_1.DikeClients.getInstance();
        return instance.removePkcs12File(body.certificateId);
    };
    return RemoveP12Channel;
}());
exports.RemoveP12Channel = RemoveP12Channel;
var OsOpenCertificateChannel = /** @class */ (function () {
    function OsOpenCertificateChannel() {
    }
    OsOpenCertificateChannel.prototype.handleRequest = function (body) {
        console.log('Saving and opening certificate PEM');
        var temp = electron_1.app.getPath('temp');
        if (lodash_1.isNil(temp)) {
            return Promise.reject(model_1.DikeError.of(DikeErrors_1.DikeErrors.CANNOT_RETRIEVE_TEMP_FOLDER, 'Cannot retrieve temp folder'));
        }
        var filename = uuid_1.v4() + ".cer";
        var tmpPath = path.join(temp, filename);
        console.log("Storing certificate PEM file in " + tmpPath);
        return this.storeFile(tmpPath, body.pem).then(function () { return ({
            opened: electron_1.shell.openPath(tmpPath),
        }); });
    };
    OsOpenCertificateChannel.prototype.storeFile = function (path, pem) {
        var writefile = Util.promisify(fs.writeFile);
        return writefile(path, pem);
    };
    return OsOpenCertificateChannel;
}());
exports.OsOpenCertificateChannel = OsOpenCertificateChannel;
var SetCustomP11 = /** @class */ (function () {
    function SetCustomP11() {
    }
    SetCustomP11.prototype.handleRequest = function (body) {
        logger.info("SetCustomP11 %s", logger_1.safeJsonStringify(body));
        var instance = dikeClients_1.DikeClients.getInstance();
        var atr = body.atr, lib = body.lib, readerIndex = body.readerIndex;
        return instance.deviceSetCustomP11(readerIndex, atr, lib);
    };
    return SetCustomP11;
}());
exports.SetCustomP11 = SetCustomP11;
var UnSetCustomP11 = /** @class */ (function () {
    function UnSetCustomP11() {
    }
    UnSetCustomP11.prototype.handleRequest = function () {
        var instance = dikeClients_1.DikeClients.getInstance();
        return instance.deviceUnsetCustomP11();
    };
    return UnSetCustomP11;
}());
exports.UnSetCustomP11 = UnSetCustomP11;
//# sourceMappingURL=DeviceHandlers.js.map