"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Ipc_1 = require("../Ipc");
var dikeClients_1 = require("../dikeClients");
var flows_1 = require("@ice/dike-core-js/lib/types/flows");
var logger_1 = require("../logger");
var operators_1 = require("rxjs/operators");
var lodash_1 = require("lodash");
var DikeOperations_1 = require("../shared/DikeOperations");
var logger = logger_1.provideLogger('EmissionHandlers');
var EmissionListener = /** @class */ (function () {
    function EmissionListener(core, browserWindow, logger) {
        this.logger = logger;
        core.Messages$.pipe(operators_1.filter(function (value) { return lodash_1.isEqual(value.msg_type, 'emissionevent'); }), operators_1.tap(function (messages) {
            logger.info("Received message '%s'", JSON.stringify(messages));
            var webServer = core.webServer;
            browserWindow().show();
            if (!Ipc_1.IpcRegistry.Instance.isSubscribed(DikeOperations_1.DikeOperations.CORE_EMISSION)) {
                Ipc_1.IpcRegistry.Instance.bindObservable(DikeOperations_1.DikeOperations.CORE_EMISSION, webServer.emissionFlow.FlowData$, browserWindow);
            }
        })).subscribe();
    }
    return EmissionListener;
}());
exports.EmissionListener = EmissionListener;
var EmissionSendRAOAuthChannel = /** @class */ (function () {
    function EmissionSendRAOAuthChannel() {
    }
    EmissionSendRAOAuthChannel.prototype.handleRequest = function (body) {
        logger.info("Sending authentication params: %s", logger_1.safeJsonStringify(body));
        return dikeClients_1.DikeClients.getInstance().webServer.emissionFlow.send(flows_1.FlowEvent.DGS_EVT_EMISSION_RAOPIN_INSERTED, body);
    };
    return EmissionSendRAOAuthChannel;
}());
exports.EmissionSendRAOAuthChannel = EmissionSendRAOAuthChannel;
var EmissionSendSCPinChannel = /** @class */ (function () {
    function EmissionSendSCPinChannel() {
    }
    EmissionSendSCPinChannel.prototype.handleRequest = function (body) {
        logger.info("Sending SC pin params: %s", logger_1.safeJsonStringify(body));
        return dikeClients_1.DikeClients.getInstance().webServer.emissionFlow.send(flows_1.FlowEvent.DGS_EVT_EMISSION_SCPIN_INSERTED, body);
    };
    return EmissionSendSCPinChannel;
}());
exports.EmissionSendSCPinChannel = EmissionSendSCPinChannel;
var EmissionSendTrashCertsChannel = /** @class */ (function () {
    function EmissionSendTrashCertsChannel() {
    }
    EmissionSendTrashCertsChannel.prototype.handleRequest = function (body) {
        logger.info("Sending trash certs params: %s", logger_1.safeJsonStringify(body));
        return dikeClients_1.DikeClients.getInstance().webServer.emissionFlow.send(flows_1.FlowEvent.DGS_EVT_EMISSION_TRASH_CERTS, body);
    };
    return EmissionSendTrashCertsChannel;
}());
exports.EmissionSendTrashCertsChannel = EmissionSendTrashCertsChannel;
var EmissionStartSigningChannel = /** @class */ (function () {
    function EmissionStartSigningChannel() {
    }
    EmissionStartSigningChannel.prototype.handleRequest = function (body) {
        logger.info("Start signing %s", logger_1.safeJsonStringify(body));
        return dikeClients_1.DikeClients.getInstance().webServer.emissionFlow.send(flows_1.FlowEvent.DGS_EVT_START_SIGN);
    };
    return EmissionStartSigningChannel;
}());
exports.EmissionStartSigningChannel = EmissionStartSigningChannel;
var EmissionOtpSend = /** @class */ (function () {
    function EmissionOtpSend() {
    }
    EmissionOtpSend.prototype.handleRequest = function (body) {
        logger.info("Sending OTP");
        return dikeClients_1.DikeClients.getInstance().webServer.emissionFlow.send(flows_1.FlowEvent.DGS_EVT_OTP_INSERTED, { otp: body });
    };
    return EmissionOtpSend;
}());
exports.EmissionOtpSend = EmissionOtpSend;
var EmissionPollAuthorization = /** @class */ (function () {
    function EmissionPollAuthorization() {
    }
    EmissionPollAuthorization.prototype.handleRequest = function (body) {
        logger.info("Polling authorization");
        var emissionFlow = dikeClients_1.DikeClients.getInstance().webServer.emissionFlow;
        return emissionFlow.send(flows_1.FlowEvent.DGS_EVT_POLL_AUTHORIZATION).then(function () { return ({}); });
    };
    return EmissionPollAuthorization;
}());
exports.EmissionPollAuthorization = EmissionPollAuthorization;
var EmissionResendSms = /** @class */ (function () {
    function EmissionResendSms() {
    }
    EmissionResendSms.prototype.handleRequest = function (body) {
        logger.info("Resend SMS");
        var emissionFlow = dikeClients_1.DikeClients.getInstance().webServer.emissionFlow;
        return emissionFlow.send(flows_1.FlowEvent.DGS_EVT_RESEND_OTP).then(function () { return ({}); });
    };
    return EmissionResendSms;
}());
exports.EmissionResendSms = EmissionResendSms;
var EmissionAbort = /** @class */ (function () {
    function EmissionAbort() {
    }
    EmissionAbort.prototype.handleRequest = function (body) {
        var emissionFlow = dikeClients_1.DikeClients.getInstance().webServer.emissionFlow;
        return emissionFlow.abort().then(function () { return ({}); });
    };
    return EmissionAbort;
}());
exports.EmissionAbort = EmissionAbort;
//# sourceMappingURL=EmissionHandler.js.map