"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var request_1 = require("../shared/request");
var dikeClients_1 = require("../dikeClients");
var flows_1 = require("@ice/dike-core-js/lib/types/flows");
var genericFsm_1 = require("../FSM/genericFsm");
var FSM_1 = require("../FSM");
var logger_1 = require("../logger");
var lodash_1 = require("lodash");
var Immutable = require("immutable");
var fs = require("fs");
var path = require('path');
var logger = logger_1.provideLogger('EncipherHandlers');
var ENCIPHER_FLOW_TYPE = flows_1.FlowType.DGS_FLOW_ENCRYPT;
var EncipherFsmInitChannel = /** @class */ (function () {
    function EncipherFsmInitChannel() {
    }
    EncipherFsmInitChannel.prototype.handleRequest = function (body) {
        logger.info('Encipher initialization');
        var genericFsm = genericFsm_1.GenericFsm.of(ENCIPHER_FLOW_TYPE, dikeClients_1.DikeClients.getInstance());
        genericFsm_1.FsmRegistry.getInstance().set(ENCIPHER_FLOW_TYPE, genericFsm);
        return genericFsm.init().then(function () { return genericFsm.nextState()
            .then(function (v) { return FSM_1.fromState(v); }); });
    };
    return EncipherFsmInitChannel;
}());
exports.EncipherFsmInitChannel = EncipherFsmInitChannel;
var EncipherFsmPerformChannel = /** @class */ (function () {
    function EncipherFsmPerformChannel() {
    }
    EncipherFsmPerformChannel.prototype.handleRequest = function (body) {
        logger.info('Encipher performing operation');
        var payload = request_1.mapToEncryptParamsInserted(body);
        var genericFsm = genericFsm_1.FsmRegistry.getInstance().get(ENCIPHER_FLOW_TYPE);
        return genericFsm.send(flows_1.FlowEvent.DGS_EVT_ENCRYPT_PARAMS_INSERTED, payload)
            .then(function (v) { return FSM_1.fromState(v); });
    };
    return EncipherFsmPerformChannel;
}());
exports.EncipherFsmPerformChannel = EncipherFsmPerformChannel;
var EncipherFsmAbortChannel = /** @class */ (function () {
    function EncipherFsmAbortChannel() {
    }
    EncipherFsmAbortChannel.prototype.handleRequest = function (body) {
        logger.info('Encipher aborting operation');
        var genericFsm = genericFsm_1.FsmRegistry.getInstance().get(ENCIPHER_FLOW_TYPE);
        return genericFsm.flow.abort().then(function (value) { return !value ? {} : value; });
    };
    return EncipherFsmAbortChannel;
}());
exports.EncipherFsmAbortChannel = EncipherFsmAbortChannel;
var EncipherValidateChannel = /** @class */ (function () {
    function EncipherValidateChannel() {
    }
    EncipherValidateChannel.prototype.handleRequest = function (body) {
        if (!body.isOutputArchive && lodash_1.get(body, 'files', []).length > 1) {
            var immutableRequest = Immutable.fromJS(body);
            var newRequest = immutableRequest.set('files', immutableRequest.get('files').map(function (file) {
                var name = path.parse(file.get('inputPath')).name + ".p7e";
                var outPath = file.get('outputPath');
                try {
                    if (!fs.existsSync(outPath)) {
                        fs.mkdirSync(outPath, { recursive: true });
                    }
                }
                catch (_) {
                    //Ignore
                }
                return file.set('outputPath', path.join(outPath, name));
            }));
            return Promise.resolve(newRequest.toJS());
        }
        else {
            return Promise.resolve(body);
        }
    };
    return EncipherValidateChannel;
}());
exports.EncipherValidateChannel = EncipherValidateChannel;
//# sourceMappingURL=EncipherHandlers.js.map