"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var logger_1 = require("../logger");
var ResolvePortableRoot_1 = require("../ResolvePortableRoot");
var path = require("path");
var fs = require("fs");
var child_process_1 = require("child_process");
var logger = logger_1.provideLogger('GoSignWebHandlers');
var FirefoxCheckChannel = /** @class */ (function () {
    function FirefoxCheckChannel() {
    }
    FirefoxCheckChannel.prototype.handleRequest = function (body) {
        logger.info("Firefox Check Request '%s'", body);
        var retval = {
            libbitStatus: 'INSTALLED',
            pluginStatus: 'INSTALLED',
        };
        return new Promise(function (resolve) {
            fs.access('C:\\Windows\\System32\\bit4xpki.dll', function (err) {
                if (err) {
                    logger.info("Library component is not installed: '%s'", err);
                    retval.libbitStatus = 'NOT_INSTALLED';
                }
                logger.info("Library component is installed.");
                fs.access('C:\\Program Files (x86)\\Firefox PKCS11 Loader\\bit4xpki.json', function (err2) {
                    if (err2) {
                        logger.info("Plugin component is not installed: '%s'", err2);
                        retval.pluginStatus = 'NOT_INSTALLED';
                    }
                    logger.info("Plugin component is installed.");
                    resolve(retval);
                });
            });
        });
    };
    return FirefoxCheckChannel;
}());
exports.FirefoxCheckChannel = FirefoxCheckChannel;
var FirefoxOpenChannel = /** @class */ (function () {
    function FirefoxOpenChannel() {
    }
    FirefoxOpenChannel.prototype.handleRequest = function (body) {
        logger.info("Firefox Open Request '%s'", body);
        var portableRoot = ResolvePortableRoot_1.resolvePortableRoot();
        var profilePath = path.join(portableRoot, 'Configurazione', 'FirefoxPortable', 'Data', 'profile');
        var arg = [];
        if (!fs.existsSync(profilePath)) {
            arg.push('https://addons.mozilla.org/firefox/downloads/file/3784342/smartcard_signature_library_loader-1.0.0-fx.xpi');
        }
        return new Promise(function (resolve, reject) {
            var firefox = child_process_1.spawn(path.join(portableRoot, 'Configurazione', 'FirefoxPortable', 'FirefoxPortable.exe'), arg);
            firefox.on('spawn', function () {
                resolve({ success: true });
            });
            firefox.on('error', function (err) {
                logger.error("Error launching firefox '%s'", err);
                reject(err);
            });
        });
    };
    return FirefoxOpenChannel;
}());
exports.FirefoxOpenChannel = FirefoxOpenChannel;
var FirefoxLoaderInstallChannel = /** @class */ (function () {
    function FirefoxLoaderInstallChannel() {
    }
    FirefoxLoaderInstallChannel.prototype.handleRequest = function (body) {
        logger.info("Firefox Install Loader Request '%s'", body);
        var msiPath = path.join(ResolvePortableRoot_1.resolvePortableRoot(), 'Configurazione', 'Windows', 'Installer', 'firefox-pkcs11-loader.msi');
        logger.info("Resources path is : '%s'", msiPath);
        return new Promise(function (resolve, reject) {
            var msiexec = child_process_1.spawn('msiexec', ['/package', msiPath]);
            msiexec.on('data', function (data) {
                logger.info("'%s'", data);
            });
            msiexec.on('close', function (code) {
                logger.info("'%s'", code);
                resolve({ code: code });
            });
            msiexec.on('error', function (err) {
                logger.error("Error installing firefox plugin '%s'", err);
                reject(err);
            });
        });
    };
    return FirefoxLoaderInstallChannel;
}());
exports.FirefoxLoaderInstallChannel = FirefoxLoaderInstallChannel;
//# sourceMappingURL=FirefoxLoadingHandler.js.map