"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var FSM_1 = require("../FSM");
var genericFsm_1 = require("../FSM/genericFsm");
var flows_1 = require("@ice/dike-core-js/lib/types/flows");
var dikeClients_1 = require("../dikeClients");
var request_1 = require("../shared/request");
var timestampRequestService_1 = require("../timestampRequestService");
var model_1 = require("../model");
var DikeErrors_1 = require("../shared/DikeErrors");
var logger_1 = require("../logger");
var logger = logger_1.provideLogger('TimestampHandlers');
var ACCOUNTS_FLOW_TYPE = flows_1.FlowType.DGS_FLOW_TS_BIND;
var TimestampAccountFsmChannelInit = /** @class */ (function () {
    function TimestampAccountFsmChannelInit() {
    }
    TimestampAccountFsmChannelInit.prototype.handleRequest = function (body) {
        var gFsm = genericFsm_1.GenericFsm.of(ACCOUNTS_FLOW_TYPE, dikeClients_1.DikeClients.getInstance());
        gFsm.setLogger(logger);
        genericFsm_1.FsmRegistry.getInstance().set(ACCOUNTS_FLOW_TYPE, gFsm);
        return gFsm.init().then(function () {
            return gFsm.nextState().then(function (v) { return FSM_1.fromState(v); });
        });
    };
    return TimestampAccountFsmChannelInit;
}());
exports.TimestampAccountFsmChannelInit = TimestampAccountFsmChannelInit;
var TimestampAccountFsmChannelLogin = /** @class */ (function () {
    function TimestampAccountFsmChannelLogin() {
    }
    TimestampAccountFsmChannelLogin.prototype.handleRequest = function (body) {
        var genericFsm = genericFsm_1.FsmRegistry.getInstance().get(ACCOUNTS_FLOW_TYPE);
        var promise = genericFsm.nextState().then(function (v) { return FSM_1.fromState(v); });
        genericFsm.send(flows_1.FlowEvent.DGS_EVT_CREDENTIAL_INSERTED, body);
        return promise;
    };
    return TimestampAccountFsmChannelLogin;
}());
exports.TimestampAccountFsmChannelLogin = TimestampAccountFsmChannelLogin;
var TimestampAccountFsmChannelRetrieve = /** @class */ (function () {
    function TimestampAccountFsmChannelRetrieve() {
    }
    TimestampAccountFsmChannelRetrieve.prototype.handleRequest = function (body) {
        return dikeClients_1.DikeClients.getInstance().getTimestampAccount(true);
    };
    return TimestampAccountFsmChannelRetrieve;
}());
exports.TimestampAccountFsmChannelRetrieve = TimestampAccountFsmChannelRetrieve;
var TimestampAccountFsmChannelRemove = /** @class */ (function () {
    function TimestampAccountFsmChannelRemove() {
    }
    TimestampAccountFsmChannelRemove.prototype.handleRequest = function (body) {
        return dikeClients_1.DikeClients.getInstance().deleteTimestampAccount();
    };
    return TimestampAccountFsmChannelRemove;
}());
exports.TimestampAccountFsmChannelRemove = TimestampAccountFsmChannelRemove;
var TIMESTAMP_FLOW_TYPE = flows_1.FlowType.DGS_FLOW_TIMESTAMP;
var TimestampValidateRequestChannel = /** @class */ (function () {
    function TimestampValidateRequestChannel() {
    }
    TimestampValidateRequestChannel.prototype.handleRequest = function (body) {
        logger.info('Timestamp request validation');
        if (body.status === 'NEW') {
            return timestampRequestService_1.default.validateRequest(body);
        }
        else {
            Promise.reject(model_1.DikeError.of(DikeErrors_1.DikeErrors.INVALID_STATUS, "Invalid request status " + body.status));
        }
    };
    return TimestampValidateRequestChannel;
}());
exports.TimestampValidateRequestChannel = TimestampValidateRequestChannel;
var TimestampFsmInitChannel = /** @class */ (function () {
    function TimestampFsmInitChannel() {
    }
    TimestampFsmInitChannel.prototype.handleRequest = function (body) {
        logger.info('Timestamp initialization');
        var genericFsm = genericFsm_1.GenericFsm.of(TIMESTAMP_FLOW_TYPE, dikeClients_1.DikeClients.getInstance());
        genericFsm.setLogger(logger);
        genericFsm_1.FsmRegistry.getInstance().set(TIMESTAMP_FLOW_TYPE, genericFsm);
        return genericFsm.init().then(function () { return genericFsm.nextState()
            .then(function (v) { return FSM_1.fromState(v); }); });
    };
    return TimestampFsmInitChannel;
}());
exports.TimestampFsmInitChannel = TimestampFsmInitChannel;
var TimestampFsmPerformChannel = /** @class */ (function () {
    function TimestampFsmPerformChannel(analyticsEventHandler) {
        this.analyticsEventHandler = analyticsEventHandler;
    }
    TimestampFsmPerformChannel.prototype.handleRequest = function (body) {
        var _this = this;
        logger.info('Timestamp performing operation');
        var payload = request_1.mapToTimestampParamsInserted(body);
        var genericFsm = genericFsm_1.FsmRegistry.getInstance().get(TIMESTAMP_FLOW_TYPE);
        return genericFsm.send(flows_1.FlowEvent.DGS_EVT_TIMESTAMP_PARAMS_INSERTED, payload)
            .then(function (v) {
            if (v.state_type === flows_1.FlowStateType.DGS_STATE_TS_DONE) {
                var state = v.state_data;
                var okCount = state.results.filter(function (value) { return value >= 0; }).length;
                _this.analyticsEventHandler.sendTimestamp(okCount);
            }
            ;
            return FSM_1.fromState(v);
        });
    };
    return TimestampFsmPerformChannel;
}());
exports.TimestampFsmPerformChannel = TimestampFsmPerformChannel;
var TimestampFsmAbortChannel = /** @class */ (function () {
    function TimestampFsmAbortChannel() {
    }
    TimestampFsmAbortChannel.prototype.handleRequest = function (body) {
        logger.info('Timestamp aborting operation');
        var genericFsm = genericFsm_1.FsmRegistry.getInstance().get(TIMESTAMP_FLOW_TYPE);
        return genericFsm.flow.abort().then(function (value) { return !value ? {} : value; });
    };
    return TimestampFsmAbortChannel;
}());
exports.TimestampFsmAbortChannel = TimestampFsmAbortChannel;
//# sourceMappingURL=TimestampHandlers.js.map