"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var flows_1 = require("@ice/dike-core-js/lib/types/flows");
var FSM_1 = require("../FSM");
var electron_main_1 = require("../../electron.main");
var lodash_1 = require("lodash");
var electron_1 = require("electron");
var dikeClients_1 = require("../dikeClients");
var genericFsm_1 = require("../FSM/genericFsm");
var model_1 = require("../model");
var DikeErrors_1 = require("../shared/DikeErrors");
var Utils_1 = require("../Utils");
var gosign_1 = require("@ice/dike-core-js/lib/types/gosign");
var os = require('os');
var FLOW_TYPE = flows_1.FlowType.DGS_FLOW_UPDATECHECK;
var CheckUpdateInitChannel = /** @class */ (function () {
    function CheckUpdateInitChannel(browserWindowResolver, logger) {
        this.browserWindowResolver = browserWindowResolver;
        this.logger = logger;
    }
    CheckUpdateInitChannel.prototype.handleRequest = function (body) {
        this.logger.info('Init verification fsm');
        var gFsm = genericFsm_1.GenericFsm.of(FLOW_TYPE, dikeClients_1.DikeClients.getInstance());
        genericFsm_1.FsmRegistry.getInstance().set(FLOW_TYPE, gFsm);
        // IpcRegistry.Instance.bindObservable(
        //   DikeOperations.UPDATER_PROGRESS_QUEUE,
        //   gFsm.flow.FlowData$,
        //   this.browserWindowResolver
        // );
        return gFsm.init().then(function () {
            return gFsm.nextState().then(function (v) { return FSM_1.fromState(v); });
        });
    };
    return CheckUpdateInitChannel;
}());
exports.CheckUpdateInitChannel = CheckUpdateInitChannel;
var CheckUpdateChannel = /** @class */ (function () {
    function CheckUpdateChannel(versionResolver, logger, electronMessages) {
        this.versionResolver = versionResolver;
        this.logger = logger;
        this.electronMessages = electronMessages;
    }
    CheckUpdateChannel.prototype.handleRequest = function (body) {
        var _this = this;
        this.logger.info("Checking '%s'", body);
        if (electron_main_1.LAUNCH_ARGS.skipupdate || electron_main_1.LAUNCH_ARGS.tdd) {
            this.logger.info("Skipped by LAUNCH_ARGS skipupdate || tdd");
            return Promise.resolve({
                status: 'NO_UPDATE',
                filepath: '',
                newVersion: ''
            });
        }
        if (['win32', 'darwin'].includes(os.platform()) && Utils_1.isSquirrel()) {
            return dikeClients_1.DikeClients.getInstance().getUrl(os.platform() == 'darwin' ? gosign_1.DGS_URLS.RINNOVO_BASE_URL : gosign_1.DGS_URLS.SQUIRREL_UPDATE_URL)
                .then(function (value) {
                var updateFeed = value.url + (os.platform() === 'darwin' ? "/updates/" + electron_main_1.PROFILE.customization + "/squirrel" : '/');
                electron_1.autoUpdater.setFeedURL({
                    url: updateFeed + "?v=" + _this.versionResolver()
                });
                _this.logger.info("Checking '%s'", electron_1.autoUpdater.getFeedURL());
                // Display a success message on successful update
                electron_1.autoUpdater.addListener("update-downloaded", function (event, releaseNotes, releaseName) {
                    _this.logger.info("Update downloaded!");
                    _this.electronMessages.next({
                        id: '',
                        msg_type: 'autoupdate',
                        payload: null,
                        timestamp: new Date().getTime()
                    });
                });
                //autoUpdater.quitAndInstall()
                // Display an error message on update error
                electron_1.autoUpdater.addListener("error", function (error) {
                    _this.logger.info("Error checking for update: %s", error);
                });
                electron_1.autoUpdater.checkForUpdates();
                return {
                    status: 'NO_UPDATE',
                    filepath: '',
                    newVersion: ''
                };
            });
        }
        else {
            //Old updating
            var genericFsm = genericFsm_1.FsmRegistry.getInstance().get(FLOW_TYPE);
            var payload = {
                version: this.versionResolver(),
            };
            return genericFsm
                .send(flows_1.FlowEvent.DGS_EVT_UPDATE_CHECK_REQUESTED, payload)
                .then(function (value) {
                var value1 = value.state_data;
                return _this.updateAvailable(value1);
            })
                .then(function (res) {
                _this.logger.info("Response '%s'", JSON.stringify(res));
                return res;
            });
        }
    };
    CheckUpdateChannel.prototype.updateAvailable = function (value) {
        if (lodash_1.has(value, 'updateinfo')) {
            return {
                status: 'UPDATE_AVAILABLE',
                filepath: value.updateinfo.path,
                newVersion: value.updateinfo.version,
            };
        }
        else {
            return {
                status: 'NO_UPDATE',
                filepath: '',
                newVersion: ''
            };
        }
    };
    return CheckUpdateChannel;
}());
exports.CheckUpdateChannel = CheckUpdateChannel;
var UpdateChannel = /** @class */ (function () {
    function UpdateChannel(logger) {
        this.logger = logger;
    }
    UpdateChannel.prototype.handleRequest = function (body) {
        this.logger.info("Installing '%s'", JSON.stringify(body));
        var res = electron_1.shell.openPath(body.path);
        if (res) {
            return Promise.resolve({});
        }
        else {
            return Promise.reject(model_1.DikeError.of(DikeErrors_1.DikeErrors.CANNOT_OPEN_UPDATE_FILE, "Cannot find file " + body.path));
        }
    };
    return UpdateChannel;
}());
exports.UpdateChannel = UpdateChannel;
var RestartUpdateChannel = /** @class */ (function () {
    function RestartUpdateChannel(logger) {
        this.logger = logger;
    }
    RestartUpdateChannel.prototype.handleRequest = function (body) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            _this.logger.info("Installing '%s'", JSON.stringify(body));
            try {
                electron_1.autoUpdater.quitAndInstall();
                setTimeout(function () {
                    electron_1.app.relaunch();
                    electron_1.app.exit(0);
                }, 10000); //6000
                resolve({});
            }
            catch (error) {
                _this.logger.error("Errore durante l'installazione dell'aggiornamento: " + error);
                reject(error);
            }
        });
    };
    return RestartUpdateChannel;
}());
exports.RestartUpdateChannel = RestartUpdateChannel;
//# sourceMappingURL=UpdaterHandlers.js.map