"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var flows_1 = require("@ice/dike-core-js/lib/types/flows");
var date_fns_1 = require("date-fns");
var electron_1 = require("electron");
var fs = require("fs");
var lodash_1 = require("lodash");
var path = require("path");
var uuid_1 = require("uuid");
var dikeClients_1 = require("../dikeClients");
var FSM_1 = require("../FSM");
var genericFsm_1 = require("../FSM/genericFsm");
var logger_1 = require("../logger");
var model_1 = require("../model");
var DikeErrors_1 = require("../shared/DikeErrors");
var request_1 = require("../shared/request");
var qualified_validation_1 = require("@ice/dike-core-js/lib/types/qualified_validation");
var logger = logger_1.provideLogger('VerificationHandlers');
var assert = require('assert').strict;
var FLOW_TYPE = flows_1.FlowType.DGS_FLOW_VERIFY;
var VerificationFsmChannelInit = /** @class */ (function () {
    function VerificationFsmChannelInit() {
    }
    VerificationFsmChannelInit.prototype.handleRequest = function (body) {
        logger.info('Init verification fsm');
        var genericFsm = genericFsm_1.GenericFsm.of(FLOW_TYPE, dikeClients_1.DikeClients.getInstance());
        genericFsm_1.FsmRegistry.getInstance().set(FLOW_TYPE, genericFsm);
        return genericFsm.init().then(function () {
            return genericFsm.nextState().then(function (v) { return FSM_1.fromState(v); });
        });
    };
    return VerificationFsmChannelInit;
}());
exports.VerificationFsmChannelInit = VerificationFsmChannelInit;
var VerificationFsmChannelVerify = /** @class */ (function () {
    function VerificationFsmChannelVerify(analyticsEventHandler) {
        this.analyticsEventHandler = analyticsEventHandler;
    }
    VerificationFsmChannelVerify.prototype.handleRequest = function (body) {
        var _this = this;
        logger.info('Performing verification %s', JSON.stringify(body));
        var payload = {
            files: body.files,
            check_revocation: true,
            verify_date: date_fns_1.format(new Date(), "yyyyMMdd'T'HHmmss'Z'"),
        };
        var genericFsm = genericFsm_1.FsmRegistry.getInstance().get(FLOW_TYPE);
        return genericFsm
            .send(flows_1.FlowEvent.DGS_EVT_VERIFY_PARAMS_INSERTED, payload)
            .then(function (value) {
            if (value.state_type === flows_1.FlowStateType.DGS_STATE_VERIFY_DONE) {
                var state = value.state_data;
                var count = state.results.length;
                _this.analyticsEventHandler.sendVerification(count);
            }
            ;
            return FSM_1.fromState(value);
        });
    };
    return VerificationFsmChannelVerify;
}());
exports.VerificationFsmChannelVerify = VerificationFsmChannelVerify;
var VerificationFsmChannelTslAdded = /** @class */ (function () {
    function VerificationFsmChannelTslAdded() {
    }
    VerificationFsmChannelTslAdded.prototype.handleRequest = function (body) {
        logger.info('Adding missing TSL %s', JSON.stringify(body.countries));
        var genericFsm = genericFsm_1.FsmRegistry.getInstance().get(FLOW_TYPE);
        var payload = {
            countries_tsl: body.countries,
        };
        return genericFsm
            .send(flows_1.FlowEvent.DGS_EVT_VERIFY_ADD_COUNTRY_TSL, payload)
            .then(function (value) { return FSM_1.fromState(value); });
    };
    return VerificationFsmChannelTslAdded;
}());
exports.VerificationFsmChannelTslAdded = VerificationFsmChannelTslAdded;
var VerificationFsmChannelDetachedSourcesPassed = /** @class */ (function () {
    function VerificationFsmChannelDetachedSourcesPassed() {
    }
    VerificationFsmChannelDetachedSourcesPassed.prototype.handleRequest = function (body) {
        logger.info('Passing detached sources %s', JSON.stringify(body.sources));
        var genericFsm = genericFsm_1.FsmRegistry.getInstance().get(FLOW_TYPE);
        var payload = request_1.mapToVerifyDetachedSources(body);
        return genericFsm
            .send(flows_1.FlowEvent.DGS_EVT_VERIFY_DETACHED_SOURCES, payload)
            .then(function (value) { return FSM_1.fromState(value); });
    };
    return VerificationFsmChannelDetachedSourcesPassed;
}());
exports.VerificationFsmChannelDetachedSourcesPassed = VerificationFsmChannelDetachedSourcesPassed;
var VerificationFsmChannelOpenReport = /** @class */ (function () {
    function VerificationFsmChannelOpenReport() {
    }
    VerificationFsmChannelOpenReport.prototype.handleRequest = function (body) {
        logger.info("Opening report request %s", JSON.stringify(body));
        var core = dikeClients_1.DikeClients.getInstance();
        try {
            var temp = electron_1.app.getPath('temp');
            assert(!lodash_1.isNil(temp), 'Cannot determine temp folder');
            var filename = uuid_1.v4() + ".html";
            var tmpPath_1 = path.join(temp, filename);
            logger.info("Storing report file in " + temp);
            var atDateFmt = undefined;
            if (!lodash_1.isNil(body.atDate)) {
                atDateFmt = date_fns_1.format(new Date(body.atDate), "yyMMddHHmmss");
            }
            logger.info("At date " + atDateFmt);
            return core.createHTMLverificationReport(body.filePath, tmpPath_1, body.dataFile, atDateFmt).then(function () { return electron_1.shell.openPath(tmpPath_1); });
        }
        catch (e) {
            return Promise.reject(model_1.DikeError.of(DikeErrors_1.DikeErrors.CANNOT_STORE_TEMP, e.message));
        }
    };
    return VerificationFsmChannelOpenReport;
}());
exports.VerificationFsmChannelOpenReport = VerificationFsmChannelOpenReport;
var VerificationAbortChannel = /** @class */ (function () {
    function VerificationAbortChannel() {
    }
    VerificationAbortChannel.prototype.handleRequest = function (body) {
        var genericFsm = genericFsm_1.FsmRegistry.getInstance().get(FLOW_TYPE);
        return genericFsm.flow.abort().then(function (value) { return (!value ? {} : value); });
    };
    return VerificationAbortChannel;
}());
exports.VerificationAbortChannel = VerificationAbortChannel;
var VerificationPerformAtDateChannel = /** @class */ (function () {
    function VerificationPerformAtDateChannel() {
    }
    VerificationPerformAtDateChannel.prototype.handleRequest = function (body) {
        logger.info('Performing verification at date %s', JSON.stringify(body));
        var datafile = body.detachedFilePath ? body.detachedFilePath : '';
        var verifydate = body.atDate ? body.atDate : '';
        return dikeClients_1.DikeClients.getInstance().verifyFile(body.inputFilePath, datafile, verifydate)
            // TODO: akokot: remove when core library updated
            .then(function (result) { return result; });
    };
    return VerificationPerformAtDateChannel;
}());
exports.VerificationPerformAtDateChannel = VerificationPerformAtDateChannel;
var VerificationExtractHandler = /** @class */ (function () {
    function VerificationExtractHandler(logger) {
        this.logger = logger;
    }
    VerificationExtractHandler.prototype.handleRequest = function (body) {
        this.logger.info("Extract %s", body);
        var filename = path.parse(body.inputFile);
        var folderName = "verification_" + date_fns_1.format(new Date(), "yyMMddHHmmssSSS");
        var tempFolder = lodash_1.cond([
            [function (t) { return t; }, function () { return electron_1.app.getPath('temp'); }],
            [lodash_1.stubTrue, function () { return body.outputFolder; }]
        ])(body.useTemp);
        var extractionFolder = path.join(tempFolder, folderName);
        return this.extract({
            folderName: folderName,
            inputFile: body.inputFile,
            outputFolder: extractionFolder,
            openFirst: body.tryOpenFirstOutput,
            dotExtractedFullPath: extractionFolder
        });
    };
    VerificationExtractHandler.prototype.extract = function (extractArguments) {
        var _this = this;
        this.logger.info("Extracting %s", JSON.stringify(extractArguments));
        return dikeClients_1.DikeClients.getInstance().extractFile(extractArguments.inputFile, extractArguments.outputFolder)
            .then(function (arg) {
            _this.logger.info("ApiResult is " + JSON.stringify(arg));
            var isOpenFirst = function (a) { return a.openFirst; };
            return lodash_1.cond([
                [isOpenFirst, function (a) { return _this.tryOpenFirst(a.dotExtractedFullPath); }],
                [lodash_1.stubTrue, function (a) {
                        electron_1.shell.showItemInFolder(a.dotExtractedFullPath);
                        return { status: 'ok' };
                    }]
            ])(extractArguments);
        });
    };
    /**
     * Try open the first extracted files from dotExtractedFullPath,
     * if path does not exists trhrow an error, if file cannot be opened
     * the paret folder is shown istead
     * @param dotExtractedFullPath
     * @private
     */
    VerificationExtractHandler.prototype.tryOpenFirst = function (dotExtractedFullPath) {
        this.logger.info("Try open first " + dotExtractedFullPath);
        var files = fs.readdirSync(dotExtractedFullPath);
        var firstOutput = lodash_1.get(files, '0', dotExtractedFullPath);
        if (!electron_1.shell.openPath(path.join(dotExtractedFullPath, firstOutput))) {
            this.logger.warn("cannot open " + firstOutput + ", open his parent path " + dotExtractedFullPath + " instead");
            electron_1.shell.showItemInFolder(dotExtractedFullPath);
            return { status: 'ok' };
        }
        return { status: 'ok' };
    };
    return VerificationExtractHandler;
}());
exports.VerificationExtractHandler = VerificationExtractHandler;
var VerificationExtractFilesHandler = /** @class */ (function () {
    function VerificationExtractFilesHandler(logger) {
        this.logger = logger;
    }
    VerificationExtractFilesHandler.prototype.handleRequest = function (body) {
        this.logger.info("Extract %s", body);
        var extractionFolder = body.json.output_dirs[0];
        var json = {
            output_dirs: body.json.output_dirs,
            input_files: body.json.input_files
        };
        return this.extractFiles({
            dotExtractedFullPath: extractionFolder,
            json: json
        });
    };
    VerificationExtractFilesHandler.prototype.extractFiles = function (extractArguments) {
        var _this = this;
        this.logger.info("Extracting %s", JSON.stringify(extractArguments));
        //@ts-ignore
        return dikeClients_1.DikeClients.getInstance().extractFiles(extractArguments.json)
            .then(function (arg) {
            _this.logger.info("ApiResult is " + JSON.stringify(arg));
            return lodash_1.cond([
                [lodash_1.stubTrue, function (a) {
                        electron_1.shell.showItemInFolder(a.dotExtractedFullPath);
                        return { status: 'ok' };
                    }]
            ])(extractArguments);
        });
    };
    return VerificationExtractFilesHandler;
}());
exports.VerificationExtractFilesHandler = VerificationExtractFilesHandler;
var VagaVerificationChannel = /** @class */ (function () {
    function VagaVerificationChannel(logger) {
        this.logger = logger;
    }
    VagaVerificationChannel.prototype.handleRequest = function (body) {
        var core = dikeClients_1.DikeClients.getInstance();
        var signed_file = body.signed_file, _a = body.original_file, original_file = _a === void 0 ? "" : _a, _b = body.paymentType, paymentType = _b === void 0 ? qualified_validation_1.IQVPaymentType.IdentifierPayment : _b, paymentCode = body.paymentCode;
        this.logger.info("Opening report request body= %s", JSON.stringify(body));
        logger.info({ signed_file: signed_file, original_file: original_file, paymentType: paymentType, paymentCode: paymentCode });
        if (!signed_file || !paymentCode || paymentType === undefined) {
            return Promise.reject(model_1.DikeError.of(DikeErrors_1.DikeErrors.CANNOT_STORE_TEMP, "Missing parameters"));
        }
        //auth_token: string, signed_file: string, original_file: string, coupon: string, identifier: string
        return core.generateQualifiedVerifyReport(signed_file, original_file, paymentType, paymentCode);
    };
    return VagaVerificationChannel;
}());
exports.VagaVerificationChannel = VagaVerificationChannel;
var VagaSignChannel = /** @class */ (function () {
    function VagaSignChannel(logger) {
        this.logger = logger;
    }
    VagaSignChannel.prototype.handleRequest = function (body) {
        var core = dikeClients_1.DikeClients.getInstance();
        var pdf_file = body.pdf_file, etsi_xml_report = body.etsi_xml_report, signed_file = body.signed_file, _a = body.paymentType, paymentType = _a === void 0 ? qualified_validation_1.IQVPaymentType.IdentifierPayment : _a, paymentCode = body.paymentCode;
        this.logger.info("Opening sign request   body= %s", JSON.stringify(body));
        logger.info({ pdf_file: pdf_file, etsi_xml_report: etsi_xml_report, signed_file: signed_file, paymentType: paymentType, paymentCode: paymentCode });
        if (!signed_file || !paymentCode || paymentType === undefined) {
            return Promise.reject(model_1.DikeError.of(DikeErrors_1.DikeErrors.CANNOT_STORE_TEMP, "Missing parameters"));
        }
        //auth_token: string, signed_file: string, original_file: string, coupon: string, identifier: string
        return core.signQualifiedVerifyReport(pdf_file, etsi_xml_report, signed_file, paymentType, paymentCode);
    };
    return VagaSignChannel;
}());
exports.VagaSignChannel = VagaSignChannel;
var ValidationCount = /** @class */ (function () {
    function ValidationCount() {
    }
    ValidationCount.prototype.handleRequest = function (body) {
        var instance = dikeClients_1.DikeClients.getInstance();
        return instance.getQualifiedVerifyCount(body.identifier);
    };
    return ValidationCount;
}());
exports.ValidationCount = ValidationCount;
var CheckVagaCoupon = /** @class */ (function () {
    function CheckVagaCoupon() {
    }
    CheckVagaCoupon.prototype.handleRequest = function (body) {
        var instance = dikeClients_1.DikeClients.getInstance();
        var couponType = qualified_validation_1.ICouponType.ValidationCoupon;
        return instance.getCheckCoupon(couponType, body.coupon);
    };
    return CheckVagaCoupon;
}());
exports.CheckVagaCoupon = CheckVagaCoupon;
var VagaReportsChannel = /** @class */ (function () {
    function VagaReportsChannel() {
    }
    VagaReportsChannel.prototype.handleRequest = function () {
        return __awaiter(this, void 0, void 0, function () {
            var instance, reportFolder, files, fileDetails, _i, files_1, file, filePath, parts, filename, date, statusAndExtension, _a, status_1, extension, err_1;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        instance = dikeClients_1.DikeClients.getInstance();
                        reportFolder = path.join(instance.homePath, 'qsvs');
                        _b.label = 1;
                    case 1:
                        _b.trys.push([1, 3, , 4]);
                        return [4 /*yield*/, fs.readdirSync(reportFolder)];
                    case 2:
                        files = _b.sent();
                        fileDetails = [];
                        console.log("🚀 ~ VagaReportsChannel ~ handleRequest ~ files:", files);
                        for (_i = 0, files_1 = files; _i < files_1.length; _i++) {
                            file = files_1[_i];
                            filePath = path.join(reportFolder, file);
                            parts = file.split('_');
                            console.log("🚀 ~ VagaReportsChannel ~ handleRequest ~ filePath:", filePath);
                            if (parts.length === 3) { // Assicurati che ci siano 4 parti (compresa l'estensione)
                                filename = parts[0];
                                date = parts[1];
                                statusAndExtension = parts[2];
                                _a = statusAndExtension.split('.'), status_1 = _a[0], extension = _a[1];
                                // Aggiungi l'oggetto al risultato dell'array
                                fileDetails.push({
                                    filepath: filePath,
                                    date: date,
                                    status: status_1,
                                    filename: filename,
                                    extension: extension
                                });
                            }
                        }
                        console.log("🚀 ~ VagaReportsChannel ~ handleRequest ~ fileDetails:", fileDetails);
                        return [2 /*return*/, fileDetails];
                    case 3:
                        err_1 = _b.sent();
                        console.error('Error reading directory:', err_1);
                        return [2 /*return*/, []]; // Ritorna un array vuoto in caso di errore
                    case 4: return [2 /*return*/];
                }
            });
        });
    };
    return VagaReportsChannel;
}());
exports.VagaReportsChannel = VagaReportsChannel;
//# sourceMappingURL=VerificationHandlers.js.map