"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var dikeClients_1 = require("../dikeClients");
var flows_1 = require("@ice/dike-core-js/lib/types/flows");
var logger_1 = require("../logger");
var logger = logger_1.provideLogger('WebSignatureHandlers');
var WebSignatureSendCertsChannel = /** @class */ (function () {
    function WebSignatureSendCertsChannel() {
    }
    WebSignatureSendCertsChannel.prototype.handleRequest = function (body) {
        logger.info("Received message: %s", logger_1.safeJsonStringify(body));
        var params = {
            certificate_id: body.certificateId,
            certificate_content: body.certificateContent,
            reader_index: body.readerIdx,
        };
        return dikeClients_1.DikeClients.getInstance().webServer.webSignFlow.send(flows_1.FlowEvent.DGS_EVT_CERT_PARAMS_INSERTED, params);
    };
    return WebSignatureSendCertsChannel;
}());
exports.WebSignatureSendCertsChannel = WebSignatureSendCertsChannel;
var WebSignatureSendAuthChannel = /** @class */ (function () {
    function WebSignatureSendAuthChannel() {
    }
    WebSignatureSendAuthChannel.prototype.handleRequest = function (body) {
        logger.info("Sending authentication params: %s", logger_1.safeJsonStringify(body));
        var data = {
            authenticator: flows_1.SignAuthenticator[body.authenticator],
            pin: body.pin,
        };
        return dikeClients_1.DikeClients.getInstance().webServer.webSignFlow.send(flows_1.FlowEvent.DGS_EVT_AUTH_PARAMS_INSERTED, data);
    };
    return WebSignatureSendAuthChannel;
}());
exports.WebSignatureSendAuthChannel = WebSignatureSendAuthChannel;
var WebSignatureConfirmChannel = /** @class */ (function () {
    function WebSignatureConfirmChannel() {
    }
    WebSignatureConfirmChannel.prototype.handleRequest = function (body) {
        logger.info("Sending confirm %s", logger_1.safeJsonStringify(body));
        return dikeClients_1.DikeClients.getInstance().webServer.webSignFlow.send(flows_1.FlowEvent.DGS_EVT_WEBSIGN_CONFIRM);
    };
    return WebSignatureConfirmChannel;
}());
exports.WebSignatureConfirmChannel = WebSignatureConfirmChannel;
var WebSignatureStartSigningChannel = /** @class */ (function () {
    function WebSignatureStartSigningChannel() {
    }
    WebSignatureStartSigningChannel.prototype.handleRequest = function (body) {
        logger.info("Start signing %s", logger_1.safeJsonStringify(body));
        return dikeClients_1.DikeClients.getInstance().webServer.webSignFlow.send(flows_1.FlowEvent.DGS_EVT_START_SIGN);
    };
    return WebSignatureStartSigningChannel;
}());
exports.WebSignatureStartSigningChannel = WebSignatureStartSigningChannel;
var WebSignatureOtpSend = /** @class */ (function () {
    function WebSignatureOtpSend() {
    }
    WebSignatureOtpSend.prototype.handleRequest = function (body) {
        logger.info("Sending OTP");
        return dikeClients_1.DikeClients.getInstance().webServer.webSignFlow.send(flows_1.FlowEvent.DGS_EVT_OTP_INSERTED, { otp: body });
    };
    return WebSignatureOtpSend;
}());
exports.WebSignatureOtpSend = WebSignatureOtpSend;
var WebSignaturePollAuthorization = /** @class */ (function () {
    function WebSignaturePollAuthorization() {
    }
    WebSignaturePollAuthorization.prototype.handleRequest = function (body) {
        logger.info("Polling authorization");
        var webSignFlow = dikeClients_1.DikeClients.getInstance().webServer.webSignFlow;
        return webSignFlow.send(flows_1.FlowEvent.DGS_EVT_POLL_AUTHORIZATION).then(function () { return ({}); });
    };
    return WebSignaturePollAuthorization;
}());
exports.WebSignaturePollAuthorization = WebSignaturePollAuthorization;
var WebSignatureResendSms = /** @class */ (function () {
    function WebSignatureResendSms() {
    }
    WebSignatureResendSms.prototype.handleRequest = function (body) {
        logger.info("Resend SMS");
        var webSignFlow = dikeClients_1.DikeClients.getInstance().webServer.webSignFlow;
        return webSignFlow.send(flows_1.FlowEvent.DGS_EVT_RESEND_OTP).then(function () { return ({}); });
    };
    return WebSignatureResendSms;
}());
exports.WebSignatureResendSms = WebSignatureResendSms;
var WebSignatureAbort = /** @class */ (function () {
    function WebSignatureAbort() {
    }
    WebSignatureAbort.prototype.handleRequest = function (body) {
        var webSignFlow = dikeClients_1.DikeClients.getInstance().webServer.webSignFlow;
        return webSignFlow.abort().then(function () { return ({}); });
    };
    return WebSignatureAbort;
}());
exports.WebSignatureAbort = WebSignatureAbort;
var SetWebServerStatus = /** @class */ (function () {
    function SetWebServerStatus() {
    }
    SetWebServerStatus.prototype.handleRequest = function (started) {
        var instance = dikeClients_1.DikeClients.getInstance();
        return started ? instance.webServer.start() : instance.webServer.stop();
    };
    return SetWebServerStatus;
}());
exports.SetWebServerStatus = SetWebServerStatus;
//# sourceMappingURL=WebSignatureHandlers.js.map