"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var electron_1 = require("electron");
var operators_1 = require("rxjs/operators");
var assert = require('assert');
var IpcEndpoint = /** @class */ (function () {
    function IpcEndpoint(originalArg) {
        this.original = originalArg;
    }
    IpcEndpoint.prototype.handle = function (eventArg, requestArg) {
        var request = requestArg;
        var event = eventArg;
        return this.original.handleRequest(requestArg.body)
            .then(function (response) { return event.sender.send(request.responseChannel, response); })
            .catch(function (error) { return event.sender.send(request.responseChannel, {
            error: __assign(__assign({}, error), { code: error.code, message: error.message })
        }); });
    };
    return IpcEndpoint;
}());
exports.IpcEndpoint = IpcEndpoint;
var IpcRegistry = /** @class */ (function () {
    function IpcRegistry() {
        this.channels = new Map();
    }
    Object.defineProperty(IpcRegistry, "Instance", {
        get: function () {
            return this.instance || (this.instance = new this());
        },
        enumerable: true,
        configurable: true
    });
    IpcRegistry.prototype.register = function (s, c) {
        console.log("Registering channel " + s);
        if (this.hasDuplicate(s)) {
            console.log("Found duplicate channel " + s + ", skipping...");
            return this;
        }
        var channel = new IpcEndpoint(c);
        this.channels.set(s, channel);
        electron_1.ipcMain.on(s, function (event, args) {
            channel.handle(event, args);
        });
        return this;
    };
    IpcRegistry.prototype.bindObservable = function (queueChannelName, endpoint, browserWindowResolver) {
        assert.ok(endpoint);
        assert.ok(queueChannelName);
        console.log("Binding observable to channel", queueChannelName);
        if (this.hasDuplicate(queueChannelName)) {
            console.warn("Duplicate channel found: '" + queueChannelName + "' unsubscribing from previously one");
            // destroy previous subscription
            var existing = this.channels.get(queueChannelName);
            existing.removeSubscription();
            electron_1.ipcMain.removeAllListeners(queueChannelName);
        }
        var ipcQueueProducer = new IpcQueueProducer(queueChannelName, endpoint);
        ipcQueueProducer.startSubscription(browserWindowResolver);
        this.channels.set(queueChannelName, ipcQueueProducer);
        return this;
    };
    IpcRegistry.prototype.hasDuplicate = function (s) {
        return this.channels.has(s);
    };
    IpcRegistry.prototype.isSubscribed = function (queueName) {
        var el = this.channels.get(queueName);
        if (!el) {
            return false;
        }
        else {
            return el.isSubscribed();
        }
    };
    return IpcRegistry;
}());
exports.IpcRegistry = IpcRegistry;
var IpcQueueProducer = /** @class */ (function () {
    function IpcQueueProducer(queueChannelName, endpoint) {
        this.sub = null;
        this.queueChannelName = queueChannelName;
        this.endpoint = endpoint;
    }
    IpcQueueProducer.prototype.isSubscribed = function () {
        return this.sub != null && !this.sub.closed;
    };
    IpcQueueProducer.prototype.removeSubscription = function () {
        assert.ok(this.sub);
        return this.sub.unsubscribe();
    };
    IpcQueueProducer.prototype.startSubscription = function (browserWindowResolver) {
        var _this = this;
        var browserWindow = browserWindowResolver();
        assert.ok(browserWindow);
        this.sub = this.endpoint.pipe(operators_1.tap(function (value) { return browserWindow.webContents.send(_this.queueChannelName, value); }), operators_1.finalize(function () { return console.log("Queue " + _this.queueChannelName + " finalized"); })).subscribe();
    };
    return IpcQueueProducer;
}());
exports.IpcQueueProducer = IpcQueueProducer;
//# sourceMappingURL=Ipc.js.map