"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var lodash_1 = require("lodash");
var assert = require('assert');
var path = require('path');
var SignatureDirectoryCreatorImpl = /** @class */ (function () {
    function SignatureDirectoryCreatorImpl(createDirectoryChannel, logger) {
        this.createDirectoryChannel = createDirectoryChannel;
        this.logger = logger;
        this.signatureJobs = ['DEVICE_SIGNATURE', 'DEVICE_SIGNATURE_TS', 'REMOTE_SIGNATURE', 'REMOTE_SIGNATURE_TS'];
    }
    SignatureDirectoryCreatorImpl.prototype.createDir = function (value) {
        var _this = this;
        if (this.signatureJobs.includes(value.jobType)) {
            if (value.payload.type === 'DIRECTORY') {
                var firstElementPath = lodash_1.get(value, 'payload.files[0].path');
                assert.ok(!lodash_1.isNil(firstElementPath), 'Invalid job received');
                var suggestedPath = this.suggestPath(firstElementPath);
                return this.createDirectoryChannel.handleRequest({ path: suggestedPath }).then(function (response) {
                    _this.logger.info("Create path: '%s'", JSON.stringify(response));
                    return lodash_1.set(lodash_1.cloneDeep(value), 'payload.defaultPath', response.path);
                });
            }
        }
        return Promise.resolve(value);
    };
    SignatureDirectoryCreatorImpl.prototype.suggestPath = function (pathStr) {
        try {
            if (!lodash_1.isEmpty(pathStr)) {
                var commonDir = path.parse(pathStr).dir;
                return commonDir + ".signed";
            }
        }
        catch (e) {
            this.logger.warn("Error parsing suggested path from %s", JSON.stringify(pathStr));
        }
        return '';
    };
    return SignatureDirectoryCreatorImpl;
}());
exports.SignatureDirectoryCreatorImpl = SignatureDirectoryCreatorImpl;
//# sourceMappingURL=SignatureDirectoryCreatorImpl.js.map