"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var electron_1 = require("electron");
var lodash_1 = require("lodash");
var env_1 = require("../environments/env");
var ResolvePortableRoot_1 = require("./ResolvePortableRoot");
var fs = require('fs');
var jwt = require('jsonwebtoken');
var path = require('path');
exports.stringPredicate = function (re, flags) { return function (str) { return new RegExp(re, flags).test(str); }; };
function isBk() {
    return lodash_1.isEqual(lodash_1.toUpper(env_1.env.TARGET), 'BK');
}
exports.isBk = isBk;
function isAdmin() {
    return lodash_1.isEqual(lodash_1.toUpper(env_1.env.TARGET), 'ADMIN');
}
exports.isAdmin = isAdmin;
function isSquirrel() {
    return lodash_1.isEqual(lodash_1.toUpper(env_1.env.TARGET), 'SQUIRREL');
}
exports.isSquirrel = isSquirrel;
function loadElectronProfile(p) {
    var bp = "-----BEGIN PUBLIC KEY-----\r\nMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAw/Ek/TGP35s8OgpmnVhl\r\nLGEq+aVrmrYd04Dy62MmHgq6ohLWce2Oorq7W6S31OilSwFi2m5I6XtKmkI8wBTe\r\nLI41lHa1Zx8Ul4l1Dx3IpfdceWVNM/9U1L/1wqiJKU2tKcwqmmEsDMPOsxJQu60d\r\no0DhaMfAnCy8LLUPCDDCPbpk4uug/k3Ca53HsbAC9PCAu0zJWnKY0PNlQwnWKvcd\r\nK3JM3CrNvu+udXRtk1tX1vOtNFmm/XHFQVx1o3tfyA8l6M1SPO9qj5+7gTDncdfW\r\nBfLlC4LQvAn0m0FbVekKXDQXrSnb6DbwVL1ZJKBniipLW9JpQ1eAM5zRvcqNQKPj\r\ndQ0dsGsf5g+Fg5jDaLXE0WhfD+OlQAVqtqKWNeBPvyHLlQOnqyHjsEgkAJc//lEE\r\n4g3WrX/sqtJsmJtxxMoZhq/MRHl4apxo7nBfQ+cXrD26HfwvHSp0pKDb3eQT7kUA\r\nMrxL48LoGYrV/JO/tYk3dWs/CsSfaA3fTLwsbSf9iuYSwe8fV4pWQvA8JeNmFQnV\r\nvjcr2aX+6RgTGjTJq/DUaLa6oJxvT968c4ZEblD2kbWCxI/a3SduAB1ICo09V9Tw\r\nxDDqaLxxm4dDDxgWww0ULIkKtFbc6FgCcRBW8BLPJujTC3xzKZMk6dg0jMEbtMVA\r\nzqbJyCikKUDpbxcAnoF6KfMCAwEAAQ==\r\n-----END PUBLIC KEY-----";
    try {
        var pr = fs.readFileSync(p).toString();
        //console.log(pr);
        var decoded = jwt.verify(pr, bp);
        console.log("Profile verified!");
        return decoded.electronSettings;
    }
    catch (err) {
        console.log("Cannot verify profile: " + err);
        electron_1.app.quit();
        return {
            defaultTSLParameter: 16,
            customization: 'standard',
            canLogin: true,
            bluetooth: false,
            ml: true,
            dike_web: false,
            rsDomainAliasEnabled: false
        };
    }
}
exports.loadElectronProfile = loadElectronProfile;
function getHomeDir(startup, profile, launchArgs) {
    if (startup === void 0) { startup = false; }
    var homeDir = isBk() ? ResolvePortableRoot_1.resolvePortableConfigurationPath() : electron_1.app.getPath('home');
    homeDir = path.join(homeDir, (profile === null || profile === void 0 ? void 0 : profile.customFolder) || '.gosign');
    var customHomeDir = launchArgs === null || launchArgs === void 0 ? void 0 : launchArgs.home;
    if (customHomeDir) {
        if (customHomeDir.startsWith('~') || customHomeDir.startsWith('/') || customHomeDir.startsWith('\\') || customHomeDir[1] === ":") {
            homeDir = customHomeDir;
        }
        else {
            homeDir = path.join(homeDir, customHomeDir || '.gosign');
        }
        if (startup) {
            console.log("getHomeDir Home dir override: with --home=" + (launchArgs === null || launchArgs === void 0 ? void 0 : launchArgs.home), homeDir);
        }
    }
    return homeDir;
}
exports.getHomeDir = getHomeDir;
//# sourceMappingURL=Utils.js.map