"use strict";
// Based on https://github.com/antonfisher/electron-aspect-ratio-browser-window/blob/master/index.js.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var electron_1 = require("electron");
// Winuser.h resizing hook and messages:
// https://docs.microsoft.com/en-us/windows/win32/winmsg/wm-sizing
var WM_SIZING = 0x0214;
var WM_SIZING_MSG = {
    LEFT: 1,
    RIGHT: 2,
    TOP: 3,
    TOPLEFT: 4,
    TOPRIGHT: 5,
    BOTTOM: 6,
    BOTTOMLEFT: 7,
    BOTTOMRIGHT: 8,
};
var AspectRatioDecorator = /** @class */ (function () {
    function AspectRatioDecorator(browserWindow, aspectRatio, aspectRatioExtraSize) {
        AspectRatioDecorator._browserWindow = browserWindow;
        AspectRatioDecorator._aspectRatio = aspectRatio;
        AspectRatioDecorator._aspectRatioExtraSize = aspectRatioExtraSize;
    }
    AspectRatioDecorator.prototype.applyAspectRatio = function () {
        if (process.platform !== 'win32') {
            AspectRatioDecorator._browserWindow.setAspectRatio(AspectRatioDecorator._aspectRatio, AspectRatioDecorator._aspectRatioExtraSize);
        }
        else {
            AspectRatioDecorator._browserWindow.on('will-resize', this.handleWillResize);
            AspectRatioDecorator._browserWindow.hookWindowMessage(WM_SIZING, function (wParam) {
                AspectRatioDecorator._resizeDirection = wParam.readUIntBE(0, 1);
            });
        }
    };
    AspectRatioDecorator.prototype.handleWillResize = function (event, screenBounds) {
        if (!AspectRatioDecorator._aspectRatio || !AspectRatioDecorator._resizeDirection) {
            return;
        }
        event.preventDefault();
        var rawBounds = electron_1.screen.screenToDipRect(AspectRatioDecorator._browserWindow, screenBounds);
        var newBounds = __assign({}, rawBounds);
        var _a = AspectRatioDecorator._browserWindow.getMinimumSize(), minWidth = _a[0], minHeight = _a[1];
        if (newBounds.width < minWidth || newBounds.height < minHeight) {
            return;
        }
        var extraWidth = 0;
        var extraHeight = 0;
        if (AspectRatioDecorator._aspectRatioExtraSize) {
            extraWidth = AspectRatioDecorator._aspectRatioExtraSize.width || 0;
            extraHeight = AspectRatioDecorator._aspectRatioExtraSize.height || 0;
        }
        var getHeightFromWidth = function (width) {
            return Math.max(minHeight, Math.floor((width - extraWidth) / AspectRatioDecorator._aspectRatio + extraHeight));
        };
        var getWidthFromHeight = function (height) {
            return Math.max(minWidth, Math.floor((height - extraHeight) * AspectRatioDecorator._aspectRatio + extraWidth));
        };
        // resize window
        switch (AspectRatioDecorator._resizeDirection) {
            case WM_SIZING_MSG.LEFT:
            case WM_SIZING_MSG.RIGHT:
                newBounds.height = getHeightFromWidth(rawBounds.width);
                break;
            case WM_SIZING_MSG.TOP:
            case WM_SIZING_MSG.BOTTOM:
                newBounds.width = getWidthFromHeight(rawBounds.height);
                break;
            case WM_SIZING_MSG.BOTTOMLEFT:
            case WM_SIZING_MSG.BOTTOMRIGHT:
            case WM_SIZING_MSG.TOPLEFT:
            case WM_SIZING_MSG.TOPRIGHT:
                var widthMagnitude = rawBounds.width * getHeightFromWidth(rawBounds.width);
                var heightMagnitude = rawBounds.height * getWidthFromHeight(rawBounds.height);
                if (widthMagnitude > heightMagnitude) {
                    newBounds.height = getHeightFromWidth(rawBounds.width);
                }
                else {
                    newBounds.width = getWidthFromHeight(rawBounds.height);
                }
                break;
            default:
        }
        // move window
        switch (AspectRatioDecorator._resizeDirection) {
            case WM_SIZING_MSG.TOPLEFT:
                newBounds.x += rawBounds.width - newBounds.width;
                newBounds.y += rawBounds.height - newBounds.height;
                break;
            case WM_SIZING_MSG.TOPRIGHT:
                newBounds.y += rawBounds.height - newBounds.height;
                break;
            case WM_SIZING_MSG.BOTTOMLEFT:
                newBounds.x += rawBounds.width - newBounds.width;
                break;
            default:
        }
        AspectRatioDecorator._browserWindow.setBounds(newBounds);
    };
    AspectRatioDecorator._browserWindow = null;
    AspectRatioDecorator._aspectRatio = null;
    AspectRatioDecorator._aspectRatioExtraSize = null;
    AspectRatioDecorator._resizeDirection = null;
    return AspectRatioDecorator;
}());
exports.default = AspectRatioDecorator;
//# sourceMappingURL=aspectRatioDecorator.js.map