"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var dike_core_js_1 = require("@ice/dike-core-js");
var types_1 = require("@ice/dike-core-js/lib/types");
var Constant_1 = require("@ice/dike-core-js/lib/Constant");
var logger_1 = require("./logger");
var Utils_1 = require("./Utils");
var electron_main_1 = require("../electron.main");
var path = require('path');
var fs = require('fs');
var os = require('os');
// defines whether connect to testing env or production env
exports.isTestingEnv = !!electron_main_1.LAUNCH_ARGS.cl;
exports.isVerbose = !!electron_main_1.LAUNCH_ARGS.verbose;
var liveReload = !!electron_main_1.LAUNCH_ARGS.serve;
var testVersion = !!electron_main_1.LAUNCH_ARGS.test;
var ssl = !!electron_main_1.LAUNCH_ARGS.mtls;
var logger = logger_1.provideLogger('DikeClients');
/**
* Holds dikeclient information
*/
var DikeClients = /** @class */ (function () {
    function DikeClients() {
    }
    DikeClients.getInstance = function () {
        if (DikeClients.instance == null) {
            var libPath = Constant_1.getLibPathFromEnvOrDefault(false).replace('app.asar', 'app.asar.unpacked');
            var profilePath = DikeClients.getPath('current-customization/profile.jwt');
            logger.info("Loading profile from: " + profilePath);
            if (!fs.existsSync(profilePath)) {
                logger.warn("Unable to load the file. File does not exists or is not readable");
            }
            var homePath = Utils_1.getHomeDir(false, electron_main_1.PROFILE, electron_main_1.LAUNCH_ARGS);
            logger.info("Homepath for core library is '%s'", homePath);
            console.log('HOME_PATH:', homePath);
            logger.warn("LIBRARY PATH __dirname IS STILL BROKEN, PLEASE CHECK ISSUE ON GITHUB!!!\n      https://github.com/electron/electron/issues/8206");
            if (exports.isTestingEnv) {
                logger.info('======================= TESTING ENV =======================');
                DikeClients.instance = new dike_core_js_1.default({
                    debug: exports.isVerbose,
                    env: types_1.Envs.DGS_ENV_TEST,
                    libPath: libPath,
                    profile_path: profilePath,
                    homePath: homePath
                });
            }
            else {
                logger.info('======================= PRODUCTION ENV =======================');
                DikeClients.instance = new dike_core_js_1.default({
                    debug: exports.isVerbose,
                    env: types_1.Envs.DGS_ENV_PRODUCTION,
                    libPath: libPath,
                    profile_path: profilePath,
                    homePath: homePath
                });
            }
        }
        return DikeClients.instance;
    };
    DikeClients.getPath = function (arg) {
        if (liveReload || testVersion) {
            return path.join(__dirname, "..", arg);
        }
        else if (['darwin', 'linux'].includes(os.platform())) {
            return path.join(process.resourcesPath, "app", arg);
        }
        else if (os.platform() === 'win32') {
            return path.join(process.resourcesPath, "app.asar.unpacked", arg);
        }
        else {
            return '';
        }
    };
    DikeClients.instance = null;
    return DikeClients;
}());
exports.DikeClients = DikeClients;
//# sourceMappingURL=dikeClients.js.map