"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var electron_log_1 = require("electron-log");
var lodash_1 = require("lodash");
var winston = require("winston");
var electron_main_1 = require("../electron.main");
var Utils_1 = require("./Utils");
var path = require("path");
var default_1 = require("../environments/default");
var fs_extra_1 = require("fs-extra");
var moment = require("moment");
exports.LoggerContainer = new winston.Container();
var verbose = !!electron_main_1.LAUNCH_ARGS.verbose;
var defaultLogLevel = verbose ? 'debug' : 'info';
var fName = lodash_1.get(default_1.environment, 'logFileName', 'electron.log');
var filePath = path.join(Utils_1.getHomeDir(false, electron_main_1.PROFILE, electron_main_1.LAUNCH_ARGS), fName);
// Configura il log su file
electron_log_1.default.transports.file.level = defaultLogLevel;
electron_log_1.default.transports.file.format = '{y}-{m}-{d} {h}:{i}:{s}.{ms} [{level}] {scope} {text}';
electron_log_1.default.transports.file.resolvePath = function () { return filePath; };
//Ruota solo 1 file più vecchio quando il principale raggiunge 10MB
electron_log_1.default.transports.file.maxSize = 1024 * 1024 * 10; //10MB
//LoggerElectron.transports.file.archiveLog = archiveLog;
// Configura il log su console
electron_log_1.default.transports.console.level = defaultLogLevel;
electron_log_1.default.transports.console.format = '{y}-{m}-{d} {h}:{i}:{s}.{ms} [{level}] {scope} {text}';
electron_log_1.default.log('info', 'LoggerElectron initialized');
electron_log_1.default.log("Current log level:", { verbose: verbose, defaultLogLevel: defaultLogLevel });
function provideLogger(name) {
    return electron_log_1.default.scope(name);
}
exports.provideLogger = provideLogger;
/**
 * Safely prints js objects to terminal
 * @param value the value
 * @param _ not used
 * @param space the spaces to be printed
 */
function safeJsonStringify(value, _, space) {
    var blacklist = ['otp', 'pin', 'password', 'oldPin', 'newPin', 'puk'];
    var safeReplacer = function (key, value1) {
        if (blacklist.includes(key)) {
            return '***';
        }
        return value1;
    };
    return JSON.stringify(value, safeReplacer, space);
}
exports.safeJsonStringify = safeJsonStringify;
function handleGuiLog(args) {
    var _a;
    var guiLogger = provideLogger("Gui." + args.source);
    var message = lodash_1.map((_a = args.messages) !== null && _a !== void 0 ? _a : [], function (m) { return (lodash_1.isString(m) ? m : safeJsonStringify(m)); }).join(', ');
    switch (args.level) {
        case 'Error':
            guiLogger.error(message);
            break;
        case 'Warning':
            guiLogger.warn(message);
            break;
        default:
            guiLogger.info(message);
            break;
    }
}
exports.handleGuiLog = handleGuiLog;
exports.setLoggerLevel = function (level) {
    var currentLevel = electron_log_1.default.transports.file.level;
    electron_log_1.default.info("setLoggerLevel current level: " + currentLevel + " => " + level);
    electron_log_1.default.transports.file.level = level;
    electron_log_1.default.transports.console.level = level;
};
function archiveLog(oldLogFile) {
    console.log("🚀 ~ archiveLog ~ oldLogFile:", oldLogFile);
    var file = oldLogFile.path;
    var info = path.parse(file);
    var archiveFileName = info.name + "-" + getLogFileTimestamp() + info.ext;
    try {
        // Copia il file di log esistente in un nuovo file
        fs_extra_1.copyFileSync(file, path.join(info.dir, archiveFileName));
        // Sovrascrivi il file di log esistente con un nuovo file vuoto
        //writeFileSync(file, '');
        electron_log_1.default.info('Log file is archived as:', archiveFileName);
    }
    catch (e) {
        electron_log_1.default.warn('Could not archive log:', e);
    }
}
var getLogFileTimestamp = function () {
    var now = moment();
    return now.format('YYYYMMDD-HHmmss');
};
//# sourceMappingURL=logger.js.map