"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var lodash_1 = require("lodash");
var flows_1 = require("@ice/dike-core-js/lib/types/flows");
var DikeError = /** @class */ (function () {
    function DikeError(codeArg, messageArg) {
        this.code = codeArg;
        this.message = messageArg;
    }
    DikeError.of = function (result, message) {
        return new DikeError(result, message);
    };
    return DikeError;
}());
exports.DikeError = DikeError;
function mapToDecryptParamsInserted(body) {
    var isString = function (p) { return lodash_1.isEqual(p, 'TEXT'); };
    var isFile = function (p) { return lodash_1.isEqual(p, 'FILE_CERT'); };
    var isP12 = function (p) { return lodash_1.isEqual(p, 'P12_CERT'); };
    var isSmartCard = function (p) { return lodash_1.isEqual(p, 'SMART_CARD_CERT'); };
    var method = lodash_1.cond([
        [isString, lodash_1.constant(flows_1.EncryptionMethod.DGS_CRYPT_METHOD_STRING)],
        [isFile, lodash_1.constant(flows_1.EncryptionMethod.DGS_CRYPT_METHOD_FILE)],
        [isP12, lodash_1.constant(flows_1.EncryptionMethod.DGS_CRYPT_METHOD_P12)],
        [isSmartCard, lodash_1.constant(flows_1.EncryptionMethod.DGS_CRYPT_METHOD_SC)],
    ])(body.format);
    var algorithm = lodash_1.cond([
        [function (a) { return lodash_1.isEqual(a, 'AES_GCM'); }, lodash_1.constant(flows_1.EncryptionAlgorithm.DGS_CRYPT_ALGORITHM_AESGCM)],
        [function (a) { return lodash_1.isEqual(a, '3DES'); }, lodash_1.constant(flows_1.EncryptionAlgorithm.DGS_CRYPT_ALGORITHM_3DES)],
        [function (a) { return lodash_1.isEqual(a, 'AES'); }, lodash_1.constant(flows_1.EncryptionAlgorithm.DGS_CRYPT_ALGORITHM_AESCBC)],
        [function (a) { return lodash_1.isEqual(a, 'BLOW_FISH'); }, lodash_1.constant(flows_1.EncryptionAlgorithm.DGS_CRYPT_ALGORITHM_BLOWFISH)],
        [function (a) { return lodash_1.isEqual(a, 'DES'); }, lodash_1.constant(flows_1.EncryptionAlgorithm.DGS_CRYPT_ALGORITHM_DES)],
    ])(body.algotithm);
    return {
        algorithm: algorithm,
        certpath: body.certPath,
        files: body.files.map(function (value) { return ({
            input_file: value.inputPath,
            output_file: value.outputPath,
        }); }),
        method: method,
        p12path: body.p12Path,
        pin: body.pin,
        reader_index: Number(body.readerIndex),
        keypath: body.keyPath,
    };
}
exports.mapToDecryptParamsInserted = mapToDecryptParamsInserted;
//# sourceMappingURL=index.js.map