"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var electron_1 = require("electron");
var logger_1 = require("../logger");
var model_1 = require("../model");
var DikeErrors_1 = require("../shared/DikeErrors");
var NotificationService = /** @class */ (function () {
    function NotificationService(i18n, logger) {
        if (logger === void 0) { logger = logger_1.provideLogger(NotificationService.name); }
        this.i18n = i18n;
        this.logger = logger;
        // TODO: check if it is only for debug
        electron_1.app.setAppUserModelId(process.execPath);
        this.logger.info('Initializing notification service');
    }
    NotificationService.prototype.send = function (args) {
        var _this = this;
        this.logger.info("Showing notification message %s", JSON.stringify(args));
        return new Promise(function (resolve, reject) {
            try {
                var options = {
                    title: _this.i18n.__(args.title),
                    body: _this.i18n.__(args.content, args.parameters),
                };
                new electron_1.Notification(options).show();
                resolve(args);
            }
            catch (e) {
                _this.logger.error('Error ', e);
                reject(model_1.DikeError.of(DikeErrors_1.DikeErrors.CANNOT_SEND_NOTIFICATION, JSON.stringify(e)));
            }
        });
    };
    return NotificationService;
}());
exports.NotificationService = NotificationService;
//# sourceMappingURL=NotificationService.js.map