"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var request_1 = require("./shared/request");
var flows_1 = require("@ice/dike-core-js/lib/types/flows");
var path = require("path");
var RequestService = /** @class */ (function () {
    function RequestService() {
    }
    RequestService.validateRequest = function (request) {
        var _this = this;
        return Promise.all(request.files.map(function (file) {
            return _this.replaceFolderWithFilePath(request.files.length > 1, file, request.signFormat, request.pkgFormat).then(function (replaced) {
                if (replaced.overWriteStatus === 'UNKNOWN') {
                    return _this.testFileExistenceAndIsWritable(replaced);
                }
                else {
                    return Promise.resolve(replaced);
                }
            });
        })).then(function (value) {
            var request1 = request_1.updateCoreSignatureBatchRequestFiles(request, value);
            if (value.some(function (value1) { return value1.overWriteStatus === 'FILE_EXISTS'; })) {
                request1 = request_1.updateRequestStatus(request1, 'ASK_USER');
                return request1;
            }
            return request_1.updateRequestStatus(request1, 'VALID');
        });
    };
    RequestService.testFileExistenceAndIsWritable = function (file) {
        return new Promise(function (resolve) {
            fs.access(file.output, fs.constants.F_OK | fs.constants.W_OK, function (err) {
                if (err) {
                    if (err.code === 'ENOENT') {
                        resolve(request_1.updateCoreSigningFileStatus(file, 'CREATE'));
                    }
                    else {
                        resolve(request_1.updateCoreSigningFileStatus(file, 'WRITE_ERROR'));
                    }
                }
                else {
                    resolve(request_1.updateCoreSigningFileStatus(file, 'FILE_EXISTS'));
                }
            });
        });
    };
    RequestService.replaceFolderWithFilePath = function (multiple, file, operation, pkgFormat) {
        var _this = this;
        return new Promise(function (resolve) {
            fs.lstat(file.output, function (err, stats) {
                if (err) {
                    if (err.code === 'ENOENT' && multiple) {
                        //Output is directory and it does not exist
                        fs.mkdir(file.output, { recursive: true }, function (err) {
                            if (err) {
                                return resolve(file);
                            }
                            return resolve(request_1.updateCoreSigningFileOutputName(file, _this.generateFileName(file.input, operation, pkgFormat, file.output, multiple)));
                        });
                    }
                    else {
                        return resolve(file);
                    }
                }
                else if (stats) {
                    if (stats.isDirectory()) {
                        return resolve(request_1.updateCoreSigningFileOutputName(file, _this.generateFileName(file.input, operation, pkgFormat, file.output, multiple)));
                    }
                    else {
                        return resolve(file);
                    }
                }
                else {
                    return resolve(file);
                }
            });
        });
    };
    RequestService.generateFileName = function (input, operation, pkgFormat, folderPath, multiple) {
        if (multiple === void 0) { multiple = false; }
        var fileName = path.basename(input);
        var ext = path.extname(input);
        var newFileName = fileName;
        switch (operation) {
            case flows_1.SignFormat.DGS_SIGN_TYPE_CADES:
                if (pkgFormat === flows_1.SignPackagingFormat.DGS_SIGN_PKG_DETACHED) {
                    if (ext !== '.p7s') {
                        newFileName = fileName + '.p7s';
                    }
                }
                else {
                    if (ext !== '.p7m') {
                        newFileName = fileName + '.p7m';
                    }
                }
                break;
        }
        return path.normalize(path.format({
            dir: folderPath,
            base: newFileName,
        }));
    };
    RequestService.parseRequest = function (body) {
        return Promise.resolve(body);
    };
    RequestService.parseResults = function (request, signatureResult) {
        var _this = this;
        var arr1 = request.files.reduce(function (previousValue, currentValue, currentIndex) {
            if (currentValue.overWriteStatus !== 'SKIP') {
                return __spreadArrays(previousValue, [currentIndex]);
            }
            return __spreadArrays(previousValue);
        }, []);
        return request_1.updateRequestStatus(request_1.updateCoreSignatureBatchRequestFiles(request, request.files.map(function (value, idx) {
            if (arr1.includes(idx)) {
                return request_1.updateCoreSigningFileOperationStatus(value, _this.mapSignDoneStatus(signatureResult.file_results[arr1.indexOf(idx)]));
            }
            else {
                return request_1.updateCoreSigningFileOperationStatus(value, 'SKIP');
            }
        })), this.mapSignDoneResultStatus(signatureResult.result));
    };
    RequestService.mapSignDoneResultStatus = function (result) {
        switch (result) {
            case flows_1.FlowOperationResult.DGS_OP_ABORTED:
                return 'ABORTED';
            case flows_1.FlowOperationResult.DGS_OP_ALL_OK:
                return 'COMPLETE';
            case flows_1.FlowOperationResult.DGS_OP_KO:
                return 'ERROR';
            case flows_1.FlowOperationResult.DGS_OP_PARTIAL_OK:
                return 'PARTIAL_OK';
            default:
                return 'ERROR';
        }
    };
    RequestService.mapSignDoneStatus = function (errorCode) {
        if (errorCode >= 0) {
            return 'SUCCESS';
        }
        else {
            return 'FAILED';
        }
    };
    return RequestService;
}());
exports.default = RequestService;
//# sourceMappingURL=requestService.js.map