"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var certificatechronology_1 = require("@ice/dike-core-js/lib/types/certificatechronology");
var flows_1 = require("@ice/dike-core-js/lib/types/flows");
var date_fns_1 = require("date-fns");
var lodash_1 = require("lodash");
var default_1 = require("../../../environments/default");
var CoreSetConfigurationRequest = /** @class */ (function () {
    function CoreSetConfigurationRequest() {
    }
    return CoreSetConfigurationRequest;
}());
exports.CoreSetConfigurationRequest = CoreSetConfigurationRequest;
/**
 * Remote Signature Credentials
 */
var RSCredentials = /** @class */ (function () {
    function RSCredentials(username, password, jwt, service) {
        this.username = username;
        this.password = password;
        this.jwt = jwt;
        this.service = service;
    }
    RSCredentials.of = function (username, password, jwt, service) {
        if (username === void 0) { username = ''; }
        if (password === void 0) { password = ''; }
        if (jwt === void 0) { jwt = ''; }
        return new RSCredentials(username, password, jwt, service);
    };
    return RSCredentials;
}());
exports.RSCredentials = RSCredentials;
function updateRequestStatus(request, status) {
    var newRequest = lodash_1.cloneDeep(request);
    newRequest.status = status;
    return newRequest;
}
exports.updateRequestStatus = updateRequestStatus;
function updateCoreSigningFileStatus(file, status) {
    var signingFile = lodash_1.cloneDeep(file);
    signingFile.overWriteStatus = status;
    return signingFile;
}
exports.updateCoreSigningFileStatus = updateCoreSigningFileStatus;
function updateCoreSigningFilePadesParams(file, params) {
    var signingFile = lodash_1.cloneDeep(file);
    signingFile.padesParams = params;
    return signingFile;
}
exports.updateCoreSigningFilePadesParams = updateCoreSigningFilePadesParams;
function updateCoreSigningFileOutputName(file, output) {
    var signingFile = lodash_1.cloneDeep(file);
    signingFile.output = output;
    return signingFile;
}
exports.updateCoreSigningFileOutputName = updateCoreSigningFileOutputName;
function updateCoreSignatureBatchRequestFiles(request, value) {
    var coreFileSignatureBatchRequest = lodash_1.cloneDeep(request);
    coreFileSignatureBatchRequest.files = value;
    return coreFileSignatureBatchRequest;
}
exports.updateCoreSignatureBatchRequestFiles = updateCoreSignatureBatchRequestFiles;
function updateCoreSignatureBatchRequestPin(request, value) {
    var coreFileSignatureBatchRequest = lodash_1.cloneDeep(request);
    coreFileSignatureBatchRequest.pin = value;
    return coreFileSignatureBatchRequest;
}
exports.updateCoreSignatureBatchRequestPin = updateCoreSignatureBatchRequestPin;
function mapToSignatureParametersInserted(body, purgeSkippedFiles) {
    if (purgeSkippedFiles === void 0) { purgeSkippedFiles = false; }
    var files = purgeSkippedFiles ? body.files.filter(function (value) { return value.overWriteStatus === 'SKIP'; }) : body.files;
    return {
        certificate_id: body.certificate_id,
        counter: body.counter,
        files: files.map(mapToSigningFile),
        language: body.language,
        ltv: body.ltv,
        pin: body.pin,
        pkgFormat: body.pkgFormat,
        selected_reader: body.selected_reader,
        signFormat: body.signFormat,
        timestamp: body.timestamp,
        coupon: body.coupon,
        certificate: body.certificate,
        oauth_token: body.oauth_token,
        correlation_id: body.correlation_id,
        session_id: body.session_id,
        identifier: body.identifier
    };
}
exports.mapToSignatureParametersInserted = mapToSignatureParametersInserted;
function mapToSigningFile(file) {
    var result = {
        cadesParams: lodash_1.cloneDeep(file.cadesParams) || undefined,
        input: file.input,
        output: file.output,
        padesParams: lodash_1.cloneDeep(file.padesParams),
        signerInfoCertificate: file.signerInfoCertificate,
        signingTime: file.signingTime,
        xadesAddSignTime: file.xadesAddSignTime,
        xadesSignatureId: file.xadesSignatureId,
    };
    return result;
}
exports.mapToSigningFile = mapToSigningFile;
function isValidForSignature(body) {
    return body.status === 'VALID';
}
exports.isValidForSignature = isValidForSignature;
function updateCoreSigningFileOperationStatus(file, status) {
    var signingFile = lodash_1.cloneDeep(file);
    signingFile.operationStatus = status;
    return signingFile;
}
exports.updateCoreSigningFileOperationStatus = updateCoreSigningFileOperationStatus;
function printRequest(request) {
    console.log(JSON.stringify(request, function (k, v) { return (k.match(/pin/i) ? '********' : v); }));
}
exports.printRequest = printRequest;
function flatMapWaitDetachedSources(detachedSources) {
    var detachedSignatures = mapToCoreDetachedSources(detachedSources.detached_signs, 'SIGNATURE');
    var detachedTimestamps = mapToCoreDetachedSources(detachedSources.detached_timestamps, 'TIMESTAMP');
    return { sources: detachedSignatures.concat(detachedTimestamps) };
}
exports.flatMapWaitDetachedSources = flatMapWaitDetachedSources;
function mapToCoreDetachedSources(detachedSources, type) {
    return detachedSources.map(function (sourcePath) {
        return { inputFilePath: sourcePath, detachedFilePath: '', type: type };
    });
}
function mapToVerifyDetachedSources(detachedSources) {
    return {
        detached_signs: mapToVerifyDetachedPairs(detachedSources.sources, 'SIGNATURE'),
        detached_timestamps: mapToVerifyDetachedPairs(detachedSources.sources, 'TIMESTAMP'),
    };
}
exports.mapToVerifyDetachedSources = mapToVerifyDetachedSources;
function mapToVerifyDetachedPairs(detachedPairs, type) {
    return detachedPairs
        .filter(function (pair) { return pair.type === type; })
        .map(function (pair) {
        return {
            input_file: pair.inputFilePath,
            data_file: pair.detachedFilePath,
        };
    });
}
function mapFromCoreTimestampFormat(timestampFormat) {
    switch (timestampFormat) {
        case 'TSD':
            return flows_1.TimestampFormat.DGS_TIMESTAMP_TSD;
        case 'M7M':
            return flows_1.TimestampFormat.DGS_TIMESTAMP_M7M;
        case 'TSR':
            return flows_1.TimestampFormat.DGS_TIMESTAMP_TSR;
    }
}
exports.mapFromCoreTimestampFormat = mapFromCoreTimestampFormat;
function mapToTimestampParamsInserted(request) {
    return {
        files: request.files
            .filter(function (file) { return file.overWriteStatus !== 'SKIP'; })
            .map(function (file) {
            return {
                input_file: file.inputPath,
                output_file: file.outputPath,
            };
        }),
        format: mapFromCoreTimestampFormat(request.timestampFormat),
    };
}
exports.mapToTimestampParamsInserted = mapToTimestampParamsInserted;
function updateCoreFileTimestampRequestFiles(request, files) {
    var updatedRequest = lodash_1.cloneDeep(request);
    updatedRequest.files = files;
    return updatedRequest;
}
exports.updateCoreFileTimestampRequestFiles = updateCoreFileTimestampRequestFiles;
function updateCoreFileTimestampRequestStatus(request, status, errorCode) {
    var updatedRequest = lodash_1.cloneDeep(request);
    updatedRequest.status = status;
    if (errorCode) {
        updatedRequest.errorCode = errorCode;
    }
    return updatedRequest;
}
exports.updateCoreFileTimestampRequestStatus = updateCoreFileTimestampRequestStatus;
function updateCoreTimestampFileOverWriteStatus(file, status) {
    var updatedFile = lodash_1.cloneDeep(file);
    updatedFile.overWriteStatus = status;
    return updatedFile;
}
exports.updateCoreTimestampFileOverWriteStatus = updateCoreTimestampFileOverWriteStatus;
function updateCoreTimestampFileOutputPath(file, outputPath) {
    var updatedFile = lodash_1.cloneDeep(file);
    updatedFile.outputPath = outputPath;
    return updatedFile;
}
exports.updateCoreTimestampFileOutputPath = updateCoreTimestampFileOutputPath;
function toCoreProgressStatus(currentItem, total) {
    return { currentItem: currentItem, total: total, progressPercentage: Math.ceil((currentItem / total) * 100) };
}
exports.toCoreProgressStatus = toCoreProgressStatus;
function updateCoreAssociateFilesRequestFile(request, file) {
    var updatedRequest = lodash_1.cloneDeep(request);
    updatedRequest.file = file;
    return updatedRequest;
}
exports.updateCoreAssociateFilesRequestFile = updateCoreAssociateFilesRequestFile;
function updateCoreAssociateFilesRequestStatus(request, status, errorCode) {
    var updatedRequest = lodash_1.cloneDeep(request);
    updatedRequest.status = status;
    if (errorCode) {
        updatedRequest.errorCode = errorCode;
    }
    return updatedRequest;
}
exports.updateCoreAssociateFilesRequestStatus = updateCoreAssociateFilesRequestStatus;
function updateCoreSeparateFilesRequestFile(request, file) {
    var updatedRequest = lodash_1.cloneDeep(request);
    updatedRequest.file = file;
    return updatedRequest;
}
exports.updateCoreSeparateFilesRequestFile = updateCoreSeparateFilesRequestFile;
function updateCoreSeparateFilesRequestStatus(request, status, errorCode) {
    var updatedRequest = lodash_1.cloneDeep(request);
    updatedRequest.status = status;
    if (errorCode) {
        updatedRequest.errorCode = errorCode;
    }
    return updatedRequest;
}
exports.updateCoreSeparateFilesRequestStatus = updateCoreSeparateFilesRequestStatus;
function mapToEncryptParamsInserted(request) {
    var type = request.type;
    return {
        files: request.files
            .filter(function (file) { return file.overWriteStatus !== 'SKIP'; })
            .map(function (file) {
            return {
                input_file: file.inputPath,
                output_file: request.isOutputArchive ? '' : file.outputPath,
            };
        }),
        method: mapFromCoreEncipherType(type),
        algorithm: mapFromCoreEncipherAlgorithm(request.algorithm),
        output_zip: !request.isOutputArchive ? '' : request.outputLocation,
        pin: mapToEncipherPin(request),
        p12path: request.p12Data.certPath,
        certpath: request.fileData.certPath,
        reader_index: Number(request.smartCardData.deviceIndex),
        certificateID: request.smartCardData.certificateId,
    };
}
exports.mapToEncryptParamsInserted = mapToEncryptParamsInserted;
function mapToEncipherPin(request) {
    var type = request.type;
    switch (type) {
        case 'TEXT':
            return request.textData.password;
        case 'P12_CERT':
            return request.p12Data.password;
        default:
            return '';
    }
}
function mapFromCoreEncipherType(encipherType) {
    switch (encipherType) {
        case 'TEXT':
            return flows_1.EncryptionMethod.DGS_CRYPT_METHOD_STRING;
        case 'SMART_CARD_CERT':
            return flows_1.EncryptionMethod.DGS_CRYPT_METHOD_SC;
        case 'P12_CERT':
            return flows_1.EncryptionMethod.DGS_CRYPT_METHOD_P12;
        case 'FILE_CERT':
            return flows_1.EncryptionMethod.DGS_CRYPT_METHOD_FILE;
    }
}
exports.mapFromCoreEncipherType = mapFromCoreEncipherType;
function mapFromCoreEncipherAlgorithm(algorithm) {
    switch (algorithm) {
        case 'AES':
            return flows_1.EncryptionAlgorithm.DGS_CRYPT_ALGORITHM_AESCBC;
        case '3DES':
            return flows_1.EncryptionAlgorithm.DGS_CRYPT_ALGORITHM_3DES;
        case 'BLOW_FISH':
            return flows_1.EncryptionAlgorithm.DGS_CRYPT_ALGORITHM_BLOWFISH;
    }
}
exports.mapFromCoreEncipherAlgorithm = mapFromCoreEncipherAlgorithm;
var CoreCertificateData = /** @class */ (function () {
    function CoreCertificateData() {
    }
    CoreCertificateData.fromCertificateData = function (value1) {
        var expDate = date_fns_1.parse(value1.expdate, 'yyyyMMdd', new Date());
        return {
            certid: value1.certid,
            expdate: date_fns_1.formatISO(expDate),
            pem: value1.pem,
            subjectCN: value1.subjectCN,
            type: value1.type,
            usedcount: value1.usedcount || 0,
            renewstatus: certificatechronology_1.RenewStatus[value1.renewstatus],
            status: this.computeStatus(value1, expDate),
        };
    };
    CoreCertificateData.computeStatus = function (value1, expDate) {
        var delta = date_fns_1.differenceInDays(expDate, new Date());
        if (delta < 0) {
            // scaduto
            if ([
                certificatechronology_1.RenewStatus.DGS_CERT_RENEW_STATUS_ON_CART,
                certificatechronology_1.RenewStatus.DGS_CERT_RENEW_STATUS_ORDER_CREATED,
                certificatechronology_1.RenewStatus.DGS_CERT_RENEW_STATUS_RENEW_ENABLED,
                certificatechronology_1.RenewStatus.DGS_CERT_RENEW_STATUS_CERT_GENERATED,
                certificatechronology_1.RenewStatus.DGS_CERT_RENEW_STATUS_CERT_DOWNLOADED,
            ].includes(value1.renewstatus) &&
                delta > -default_1.environment.certificatePostExpirationRenewValidityDays) {
                // rinnovo in corso
                return 'EXPIRING';
            }
            else {
                return 'EXPIRED';
            }
        }
        else {
            // non scaduto
            if (delta < default_1.environment.certificateExpirationAlertDays) {
                return 'EXPIRING';
            }
            else {
                return 'VALID';
            }
        }
    };
    return CoreCertificateData;
}());
exports.CoreCertificateData = CoreCertificateData;
var DecipherFileDesc = /** @class */ (function () {
    function DecipherFileDesc() {
    }
    return DecipherFileDesc;
}());
//# sourceMappingURL=index.js.map