"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path = require("path");
var request_1 = require("./shared/request");
var TimestampRequestService = /** @class */ (function () {
    function TimestampRequestService() {
    }
    TimestampRequestService.validateRequest = function (request) {
        var _this = this;
        return Promise.all(request.files.map(function (file) {
            return _this.replaceFolderWithFilePath(file, request.timestampFormat).then(function (updatedFile) {
                return updatedFile.overWriteStatus === 'UNKNOWN' ?
                    _this.testFileExistenceAndIsWritable(updatedFile) :
                    Promise.resolve(updatedFile);
            });
        })).then(function (updatedFiles) {
            var updatedRequest = request_1.updateCoreFileTimestampRequestFiles(request, updatedFiles);
            return updatedFiles.some(function (file) { return file.overWriteStatus === 'FILE_EXISTS'; }) ?
                request_1.updateCoreFileTimestampRequestStatus(updatedRequest, 'ASK_USER') :
                request_1.updateCoreFileTimestampRequestStatus(updatedRequest, 'VALID');
        });
    };
    TimestampRequestService.validateAssociateRequest = function (request) {
        var _this = this;
        return Promise.resolve(this.replaceFolderWithFilePath(request.file, request.associateFormat).then(function (updatedFile) {
            return updatedFile.overWriteStatus === 'UNKNOWN' ?
                _this.testFileExistenceAndIsWritable(updatedFile) :
                Promise.resolve(updatedFile);
        })).then(function (updatedFile) {
            var updatedRequest = request_1.updateCoreAssociateFilesRequestFile(request, updatedFile);
            return updatedFile.overWriteStatus === 'FILE_EXISTS' ?
                request_1.updateCoreAssociateFilesRequestStatus(updatedRequest, 'ASK_USER') :
                request_1.updateCoreAssociateFilesRequestStatus(updatedRequest, 'VALID');
        });
    };
    TimestampRequestService.testFileExistenceAndIsWritable = function (file) {
        return new Promise(function (resolve) {
            fs.access(file.outputPath, fs.constants.F_OK | fs.constants.W_OK, function (err) {
                if (err) {
                    if (err.code === 'ENOENT') {
                        resolve(request_1.updateCoreTimestampFileOverWriteStatus(file, 'CREATE'));
                    }
                    else {
                        resolve(request_1.updateCoreTimestampFileOverWriteStatus(file, 'WRITE_ERROR'));
                    }
                }
                else {
                    resolve(request_1.updateCoreTimestampFileOverWriteStatus(file, 'FILE_EXISTS'));
                }
            });
        });
    };
    TimestampRequestService.replaceFolderWithFilePath = function (file, format) {
        var _this = this;
        return new Promise(function (resolve) {
            fs.lstat(file.outputPath, function (err, stats) {
                if (err) {
                    resolve(file);
                }
                if (stats) {
                    if (stats.isDirectory()) {
                        var outputPath = _this.generateFileName(file.inputPath, format, file.outputPath);
                        resolve(request_1.updateCoreTimestampFileOutputPath(file, outputPath));
                    }
                    else {
                        resolve(file);
                    }
                }
            });
        });
    };
    TimestampRequestService.generateFileName = function (filePath, format, folderPath) {
        var fileName = path.basename(filePath);
        return path.normalize(path.format({
            dir: folderPath,
            base: this.appendFileExtenstion(fileName, format)
        }));
    };
    TimestampRequestService.appendFileExtenstion = function (fileName, format) {
        switch (format) {
            case 'TSD':
                return fileName + '.tsd';
            case 'M7M':
                return fileName + '.m7m';
            case 'TSR':
                return fileName + '.tsr';
        }
    };
    return TimestampRequestService;
}());
exports.default = TimestampRequestService;
//# sourceMappingURL=timestampRequestService.js.map