"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var electron_1 = require("electron");
var operators_1 = require("rxjs/operators");
var url = require("url");
var path = require("path");
var i18n = require('i18n');
var TrayService = /** @class */ (function () {
    function TrayService(mainWindow, routingService, configurationHandler, lifeCycleService) {
        var _this = this;
        this.mainWindow = mainWindow;
        this.routingService = routingService;
        this.configurationHandler = configurationHandler;
        this.lifeCycleService = lifeCycleService;
        this.tray = new electron_1.Tray(TrayService.iconPath);
        this.buildMenu();
        this.hideOnExit();
        configurationHandler.events.pipe(operators_1.tap(function (configuration) {
            if (configuration.user.DisableMinToTray) {
                _this.quitOnExit();
            }
            //Update menu
            _this.buildMenu();
        })).subscribe();
    }
    TrayService.prototype.init = function () {
        var _this = this;
        // Quit when all windows are closed.
        electron_1.app.on('window-all-closed', function () { return __awaiter(_this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                this.destroy();
                this.lifeCycleService.quitCoreAndElectron();
                return [2 /*return*/];
            });
        }); });
    };
    TrayService.prototype.buildMenu = function () {
        var _this = this;
        console.log('Building menu..');
        this.openMenuItem = new electron_1.MenuItem({
            label: i18n.__('open'),
            click: function () {
                console.log('show');
                _this.mainWindow.show();
            },
        });
        this.closeMenuItem = new electron_1.MenuItem({
            label: i18n.__('close'),
            click: function () {
                console.log('destroy');
                _this.mainWindow.destroy();
            },
        });
        this.renewMenuItem = new electron_1.MenuItem({
            label: i18n.__('renew'),
            click: function () {
                console.log('renew');
                _this.mainWindow.show();
                _this.routingService.openRenewPage();
            },
        });
        this.aboutMenuItem = new electron_1.MenuItem({
            label: i18n.__('about'),
            click: function () {
                console.log('about');
                _this.mainWindow.show();
                _this.routingService.openAboutPage();
            },
        });
        this.helpMenuItem = new electron_1.MenuItem({
            label: i18n.__('help'),
            click: function () {
                electron_1.shell.openExternal(i18n.__('menuHelpUrl'));
            },
        });
        this.menu = new electron_1.Menu();
        this.menu.append(this.openMenuItem);
        this.menu.append(this.renewMenuItem);
        this.menu.append(this.helpMenuItem);
        this.menu.append(this.aboutMenuItem);
        this.menu.append(this.closeMenuItem);
        this.tray.setContextMenu(this.menu);
        this.tray.on('click', function () {
            _this.tray.popUpContextMenu();
        });
        console.log('Menu build complete');
    };
    TrayService.prototype.hideOnExit = function () {
        var _this = this;
        this.mainWindow.removeAllListeners('close');
        if (process.platform === 'darwin') {
            var forceQuit = false;
            electron_1.app.on('before-quit', function () {
                forceQuit = true;
            });
            this.mainWindow.on('close', function (event) { return __awaiter(_this, void 0, void 0, function () {
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            event.preventDefault();
                            if (!!forceQuit) return [3 /*break*/, 1];
                            this.mainWindow.hide();
                            return [3 /*break*/, 3];
                        case 1:
                            this.destroy();
                            return [4 /*yield*/, this.lifeCycleService.quitCoreAndElectron()];
                        case 2:
                            _a.sent();
                            _a.label = 3;
                        case 3: return [2 /*return*/];
                    }
                });
            }); });
        }
        else {
            this.mainWindow.on('close', function (event) {
                event.preventDefault();
                _this.mainWindow.hide();
            });
        }
    };
    TrayService.prototype.quitOnExit = function () {
        var _this = this;
        this.mainWindow.removeAllListeners('close');
        this.mainWindow.on('close', function (event) { return __awaiter(_this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        event.preventDefault();
                        this.destroy();
                        return [4 /*yield*/, this.lifeCycleService.quitCoreAndElectron()];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        }); });
    };
    TrayService.prototype.destroy = function () {
        console.log("Destroying tray...");
        this.tray.destroy();
    };
    TrayService.iconPath = url.format({
        pathname: path.join(__dirname, process.platform === 'win32' ? '../resources/win/icon.ico' : '../resources/mac/icon.png'),
    });
    return TrayService;
}());
exports.TrayService = TrayService;
//# sourceMappingURL=trayService.js.map