const gulp = require('gulp');
const log = require('fancy-log');
const Package = require('./package.json');
const exec = require('gulp-exec');
const path = require('path');
const wixmsi = require('./scripts/wixmsi');
const st = require('./scripts/signtool');
const fs = require('file-system');
const cp = require('child_process');
const git = require('gulp-git');
const util = require('util');
const jwt = require('jsonwebtoken');
const lodash = require('lodash');
const osSuffix = (() => {
  switch (process.platform) {
    case 'win32':
      return 'win';
    case 'darwin':
      return 'osx';
    case 'linux':
      return 'linux';
    default:
      return '';
  }
})();

const ARGS = ((argList) => {
  let arg = {},
    a,
    opt,
    thisOpt,
    curOpt;
  for (a = 0; a < argList.length; a++) {
    thisOpt = argList[a].trim();
    opt = thisOpt.replace(/^\-+/, '');
    if (opt === thisOpt) {
      // argument value
      if (curOpt) arg[curOpt] = opt;
      curOpt = null;
    } else {
      // argument name
      curOpt = opt;
      arg[curOpt] = true;
    }
  }
  return arg;
})(process.argv);

console.info('++++++ ARGS', ARGS);

//Se è il primo giro di setConf per resettarlo a STANDARD
let CONF_RESET = false;
//Parametro c (customization)
if (ARGS.c === undefined || ARGS.c === true || ARGS.c === 'null') {
  ARGS.c = 'standard';
  CONF_RESET = true;
}
console.info('++++++ CONF_RESET', CONF_RESET);

var CUSTOMIZATION = ARGS.c;
var CUSTOMIZATION_PATH = './customizations/' + CUSTOMIZATION;

if (!fs.existsSync(CUSTOMIZATION_PATH)) {
  throw new Error(`ERROR : Customization folder ${CUSTOMIZATION_PATH} does NOT exist!`);
} else {
  console.log(`Found Customization ${CUSTOMIZATION} into ${CUSTOMIZATION_PATH} processing.. `);
}

//Parametro t (target)
if (ARGS.t === undefined || ARGS.t === true || ARGS.t === 'null') {
  ARGS.t = 'standard';
}

var msi_user_filename = '';
var exe_squirrel_filename = '';
var msi_admin_filename = '';
var installer_exe_basename = '';
var dmg_filename = '';
var deb_filename = '';
var versionstring = '';
var customization = '';

var sleep = async function (ms) {
  return new Promise((resolve) => setTimeout(resolve, ms));
};

gulp.task('signProfile', async function () {
  var customizationProfile = require('./current-customization/profile.json');
  customizationProfile.coreSettings.target = ARGS.t.toUpperCase();
  var key = fs.readFileSync('./customizations/priv.key');
  var token = jwt.sign(customizationProfile, key, {
    algorithm: 'RS256',
  });
  return fs.writeFile('./current-customization/profile.jwt', token);
});

gulp.task('copyProfile', async function () {
  /** TODO:
   * Prendere il profile.json della standard,
   * e poi quello della personalizzazione (se c'è),
   * poi effettuare un merge della sezione electronSettings/modules
   * usando standard come default e sovrascrivendo solo
   * le chiavi impostate nella personalizzazione
   */

  return new Promise((resolve, reject) => {
    if (!CONF_RESET) {
      //Se non è il primo giro di setConf per resettare a STANRDARD
      //Prendo il profile.json che sarà la standard
      var standardProfile = require('./customizations/standard/profile.json');
      //Prendo il profile.json della personalizzazione
      var customProfile = require(CUSTOMIZATION_PATH + '/profile.json');
      //console.log("🚀 ~ returnnewPromise ~ customProfile:", customProfile)
      //Effettuo un merge della sezione electronSettings/modules
      var mergedModules = lodash.mergeWith({}, standardProfile.electronSettings.modules, customProfile
        .electronSettings.modules || {}, (objValue, srcValue) => {
          //preserva i valori false
          if (srcValue === false) {
            return srcValue;
          }
        });

      //Effettuo un merge del profile.json della personalizzazione
      var customMergedProfile = {
        ...customProfile,
        electronSettings: {
          ...customProfile.electronSettings,
          modules: mergedModules
        }
      };
      //se non esistono le chiavi le prendo dalla standard
      if (!customMergedProfile.urls) {
        customMergedProfile.urls = standardProfile.urls;
      }
      if (!customMergedProfile.coreSettings) {
        customMergedProfile.coreSettings = standardProfile.coreSettings;
      }
      if (!customMergedProfile.certs) {
        customMergedProfile.certs = standardProfile.certs;
      }

      console.log('customMergedProfile electronSettings', customMergedProfile.electronSettings);
      //scrivo il file
      const copied = fs.writeFileSync('./current-customization/profile.json', JSON.stringify(
        customMergedProfile, null, 2));

      resolve(copied);
    } else {
      gulp
        .src(CUSTOMIZATION_PATH + '/profile.json')
        .pipe(gulp.dest('./current-customization/'))
        .on('finish', resolve)
        .on('error', reject);
    }
  });
});

gulp.task('overrideVersionNumber', async function (cb) {
  await sleep(1000);
  const profile_electron = require('./current-customization/profile.json').electronSettings;
  //Se non è il primo giro di setConf per resettare a STANRDARD ed esiste un override di versione
  if (!CONF_RESET && profile_electron.version && profile_electron.version !== Package.version) {
    console.log(`Version number overridden to ${profile_electron.version}`);
    //override package.json version number writing file
    Package.version = profile_electron.version;
    fs.writeFileSync('./package.json', JSON.stringify(Package, null, 2));
  } else {
    console.log(`Version number default to existing package.json ${Package.version}`);
  }
  cb();
});

gulp.task('copyTSL', () =>
  gulp.src([CUSTOMIZATION_PATH + '/default-tsl/*']).pipe(gulp.dest('./current-customization/default-tsl/'))
);

gulp.task('copyDrivers', () =>
  gulp.src([CUSTOMIZATION_PATH + '/drivers/**/*']).pipe(gulp.dest('./current-customization/drivers'))
);

gulp.task('copyInstaller', () => gulp.src(CUSTOMIZATION_PATH + '/installers/**/*').pipe(gulp.dest('./installers')));

gulp.task('copyResources', () => {
  console.log('copyResources icons');
  return gulp.src(CUSTOMIZATION_PATH + '/resources/**/*').pipe(gulp.dest('./resources'));
});

gulp.task('copyCSS', (cb) => {
  var customScss = CUSTOMIZATION_PATH + '/custom.scss';
  console.log('🚀 ~ gulp.task ~ customScss:', customScss);
  if (fs.existsSync(customScss)) {
    return gulp.src(customScss).pipe(gulp.dest('./application/src/'));
  } else {
    console.log(`File ${customScss} does NOT exist skipped`);
    cb();
  }
});

gulp.task('copyAssets', () =>
  gulp.src(CUSTOMIZATION_PATH + '/assets/**/*').pipe(gulp.dest('./application/src/assets'))
);

gulp.task('copyTheme', (cb) => {
  var themeFile = CUSTOMIZATION_PATH + '/theme/theme-variables.scss';
  if (fs.existsSync(themeFile)) {
    return gulp.src(themeFile).pipe(gulp.dest('./application/src/theme/'));
  } else {
    console.log(`File ${themeFile} does NOT exist skipped`);
    cb();
  }
});

gulp.task('copyATRini', (cb) => {
  var customATRini = CUSTOMIZATION_PATH + '/ATR.ini';
  if (fs.existsSync(customATRini)) {
    return gulp
      .src(customATRini)
      .pipe(gulp.dest('./node_modules/@ice/dike-core-js/node_modules/@ice/dike-core-' + osSuffix + '/native/'));
  } else {
    console.log(`File ${customATRini} does NOT exist skipped`);
    cb();
  }
});

gulp.task('copyReportXSLT', (cb) => {
  var customReportXSLT = CUSTOMIZATION_PATH + '/htmltransform.xslt';
  if (fs.existsSync(customReportXSLT)) {
    return gulp
      .src(customReportXSLT)
      .pipe(gulp.dest('./node_modules/@ice/dike-core-js/node_modules/@ice/dike-core-' + osSuffix +
        '/native/design/'));
  } else {
    console.log(`File ${customReportXSLT} does NOT exist skipped`);
    cb();
  }
});

gulp.task('copySignatureBackgrounds', (cb) => {
  var bgFolder = CUSTOMIZATION_PATH + '/backgrounds';
  if (fs.existsSync(bgFolder)) {
    return gulp.src(bgFolder + '/**/*').pipe(gulp.dest('./current-customization/backgrounds'));
  } else {
    console.log(`Folder ${bgFolder} does NOT exist skipped`);
    cb();
  }
});

gulp.task(
  'setConf',
  gulp.series(
    /* Cancellare le directories current-customization, installers, application/src/assets SOLO SE ARGS.c == 'standard' */
    'copyProfile',
    'overrideVersionNumber',
    'signProfile',
    'copyATRini',
    'copyReportXSLT',
    'copyTSL',
    'copyDrivers',
    'copyInstaller',
    'copyCSS',
    'copyAssets',
    'copyTheme',
    'copySignatureBackgrounds',
    'copyResources'
  )
);

// Task per MSI create

gulp.task('setOutputFilenames', async function () {
  const profile_electron = require('./current-customization/profile.json').electronSettings;
  customization = profile_electron.customization;

  const gitexec = util.promisify(git.exec);

  // git rev-parse --abbrev-ref HEAD

  return gitexec({
      args: 'rev-parse --short HEAD',
    })
    .then((stdout) => {
      const pkgOpts = require('./installers/packager-properties.json');
      const commitid = stdout.trim();

      if (!commitid) throw new Error('git rev-parse output is empty');

      // The substituted value will be contained in the result variable
      versionstring = `${Package.version}-${commitid}`;
      msi_user_filename = `${pkgOpts.executableName}-${customization}-${versionstring}.msi`;
      exe_squirrel_filename = `${pkgOpts.executableName}-Setup.exe`;
      msi_admin_filename = `${pkgOpts.executableName}-admin-${customization}-${versionstring}.msi`;
      installer_exe_basename = `${pkgOpts.executableName}-${customization}-${versionstring}`;
      installer_exe_admin_basename = `${pkgOpts.executableName}-admin-${customization}-${versionstring}`;
      dmg_filename = `${pkgOpts.executableName}-${customization}-${versionstring}`;
      deb_filename = `${pkgOpts.executableName}-${customization}-${versionstring}`;

      console.log(`Set msi_user_filename=${msi_user_filename}`);
      console.log(`Set exe_squirrel_filename=${exe_squirrel_filename}`);
      console.log(`Set msi_admin_filename=${msi_admin_filename}`);
      console.log(`Set installer_exe_basename=${installer_exe_basename}`);
      console.log(`Set installer_exe_admin_basename=${installer_exe_admin_basename}`);
      console.log(`Set dmg_filename=${dmg_filename}`);
      console.log(`Set deb_filename=${deb_filename}`);
      console.log(`Set versionstring=${versionstring}`);

      return true;
    })
    .catch((err) => {
      throw err;
    });
});

gulp.task('notarizeMacBinaries', async function () {
  const pkgOpts = require('./installers/packager-properties.json');
  const notarize = require('./scripts/notarize');
  const appPath = path.join(
    __dirname,
    'dist.packages',
    pkgOpts.escapedName + '-darwin-x64',
    pkgOpts.escapedName + '.app'
  );

  return notarize.notarizeApp(appPath);
});

gulp.task('signWinBinaries', async function () {
  var glob = require('glob');
  const pkgOpts = require('./installers/packager-properties.json');
  // Where GoSignDesktop.exe is
  var binpath = ARGS.binpath;
  if (!binpath) binpath = path.join(__dirname, 'dist.packages', pkgOpts.name + '-win32-ia32');
  console.log('Binpath: ', binpath);

  await new Promise((resolve, reject) => {
    var files2sign = [];
    glob(
      binpath + '/**/*.dll', {
        ignore: [
          binpath +
          '/resources/app.asar.unpacked/node_modules/@ice/dike-core-js/node_modules/@ice/dike-core-win/native/dll-alpha.dll',
        ],
      },
      function (err, flist) {
        if (err) reject(err);

        files2sign = files2sign.concat(flist);

        glob(binpath + '/**/*.exe', async function (err, flist) {
          if (err) reject(err);

          files2sign = files2sign.concat(flist);
          if (files2sign.length == 0) resolve();

          for (const element of files2sign) {
            await sleep(500); // to avoid throttle from timestamp server
            await st.signfile(element);
          }
          resolve();
        });
      }
    );
  });
});

gulp.task('signWinBinaries64', async function () {
  var glob = require('glob');
  const pkgOpts = require('./installers/packager-properties.json');
  // Where GoSignDesktop.exe is
  var binpath = ARGS.binpath;
  if (!binpath) binpath = path.join(__dirname, 'dist.packages', pkgOpts.name + '-win32-x64');
  console.log('Binpath: ', binpath);

  await new Promise((resolve, reject) => {
    var files2sign = [];
    glob(
      binpath + '/**/*.dll', {
        ignore: [
          binpath +
          '/resources/app.asar.unpacked/node_modules/@ice/dike-core-js/node_modules/@ice/dike-core-win64/native/dll-alpha.dll',
        ],
      },
      function (err, flist) {
        if (err) reject(err);

        files2sign = files2sign.concat(flist);

        glob(binpath + '/**/*.exe', async function (err, flist) {
          if (err) reject(err);

          files2sign = files2sign.concat(flist);
          if (files2sign.length == 0) resolve();

          for (const element of files2sign) {
            await sleep(500); // to avoid throttle from timestamp server
            await st.signfile(element);
          }
          resolve();
        });
      }
    );
  });
});

gulp.task('buildUserMsi', async function () {
  const pkgOpts = require('./installers/packager-properties.json');
  // Where GoSignDesktop.exe is
  var binpath = ARGS.binpath;
  if (!binpath) binpath = path.join(__dirname, 'dist.packages', pkgOpts.name + '-win32-ia32/');
  console.log('Binpath: ', binpath);

  const profile_installer = require('./installers/installer-properties.json');

  var msi_output_user = path.join(__dirname, 'dist.packages', msi_user_filename);

  console.log('Outfile: ', msi_output_user);
  console.log('Language: ', profile_installer.culture);

  const installer_basedir = path.join(__dirname, './installers/windows/wixmsi/');
  const wxs_user = ['common.wxs', 'product-user.wxs'];

  await wixmsi.create_msi(
    binpath,
    installer_basedir,
    Package.version,
    msi_output_user,
    wxs_user,
    profile_installer.culture
  );

  await sleep(2000);

  await st.signfile(msi_output_user);
});

gulp.task('buildSquirrelExe', async function () {
  const profile_electron = require('./current-customization/profile.json').electronSettings;
  customization = profile_electron.customization;
  const pkgOpts = require('./installers/packager-properties.json');
  const squirrel = require('./scripts/squirrel');
  // Where GoSignDesktop.exe is
  var binpath = ARGS.binpath;
  if (!binpath) binpath = path.join(__dirname, 'dist.packages', pkgOpts.name + '-win32-ia32/');

  console.log('Binpath: ', binpath);

  var pkg_output_user = path.join(__dirname, 'dist.packages', 'win32');

  console.log('Outdir: ', pkg_output_user);

  var pkg_outputfile_user = path.join(pkg_output_user, exe_squirrel_filename);

  console.log('Outfile: ', pkg_outputfile_user);

  await squirrel.create_squirrel_pkg(
    binpath,
    exe_squirrel_filename,
    pkgOpts.escapedName,
    pkgOpts.executableName,
    pkgOpts.description,
    pkg_output_user,
    `https://d2nu8i0ja8i6qk.cloudfront.net/gosign/updates/${profile_electron.customization}/`,
    `https://d2nu8i0ja8i6qk.cloudfront.net/gosign/${profile_electron.customization}/icon.png`
  );

  await sleep(2000);

  await st.signfile(pkg_outputfile_user);
});

gulp.task('buildAdminMsi', async function () {
  const pkgOpts = require('./installers/packager-properties.json');
  // Where GoSignDesktop.exe is
  var binpath = ARGS.binpath;
  if (!binpath) binpath = path.join(__dirname, 'dist.packages', pkgOpts.name + '-win32-ia32/');

  console.log('Binpath: ', binpath);

  var msi_output_admin = path.join(__dirname, 'dist.packages', msi_admin_filename);
  const profile_installer = require('./installers/installer-properties.json');

  console.log('Outfile: ', msi_output_admin);
  console.log('Language: ', profile_installer.culture);

  const installer_basedir = path.join(__dirname, './installers/windows/wixmsi/');
  const wxs_admin = ['common.wxs', 'product-admin.wxs'];

  await wixmsi.create_msi(
    binpath,
    installer_basedir,
    Package.version,
    msi_output_admin,
    wxs_admin,
    profile_installer.culture
  );

  await sleep(2000);

  await st.signfile(msi_output_admin);
});

gulp.task('copyMsiIntoUpdater', async () => {
  return fs.copyFile(`dist.packages/${msi_user_filename}`,
    './installers/windows/updater/GoSignUpdater/msi/dike.msi');
});

gulp.task('copySquirrelIntoUpdater', async () => {
  return fs.copyFile(
    `dist.packages/win32/${exe_squirrel_filename}`,
    './installers/windows/squirrel/GoSignUpdater/exe/app.exe'
  );
});

gulp.task('buildUserExe', async function () {
  var output_dir = path.join(__dirname, `dist.packages/`);
  var outfile = path.join(output_dir, installer_exe_basename + '.exe');

  await new Promise((resolve, reject) => {
    fs.copyFileSync(
      './installers/windows/updater/GoSignUpdater/App.config.usr',
      './installers/windows/updater/GoSignUpdater/App.config'
    );

    var cmd = `build.cmd ${Package.version} ${output_dir} ${installer_exe_basename}`;
    cp.exec(
      cmd, {
        cwd: './installers/windows/updater/',
      },
      async function (err, stdout, stderr) {
        if (err) {
          console.log(stdout);
          console.log(stderr);
          console.log(err);
          reject(err);
        } else {
          resolve();
        }
      }
    );
  });

  await sleep(2000);

  await st.signfile(outfile);
});

gulp.task('buildSquirrelUpdaterExe', async function () {
  var output_dir = path.join(__dirname, `dist.packages/`);
  var outfile = path.join(output_dir, installer_exe_basename + '.exe');

  await new Promise(async (resolve, reject) => {
    fs.copyFileSync(
      './installers/windows/squirrel/GoSignUpdater/App.config.usr',
      './installers/windows/squirrel/GoSignUpdater/App.config'
    );

    var cmd = `build.cmd ${Package.version} ${output_dir} ${installer_exe_basename}`;
    cp.exec(
      cmd, {
        cwd: './installers/windows/squirrel/',
      },
      async function (err, stdout, stderr) {
        if (err) {
          console.log(stdout);
          console.log(stderr);
          console.log(err);
          reject(err);
        } else {
          resolve();
        }
      }
    );
  });

  await sleep(2000);

  await st.signfile(outfile);
});

gulp.task('copyAdminMsiIntoUpdater', async () => {
  return fs.copyFile(`dist.packages/${msi_admin_filename}`,
    './installers/windows/updater/GoSignUpdater/msi/dike.msi');
});

gulp.task('buildAdminExe', async function () {
  var output_dir = path.join(__dirname, `dist.packages/`);
  var outfile = path.join(output_dir, installer_exe_admin_basename + '.exe');

  await new Promise((resolve, reject) => {
    fs.copyFileSync(
      './installers/windows/updater/GoSignUpdater/App.config.adm',
      './installers/windows/updater/GoSignUpdater/App.config'
    );

    var cmd = `build.cmd ${Package.version} ${output_dir} ${installer_exe_admin_basename}`;
    cp.exec(
      cmd, {
        cwd: './installers/windows/updater/',
      },
      async function (err, stdout, stderr) {
        if (err) {
          console.log(stdout);
          console.log(stderr);
          console.log(err);
          reject(err);
        } else {
          resolve();
        }
      }
    );
  });

  await sleep(2000);

  await st.signfile(outfile);
});

gulp.task('buildDmg', async function () {
  const pkgOpts = require('./installers/packager-properties.json');
  const dmg = require('./scripts/dmg');
  const out = path.join(__dirname, 'dist.packages');
  const appPath = path.join(
    __dirname,
    'dist.packages',
    pkgOpts.escapedName + '-darwin-x64',
    pkgOpts.escapedName + '.app'
  );
  const background = path.join(__dirname, 'installers/mac/installer_background.png');
  const icon = path.join(__dirname, 'installers/mac/installer_icon.png');
  var outfile = path.join('dist.packages', dmg_filename);

  await dmg.create_dmg(out, background, icon, appPath, outfile);
});

gulp.task('buildZip', async function () {
  const zip = require('./scripts/zip');
  const pkgOpts = require('./installers/packager-properties.json');
  const out = path.join(__dirname, 'dist.packages', dmg_filename + '.zip');
  const appPath = path.join(
    __dirname,
    'dist.packages',
    pkgOpts.escapedName + '-darwin-x64',
    pkgOpts.escapedName + '.app'
  );

  await zip.create_zip(appPath, out);
});

gulp.task('buildDeb', async function () {
  const pkgOpts = require('./installers/packager-properties.json');
  const deb = require('./scripts/deb');
  const out = path.join(__dirname, 'dist.packages');
  const app = path.join(__dirname, 'dist.packages', pkgOpts.escapedName + '-linux-x64');
  const icon = path.join(__dirname, 'installers/linux/installer_icon.png');

  await deb.create_deb(out, icon, app);
});

gulp.task(
  'buildSquirrelWindowsInstaller',
  gulp.series(
    'setOutputFilenames',
    'signWinBinaries',
    'buildSquirrelExe',
    'copySquirrelIntoUpdater',
    'buildSquirrelUpdaterExe'
  )
);

gulp.task(
  'buildUserWindowsInstaller',
  gulp.series('setOutputFilenames', 'signWinBinaries', 'buildUserMsi', 'copyMsiIntoUpdater', 'buildUserExe')
);

gulp.task(
  'buildAdminWindowsInstaller',
  gulp.series('setOutputFilenames', 'signWinBinaries', 'buildAdminMsi', 'copyAdminMsiIntoUpdater', 'buildAdminExe')
);

gulp.task('buildAllMacInstaller', gulp.series('setOutputFilenames', 'buildDmg', 'buildZip'));
gulp.task('buildAllLinuxInstaller', gulp.series('setOutputFilenames', 'buildDeb'));
