"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLibName = exports.getLibPathFromEnvOrDefault = exports.Platform = exports.AssetsDir = exports.HomeDir = void 0;
var os_1 = require("os");
var path = require("path");
var fs = require("fs");
var dotenv = require('dotenv');
var slash = require('slash');
exports.HomeDir = slash((0, os_1.homedir)() + "/.gosign");
exports.AssetsDir = slash((0, os_1.homedir)() + "/userdata");
dotenv.config();
//@ts-ignore
exports.Platform = (0, os_1.type)();
//console.log("Platform", Platform, "arch", process.arch);
var getLibPathFromEnvOrDefault = function (debug) {
    if (debug === void 0) { debug = false; }
    var LibPath = "";
    if (debug)
        console.log("Platform", exports.Platform);
    var dikeModulePath = checkDikeModuleInstalledPath(debug);
    if (dikeModulePath) {
        return dikeModulePath;
    }
    switch (exports.Platform) {
        //Mac
        case "Darwin":
            LibPath = process.env.DIKE_LIB_PATH_OSX || "";
            break;
        //Windows
        case "Windows_NT":
            LibPath = process.env.DIKE_LIB_PATH_WINDOWS || "";
            break;
        //Linux
        case "Linux":
            LibPath = process.env.DIKE_LIB_PATH_LINUX || "";
            break;
    }
    if (!LibPath)
        throw new Error("Missing native libpath! install " + getNativeModuleByPlatform() + " package or put a ENV variable");
    if (debug)
        console.log("getDeafaultLibPath Platform", exports.Platform, "DIKE_LIB_PATH", LibPath);
    return slash(LibPath);
};
exports.getLibPathFromEnvOrDefault = getLibPathFromEnvOrDefault;
var getLibName = function (debug) {
    if (debug === void 0) { debug = false; }
    var LibName = "";
    switch (exports.Platform) {
        //Mac
        case "Darwin":
            LibName = "libdgsapi";
            break;
        //Windows
        case "Windows_NT":
            LibName = "dgsapi1.dll";
            break;
        //Linux
        case "Linux":
            LibName = "libdgsapi";
            break;
    }
    if (debug)
        console.log("getLibName Platform", exports.Platform, "LibName", LibName);
    return LibName;
};
exports.getLibName = getLibName;
// checks if module is available to load
var checkDikeModuleInstalledPath = function (debug) {
    if (debug === void 0) { debug = false; }
    var nativeModuleLib = getNativeModuleByPlatform();
    var dikeApiModulePath = slash(path.join(process.cwd(), "node_modules/@ice/dike-core-js/node_modules/", nativeModuleLib));
    // const electronDikeApiModulePath = slash(path.join(process.cwd(), "/resources/app/node_modules/@ice/dike-core-js/node_modules/", nativeModuleLib));
    var electronDikeApiModulePath = slash(path.join(path.dirname(__dirname), "/node_modules/", nativeModuleLib));
    if (debug)
        console.log("isModuleAvailableSync -> dikeApiModulePath", dikeApiModulePath);
    if (fs.existsSync(dikeApiModulePath) === true) {
        if (debug)
            console.log("dikeApiModule found", dikeApiModulePath);
        var dike_api_path = require(dikeApiModulePath);
        if (debug)
            console.log("dike_api_path", dike_api_path);
        return (dike_api_path === null || dike_api_path === void 0 ? void 0 : dike_api_path.default) || false;
    }
    else if (fs.existsSync(electronDikeApiModulePath) === true) {
        if (debug)
            console.log("electronDikeApiModulePath found", electronDikeApiModulePath);
        var dike_api_path = require(electronDikeApiModulePath);
        if (debug)
            console.log("electronDikeApiModulePath", dike_api_path);
        return (dike_api_path === null || dike_api_path === void 0 ? void 0 : dike_api_path.default) || false;
    }
    else {
        if (debug)
            console.log("dikeApiModule NOT installed");
        return false;
    }
};
var getNativeModuleByPlatform = function () {
    var nativeModuleLib;
    switch (exports.Platform) {
        //Mac
        case "Darwin":
            nativeModuleLib = "@ice/dike-core-osx";
            break;
        //Windows
        case "Windows_NT":
            var arch = process.arch == 'x64' ? "64" : "";
            nativeModuleLib = "@ice/dike-core-win" + arch;
            break;
        //Linux
        case "Linux":
            nativeModuleLib = "@ice/dike-core-linux";
            break;
    }
    console.log("Native module: " + nativeModuleLib, process.arch);
    return nativeModuleLib;
};
//# sourceMappingURL=Constant.js.map