"use strict";
/**@hidden */
//const exitHook = require('async-exit-hook');
//import * as ffi from "ffi-napi"; //"@lwahonen/ffi-napi";
//import * as ref from "ref-napi"; //"@lwahonen/ref-napi";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
Object.defineProperty(exports, "__esModule", { value: true });
var ffi, ref;
try {
    ffi = require('@lwahonen/ffi-napi');
    ref = require('@lwahonen/ref-napi');
    console.log("Using @lwahonen ");
}
catch (err) {
    ffi = require('ffi-napi');
    ref = require('ref-napi');
    console.log("Using @ffi-napi ");
}
var Constant_1 = require("./Constant");
var FlowProcess_1 = require("./FlowProcess");
var Helpers_1 = require("./Helpers");
var Logger_1 = require("./Logger");
var Methods_1 = require("./Methods");
var PipeServerr_1 = require("./PipeServerr");
//import { resolve } from 'bluebird';
var Scheduler_1 = require("./Scheduler");
var types_1 = require("./types");
var error_codes_1 = require("./types/error_codes");
var flows_1 = require("./types/flows");
var WebServer_1 = require("./WebServer");
var slash = require('slash');
var fs = require('fs');
var jwt = require('jsonwebtoken');
/**  @ignore */
var defaultOptions = {
    homePath: Constant_1.HomeDir,
    userDataDir: Constant_1.AssetsDir,
    profile_path: "",
    debug: false,
    env: 0,
    start_scheduler: true,
};
/**
 * ## DGS_CORE API DOCS
 *
 * Main library Class
 * **All the library methods are asyncs** so they will return a *Promise* object, in order to use them is required to use the async/await or the then/catch pattern;
 * <br> the response promise can be resolved or rejected.
 * <br> the Resolved success (then) response can be a:
 * * A typed return value (like in the method {@link getVersion}, the resolved promise result is a string in this case)
 * * or a generic {@link ApiResult}
 * <br><br> the Rejected error (in the catch) is always a {@link ApiError} object
 */
var DGS_CORE = /** @class */ (function () {
    /**
     *
     * Instantiate the main class
     * @param options optional options object
     *
     */
    function DGS_CORE(options) {
        if (options === void 0) { options = defaultOptions; }
        var _this = this;
        var _a, _b;
        this._homePath = Constant_1.HomeDir;
        this.libPath = (0, Constant_1.getLibPathFromEnvOrDefault)();
        this.debug = false;
        this.start_scheduler = true;
        this.profilePath = "";
        /** The filesystem folder used to store and get application data, sign images etc.. */
        this.assetsFolder = Constant_1.AssetsDir;
        this.getErrorObject = function (errorCode) {
            var message = _this.getErrorMessage(errorCode);
            var error = new Helpers_1.DgsError(message, errorCode);
            return error;
        };
        this.callJsonNative = function (method, params) {
            if (params === void 0) { params = [_this.CORE]; }
            return __awaiter(_this, void 0, void 0, function () {
                var _this = this;
                return __generator(this, function (_a) {
                    //Logger.log("callJsonNative", `${method}`, params)
                    return [2 /*return*/, new Promise(function (resolve, reject) { return __awaiter(_this, void 0, void 0, function () {
                            var json, err_1;
                            return __generator(this, function (_a) {
                                switch (_a.label) {
                                    case 0:
                                        _a.trys.push([0, 2, , 3]);
                                        return [4 /*yield*/, this.read_json_value(method, params)];
                                    case 1:
                                        json = _a.sent();
                                        resolve(json);
                                        return [3 /*break*/, 3];
                                    case 2:
                                        err_1 = _a.sent();
                                        Logger_1.default.error("callJsonNative error", err_1);
                                        reject(err_1);
                                        return [3 /*break*/, 3];
                                    case 3: return [2 /*return*/];
                                }
                            });
                        }); })];
                });
            });
        };
        /**
         *
         * @param method the native method call
         * @param args optionals arguments
         * @returns reponseData response or error object
        */
        this.callNative = function (method) {
            var args = [];
            for (var _i = 1; _i < arguments.length; _i++) {
                args[_i - 1] = arguments[_i];
            }
            return __awaiter(_this, void 0, void 0, function () {
                var _this = this;
                return __generator(this, function (_a) {
                    // Logger.log("callNative", `${method}`, args)
                    return [2 /*return*/, new Promise(function (resolve, reject) { return __awaiter(_this, void 0, void 0, function () {
                            var promised, result, err, message, err_2;
                            return __generator(this, function (_a) {
                                switch (_a.label) {
                                    case 0:
                                        _a.trys.push([0, 2, , 3]);
                                        promised = (0, Helpers_1.Promisify)(method);
                                        return [4 /*yield*/, promised.apply(void 0, args)];
                                    case 1:
                                        result = _a.sent();
                                        //Logger.log("callNative", `${method}`, "result", result)
                                        //se è un int code
                                        if (Number.isInteger(result)) {
                                            if (result !== 0) {
                                                err = this.getErrorObject(result);
                                                throw err;
                                            }
                                            else {
                                                message = this.getErrorMessage(result);
                                                // resolve(message);
                                                resolve((0, Helpers_1.sendSuccess)(message, result));
                                            }
                                        }
                                        //è un messaggio normale
                                        resolve(result);
                                        return [3 /*break*/, 3];
                                    case 2:
                                        err_2 = _a.sent();
                                        // const error: ApiError = {
                                        //   code: 1,
                                        //   message: "dsa",
                                        //   name: "dsa"
                                        // }
                                        // const message = this.getErrorMessage(result);
                                        Logger_1.default.error("callNative error", err_2);
                                        reject(err_2);
                                        return [3 /*break*/, 3];
                                    case 3: return [2 /*return*/];
                                }
                            });
                        }); })];
                });
            });
        };
        this.libPath = options.libPath || (0, Constant_1.getLibPathFromEnvOrDefault)();
        this._homePath = options.homePath || defaultOptions.homePath || "";
        this.debug = options.debug || defaultOptions.debug;
        this.assetsFolder = options.userDataDir || defaultOptions.userDataDir || "";
        this.start_scheduler = (_b = (_a = options.start_scheduler) !== null && _a !== void 0 ? _a : defaultOptions.start_scheduler) !== null && _b !== void 0 ? _b : true;
        this.profilePath = options.profile_path || defaultOptions.profile_path || "";
        //SegfaultHandler.registerHandler(slash(this.homePath + "/core.log"));
        if (this.debug)
            console.log("init Constructor", { libpath: this.libPath, options: options });
        //IF WINDOWS....
        if (Constant_1.Platform === "Windows_NT") {
            var KernelLib = ffi.Library("kernel32", {
                'SetDllDirectoryA': ["bool", ["string"]],
                'SetDllDirectoryW': ["bool", ["string"]]
            });
            //Trasforamre in utf 16 prima di passarlo
            //const libPathUtf16 = Buffer.from(this.libPath, 'utf16le');
            var libPathUtf16 = Buffer.from(this.libPath + "\0", 'utf16le');
            //console.log("libPathUtf16", libPathUtf16);
            var setDIr = KernelLib.SetDllDirectoryW(libPathUtf16);
            //console.log("setDIr", setDIr);
        }
        //END IF WINDOWS
        var fullPath = this.libPath + (0, Constant_1.getLibName)(this.debug);
        if (this.debug)
            console.log("API fullPath", fullPath);
        this.libdgsapi = ffi.Library(fullPath, Methods_1.default);
        this.init(this._homePath, this.libPath, options.env);
    }
    /**
     * Initialize Core lib
     * @param homepath user home path
     * @param atrpath lib path
     * @returns core lib instance
     */
    DGS_CORE.prototype.init = function (homepath, atrpath, env) {
        var _a;
        if (this.debug)
            console.log("init DGSCORE", { libpath: this.libPath, homepath: homepath, atrpath: atrpath });
        Logger_1.default.init(homepath, this.debug);
        this.libdgsapi.dgs_init_statics(homepath);
        this.profile = this.loadElectronProfile(this.profilePath);
        if (!this.profile) {
            console.log("invalid profile", { profilePath: this.profilePath });
            return null;
        }
        this.CORE = this.libdgsapi.dgs_core_init(homepath, atrpath, this.profilePath);
        this.setEnvironment(env);
        this.setDebug((_a = this.debug) !== null && _a !== void 0 ? _a : false);
        this.assetsFolder = (this === null || this === void 0 ? void 0 : this._homePath) + "";
        Logger_1.default.log("_homePath", this._homePath);
        this.getVersion()
            .then(function (version) { return Logger_1.default.log("initialized CORE version ".concat(version)); });
        if (this.start_scheduler) {
            this.initScheduler();
        }
        this.webServer = new WebServer_1.default({
            getDevices: this.getDevices.bind(this),
            flowStart: this.flowStart.bind(this),
            messageSubject: this.MessagesSubject,
            profile: this.profile,
            logger: Logger_1.default
        });
        this.webServer.init().then(function (value) {
            Logger_1.default.log("Started WebServer: ".concat(value));
        });
        //this.onExit();
        this.pipeServer = new PipeServerr_1.default({
            getDevices: this.getDevices.bind(this),
            flowStart: this.flowStart.bind(this),
            messageSubject: this.MessagesSubject,
            profile: this.profile,
            logger: Logger_1.default
        });
        /*this.pipeServer.start().then((value) => {
          Logger.log(`Started PipeServer: ${value}`);
        }).catch((err) => {
          Logger.error(`Error starting PipeServer: ${err}`);
        });*/
        return this.CORE;
    };
    DGS_CORE.prototype.loadElectronProfile = function (p) {
        var bp = "-----BEGIN PUBLIC KEY-----\r\nMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAw/Ek/TGP35s8OgpmnVhl\r\nLGEq+aVrmrYd04Dy62MmHgq6ohLWce2Oorq7W6S31OilSwFi2m5I6XtKmkI8wBTe\r\nLI41lHa1Zx8Ul4l1Dx3IpfdceWVNM/9U1L/1wqiJKU2tKcwqmmEsDMPOsxJQu60d\r\no0DhaMfAnCy8LLUPCDDCPbpk4uug/k3Ca53HsbAC9PCAu0zJWnKY0PNlQwnWKvcd\r\nK3JM3CrNvu+udXRtk1tX1vOtNFmm/XHFQVx1o3tfyA8l6M1SPO9qj5+7gTDncdfW\r\nBfLlC4LQvAn0m0FbVekKXDQXrSnb6DbwVL1ZJKBniipLW9JpQ1eAM5zRvcqNQKPj\r\ndQ0dsGsf5g+Fg5jDaLXE0WhfD+OlQAVqtqKWNeBPvyHLlQOnqyHjsEgkAJc//lEE\r\n4g3WrX/sqtJsmJtxxMoZhq/MRHl4apxo7nBfQ+cXrD26HfwvHSp0pKDb3eQT7kUA\r\nMrxL48LoGYrV/JO/tYk3dWs/CsSfaA3fTLwsbSf9iuYSwe8fV4pWQvA8JeNmFQnV\r\nvjcr2aX+6RgTGjTJq/DUaLa6oJxvT968c4ZEblD2kbWCxI/a3SduAB1ICo09V9Tw\r\nxDDqaLxxm4dDDxgWww0ULIkKtFbc6FgCcRBW8BLPJujTC3xzKZMk6dg0jMEbtMVA\r\nzqbJyCikKUDpbxcAnoF6KfMCAwEAAQ==\r\n-----END PUBLIC KEY-----";
        try {
            var pr = fs.readFileSync(p).toString();
            //console.log(pr);
            var decoded = jwt.verify(pr, bp);
            console.log("Profile verified!");
            return decoded;
        }
        catch (err) {
            console.log("Cannot verify profile: " + err);
            return null;
        }
    };
    Object.defineProperty(DGS_CORE.prototype, "homePath", {
        get: function () {
            return this._homePath;
        },
        enumerable: false,
        configurable: true
    });
    // private onExit() {
    //   exitHook(callback => {
    //     Logger.warn("ON EXIT")
    //     this.quit()
    //     callback();
    //   });
    // }
    DGS_CORE.prototype.quit = function () {
        return __awaiter(this, void 0, void 0, function () {
            var e_1;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        Logger_1.default.log("DGS_CORE -> quit -> quit");
                        _a.label = 1;
                    case 1:
                        _a.trys.push([1, 3, , 4]);
                        return [4 /*yield*/, this.stopMonitor()];
                    case 2:
                        _a.sent();
                        return [3 /*break*/, 4];
                    case 3:
                        e_1 = _a.sent();
                        console.error("error on Exit processes", e_1);
                        return [3 /*break*/, 4];
                    case 4: return [2 /*return*/];
                }
            });
        });
    };
    /**
     * SetDebug true/false
     * @returns the new debug value
     */
    DGS_CORE.prototype.setDebug = function (active) {
        this.debug = Logger_1.default.enabled = active;
        // if (this.debug) {
        //   this.DgsSetLogLevel(LogLevel.DGS_LVL_TRACE);
        // }
        return this.debug;
    };
    DGS_CORE.prototype.DgsSetLogLevel = function (logLevel) {
        if (logLevel === void 0) { logLevel = types_1.LogLevel.DGS_LVL_INFO; }
        this.libdgsapi.dgs_set_log_level(logLevel);
    };
    /**
     * Get the version number
     * @returns the version number
     */
    DGS_CORE.prototype.getVersion = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_core_version)];
            });
        });
    };
    /**
    * @brief setEnvironment set library environment
    * Switch production/testing environment endpoints
    * @param env Envs Selected environment
    */
    DGS_CORE.prototype.setEnvironment = function (env) {
        if (env === void 0) { env = 0; }
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                if (this.debug)
                    Logger_1.default.log("setEnviroment", env, env === 0 ? "PRODUCTION" : "TEST");
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_select_environment, env)];
            });
        });
    };
    /************
    CONFIGURATION METHODS
    ************/
    /**
     * @brief Reload config from ini files
     *
     * @return 0 on success, a non-zero integer otherwise
     */
    DGS_CORE.prototype.reloadConfiguration = function () {
        return this.callJsonNative(this.libdgsapi.dgs_core_reloadcfg);
    };
    /**
    * @brief Get Configuration settings
    * @category Configuration
    * @returns configuration object
    */
    DGS_CORE.prototype.getConfiguration = function () {
        var _this = this;
        return this.callJsonNative(this.libdgsapi.dgs_configuration_get).then(function (config) {
            //Setto il loglevel in base alla configurazione del file ini
            var logLevel = config.user.loglevel.toLowerCase();
            _this.setDebug(logLevel === "trace");
            return config;
        });
    };
    /**
     * Set a new configuration setting
     * @category Configuration
     * @param prop the name of the configuration property to change one of the {@link Configuration} properties
     * @param json the updated json configuration object of type (Configuration[prop])
     * @example ```CORE_INSTANCE.setConfiguration("gui", {language:"en"});```
     */
    DGS_CORE.prototype.setConfiguration = function (prop, json) {
        Logger_1.default.log("setConfiguration", prop, json);
        return this.callNative(this.libdgsapi.dgs_configuration_set, this.CORE, prop, (0, Helpers_1.sendJsonString)(json));
    };
    /************
    DEVICE METHODS
    ************/
    /**
    * @brief Returns a snapshot of current devices and certificates, **need to be called before any other device method !**
    * @category Devices
    * @returns device List object
    */
    DGS_CORE.prototype.getDevices = function (force_rescan) {
        if (force_rescan === void 0) { force_rescan = false; }
        return __awaiter(this, void 0, void 0, function () {
            var rescan;
            return __generator(this, function (_a) {
                rescan = force_rescan ? 1 : 0;
                return [2 /*return*/, this.callJsonNative(this.libdgsapi.dgs_device_snapshot_ext, [this.CORE, 0xff, rescan])];
            });
        });
    };
    /**
   * @brief Tests PIN
   * Tests PIN on selected reader (PUK is needed, PHYSICAL READER ONLY!)
   * <br> **{@link getDevices} needed to be called before**
    * @category Devices
    * @returns Success or Error
    */
    DGS_CORE.prototype.deviceTestPin = function (deviceIndex, pin) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                if (!deviceIndex)
                    (0, Helpers_1.sendError)("no deviceIndex");
                if (!pin)
                    (0, Helpers_1.sendError)("no Pin");
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_test_pin, this.CORE, deviceIndex, pin)];
            });
        });
    };
    /**
     * @brief Sets a new PIN
     * Sets a new PIN for selected smartcard (PHYSICAL READER ONLY)
     * <br> **{@link getDevices} needed to be called before**
     * @param readerIndex readerIndex (MUST be > 0)
     * @param oldPin oldPin, the old pin string
     * @param newPin newPin, the new pin string
     * @category Devices
     */
    DGS_CORE.prototype.deviceChangePin = function (readerIndex, oldPin, newPin) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                if (!oldPin) {
                    (0, Helpers_1.sendError)("no Pin");
                }
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_change_pin, this.CORE, readerIndex, oldPin, newPin)];
            });
        });
    };
    /**
     * Unlock smartcard with PUK, forcing a new PIN
     * (PHYSICAL READER ONLY!)
     * <br> **{@link getDevices} needed to be called before**
     * @category Devices
     * @param reader Reader index (MUST be > 0)
     * @param puk PUK
     * @param pin New PIN
     *
     */
    DGS_CORE.prototype.deviceUnlockPin = function (reader, puk, pin) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                if (!puk) {
                    (0, Helpers_1.sendError)("no Pin");
                }
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_unlock_pin, this.CORE, reader, puk, pin)];
            });
        });
    };
    /**
     * Unlock smartcard with HEX PUK, forcing a new PIN
     * (PHYSICAL READER ONLY!)
     * <br> **{@link getDevices} needed to be called before**
     * @category Devices
     * @param reader Reader index (MUST be > 0)
     * @param puk HEX PUK
     * @param pin New PIN
     *
     */
    DGS_CORE.prototype.deviceUnlockCEPin = function (reader, puk, pin) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                if (!puk) {
                    (0, Helpers_1.sendError)("no Pin");
                }
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_unlock_ce_pin, this.CORE, reader, puk, pin)];
            });
        });
    };
    /**
     * Activate a smartcard, setting the new PIN (PUK is needed, PHYSICAL READER ONLY!)
     * <br> **{@link getDevices} needed to be called before**
     * @category Devices
     *
     * @param reader Reader index (MUST be > 0)
     * @param puk PUK string
     * @param newpin PIN to be set
     */
    DGS_CORE.prototype.deviceActivate = function (readerIndex, puk, pin) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                if (!pin) {
                    (0, Helpers_1.sendError)("no Pin");
                }
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_activate_card, this.CORE, readerIndex, puk, pin)];
            });
        });
    };
    /**
     * Activate a Cert Europe smartcard, setting the new PIN (HEX PUK is needed, PHYSICAL READER ONLY!)
     * <br> **{@link getDevices} needed to be called before**
     * @category Devices
     *
     * @param reader Reader index (MUST be > 0)
     * @param puk HEX PUK string
     * @param newpin PIN to be set
     * @param uuid UUID to be set
     */
    DGS_CORE.prototype.deviceActivateCE = function (readerIndex, puk, pin, uuid) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                if (!pin) {
                    (0, Helpers_1.sendError)("no Pin");
                }
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_activate_ce_card, this.CORE, readerIndex, puk, pin, uuid)];
            });
        });
    };
    /**
    * Enable double PIN on selected reader (Only for bit4id libraries)
    * <br> **{@link getDevices} needed to be called before**
    * @category Devices
    *
    * @param readerIndex Reader index (MUST be > 0)
    * @param enabled boolean
    */
    DGS_CORE.prototype.deviceSetDoublePin = function (readerIndex, enabled) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_set_double_pin, this.CORE, readerIndex, enabled ? 1 : 0)];
            });
        });
    };
    /**
     * Sets custom P11
     * @category Devices
     *
     * @param reader Reader index (MUST be > 0)
     * @param atr Smartcard ATR code
     * @param lib LIB absolute path
     */
    DGS_CORE.prototype.deviceSetCustomP11 = function (readerIndex, atr, lib) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_customp11_set, this.CORE, readerIndex, atr, lib)];
            });
        });
    };
    /**
     * Unset custom P11
     * @category Devices
     */
    DGS_CORE.prototype.deviceUnsetCustomP11 = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_customp11_unset, this.CORE)];
            });
        });
    };
    /**
     * Deletes a bound sign certificate
     * @category Devices
     * @param certificate_id
     */
    DGS_CORE.prototype.deleteCertificate = function (reader_id, certificate_id) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                if (reader_id === 0) {
                    return [2 /*return*/, this.callNative(this.libdgsapi.dgs_delete_rs_certificate, this.CORE, certificate_id)];
                }
                else {
                    //TODO
                    return [2 /*return*/, {
                            code: 0,
                            message: "OK"
                        }];
                }
                return [2 /*return*/];
            });
        });
    };
    /**
     * Set e-seal and automatic remote signature JWT
     * @category Devices
     * @param certificate_id
     * @param jwt
     */
    DGS_CORE.prototype.setRSCertificateJWT = function (certificate_id, jwt) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_set_rs_account_jwt, this.CORE, certificate_id, jwt)];
            });
        });
    };
    /***************
   TIMESTAMP ACCOUNT
   ****************/
    /**
     * Return details of configured timestamp account
     * @category Timestamp account
     * @param refresh_counter force the refresh of counter
     */
    DGS_CORE.prototype.getTimestampAccount = function (refresh_counter) {
        if (refresh_counter === void 0) { refresh_counter = false; }
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callJsonNative(this.libdgsapi.dgs_get_timestamp_account, [this.CORE, refresh_counter]).catch(function (e) {
                        return (0, Helpers_1.sendSuccess)("No account found", e.code);
                    })];
            });
        });
    };
    /**
     * Deletes configured timestamp account
     * @category Timestamp account
     */
    DGS_CORE.prototype.deleteTimestampAccount = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_delete_timestamp_account, this.CORE)];
            });
        });
    };
    /***************
    MESSAGE METHODS
    ****************/
    DGS_CORE.prototype.getMessages = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callJsonNative(this.libdgsapi.dgs_message_queue_pop).catch(function (err) {
                        Logger_1.default.error("getMessages", err);
                    })];
            });
        });
    };
    DGS_CORE.prototype.startMonitor = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_pcscmonitor_run, this.CORE).then(function (success) {
                        console.log("🚀 ~ returnthis.callNative ~ success", success);
                        return success;
                    }).catch(function (err) {
                        console.error("startMonitor", err);
                        return err;
                    })];
            });
        });
    };
    DGS_CORE.prototype.stopMonitor = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                this.sendMessages("999999", "quitevent", {});
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_pcscmonitor_stop, this.CORE)];
            });
        });
    };
    DGS_CORE.prototype.sendMessages = function (id, category, json) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_message_queue_echo, this.CORE, id, category, JSON.stringify(json))];
            });
        });
    };
    DGS_CORE.prototype.initScheduler = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                Logger_1.default.log("DGS_CORE -> initScheduler -> initScheduler");
                this.startMonitor().then(function (monitorRes) {
                    Logger_1.default.log("startMonitor", monitorRes);
                }).catch(function (err) {
                    Logger_1.default.error("startMonitor Error", err);
                });
                this.scheduler = new Scheduler_1.default(this.getMessages.bind(this));
                this.MessagesSubject = this.scheduler.MessagesSubject;
                this.Messages$ = this.scheduler.Messages$;
                this.FilteredMessages$ = this.scheduler.FilteredMessages$;
                return [2 /*return*/];
            });
        });
    };
    DGS_CORE.prototype.stopScheduler = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                Logger_1.default.log("DGS_CORE -> stopScheduler");
                this.stopMonitor().then(function (monitorRes) {
                    Logger_1.default.log("stopMonitor", monitorRes);
                }).catch(function (err) {
                    Logger_1.default.error("stopMonitor Error", err);
                });
                this.scheduler.MessagesSubject.complete();
                return [2 /*return*/];
            });
        });
    };
    /************
    FLOW METHODS
    ************/
    /**
     * Initialize a flow process, get updates on its state and send new data to proceed
     * Returns a {@link Flow} Object that has:
     * - FlowData$ property, is a observable to follow the status of the flow<br>
     * - send() method , used to send new data to the flow<br>
     * @category FlowActions
     * @param FlowType:{@link flowType} the type of flow to start
     * @example
     *  ```javascript
     * //Create a new Flow of type DGS_FLOW_RS_BIND
     * const FlowRsBind = await CORE_INSTANCE.flowStart(FlowType.DGS_FLOW_RS_BIND);
     * //Subscribe to state changes and complete event
     * FlowRsBind.FlowData$.subscribe({
     *   next: async (data) => {
     *     console.log("new state data", data);
     *     //check current state and send events based on it
     *    if (data.state_type === FlowStateType.DGS_STATE_BIND_WAIT_CREDENTIALS) {
     *         FlowRsBind.send(FlowEvent.DGS_EVT_CREDENTIAL_INSERTED, { username, password })
     *     }
     *     if (data.state_type === FlowStateType.DGS_STATE_BIND_WAIT_OTP) {
     *       FlowRsBind.send(FlowEvent.DGS_EVT_OTP_INSERTED, { otp })
     *     }
     *   },
     *   error: (err) => {
     *    console.error("Flow error", err);
     *   },
     *   complete: () => {
     *     console.log("Flow completed")
     *   },
     * })
     *  ```
     */
    DGS_CORE.prototype.flowStart = function (flowType, isWeb) {
        if (isWeb === void 0) { isWeb = false; }
        return __awaiter(this, void 0, void 0, function () {
            var flowP, newFlow;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.callNative(this.libdgsapi.dgs_flow_start, this.CORE, flowType)];
                    case 1:
                        flowP = _a.sent();
                        Logger_1.default.log("FLOW", flows_1.FlowType[flowType], "flowStart", { isWeb: isWeb });
                        newFlow = new FlowProcess_1.default({
                            flowState: this.flowState.bind(this),
                            flowFree: this.flowFree.bind(this),
                            flowPostEvent: this.flowPostEvent.bind(this),
                            flowAbort: this.flowAbort.bind(this),
                            getErrorMessage: this.getErrorMessage.bind(this)
                        }, flowP, Logger_1.default, isWeb);
                        return [2 /*return*/, newFlow];
                }
            });
        });
    };
    DGS_CORE.prototype.flowState = function (flow) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callJsonNative(this.libdgsapi.dgs_flow_state, [flow])];
            });
        });
    };
    DGS_CORE.prototype.flowPostEvent = function (flow, flowEvent, json) {
        if (flowEvent === void 0) { flowEvent = 0; }
        return __awaiter(this, void 0, void 0, function () {
            var JsonPayload;
            return __generator(this, function (_a) {
                Logger_1.default.log("FLOW", flows_1.FlowEvent[flowEvent], "flowPostEvent -> json", json);
                JsonPayload = (0, Helpers_1.sendJsonString)(json);
                // if (flowEvent === FlowEvent.DGS_EVT_SIGNATURE_PARAMS_INSERTED) {
                //   const { session_tmpdir } = await this.getSessionParams()
                //   //@ts-expect-error
                //   const signParams: FlowEvents.SignatureParametersInserted = json;
                //   //if is PDF
                //   if (signParams.signFormat === SignFormat.DGS_SIGN_TYPE_PADES) {
                //     const hasImage = signParams.files.find(file => {
                //       return file.padesParams?.find(pades => {
                //         return pades.image;
                //       })
                //     })
                //     if (hasImage) {
                //       console.log("🚀 ~ flowPostEvent ~ hasImage", hasImage)
                //       // Using Promise.map and async/await:
                //       const newFiles: SigningFile[] = await BluePromise.map(signParams.files, async (file) => {
                //         // Promise.map awaits for returned promises as well.
                //         const hasImage = file.padesParams?.find(pades => {
                //           return pades.image;
                //         })
                //         if (file?.padesParams && hasImage) {
                //           file.padesParams = await BluePromise.map(file.padesParams, async (pades) => {
                //             if (pades.image) {
                //               console.log("🚀 ~  pades.image BEFORE", pades.image)
                //               pades.image = await this.resizeImage({
                //                 imagePath: pades.image,
                //                 targetWidth: pades.width,
                //                 targetHeight: pades.height,
                //                 outputPath: session_tmpdir
                //               })
                //               console.log("🚀 ~  pades.image AFTER", pades.image)
                //             }
                //             return pades;
                //           }, { concurrency: 2 })
                //         } else {
                //         }
                //         return file
                //       }, { concurrency: 2 });
                //       console.log("signParams.files BEFORE")
                //       console.log(JSON.stringify(signParams.files, null, 4))
                //       signParams.files = newFiles;
                //       console.log("signParams.files AFTER")
                //       console.log(JSON.stringify(signParams.files, null, 4))
                //     }
                //   }
                //   JsonPayload = JSON.stringify(signParams)
                // }
                //Logger.log("FLOW", FlowEvent[flowEvent], "flowPostEvent -> JsonPayload", JsonPayload)
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_flow_post_event, flow, flowEvent, JsonPayload)];
            });
        });
    };
    DGS_CORE.prototype.flowAbort = function (flow) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                Logger_1.default.log("FLOW", "flowAbort");
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_flow_abort_event_process, flow)];
            });
        });
    };
    DGS_CORE.prototype.flowFree = function (flow) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                Logger_1.default.log("FLOW", "flowFree");
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_flow_free, flow)];
            });
        });
    };
    /**
     * LICENSE METHODS
     */
    /**
     * Activates License by key
     * @category License
     */
    DGS_CORE.prototype.bindLicense = function (license_key) {
        return this.callJsonNative(this.libdgsapi.dgs_license_bind, [this.CORE, license_key]);
    };
    /**
     * Gets License Data
     * @category License
     */
    DGS_CORE.prototype.getLicense = function () {
        return this.callJsonNative(this.libdgsapi.dgs_license_get_status, [this.CORE]);
    };
    /**
     *  Deactivates current License
     * @category License
     */
    DGS_CORE.prototype.unbindLicense = function (license_key) {
        return this.callNative(this.libdgsapi.dgs_license_unbind, this.CORE, license_key);
    };
    /**
     *  Removes current License
     * @category License
     */
    DGS_CORE.prototype.removeLicense = function () {
        return this.callNative(this.libdgsapi.dgs_license_remove, this.CORE);
    };
    /**
    * TLS METHODS
    */
    /**
   * @brief getTsl Gets list of installed TSLs
   *
   * TSL status format is {@TslPayload}:
   * {
   *  "countries" : [<country_codes_of_installed_TSLs>]
   * }
   *
    * @category TSL
    */
    DGS_CORE.prototype.getTsl = function () {
        return this.callJsonNative(this.libdgsapi.dgs_tsl_get, [this.CORE]);
    };
    /**
     * @brief checkUpdatesTsl Verifies available updates for installed TSLs
     *
     * Update status format is:
     * {
     *  "countries" : [<country_codes_to_update>]
     * }
     * @category TSL
     */
    DGS_CORE.prototype.checkUpdatesTsl = function () {
        return this.callJsonNative(this.libdgsapi.dgs_tsl_checkupdates, [this.CORE]);
    };
    /**
    * @brief updateTsl Update a sublist of installed TSLs
    *
    * Update status format is:
    * {
    *  "countries" : [<country_codes_to_update>]
    * }
    * @category TSL
    */
    DGS_CORE.prototype.updateTsl = function (tsl_to_update) {
        return this.callNative(this.libdgsapi.dgs_tsl_update, this.CORE, (0, Helpers_1.sendJsonString)(tsl_to_update));
    };
    /**
    * addTSL
    * @brief addTsl Adds new country TSL
    * @category TSL
    */
    DGS_CORE.prototype.addTsl = function (countryCode) {
        return this.callNative(this.libdgsapi.dgs_tsl_add, this.CORE, countryCode);
    };
    /**
    * @brief removeTsl Removes a country TSL
    * @category TSL
    */
    DGS_CORE.prototype.removeTsl = function (countryCode) {
        return this.callNative(this.libdgsapi.dgs_tsl_remove, this.CORE, countryCode);
    };
    /**
    * @brief reloadTsl Reloads loaded TSLs
    * @category TSL
    */
    DGS_CORE.prototype.reloadTsl = function () {
        return this.callNative(this.libdgsapi.dgs_tsl_reload, this.CORE);
    };
    /**
    * PKCS12  METHODS
    */
    /**
   * @brief  Add PKCS#12 file to available signing certificates
   *
    * @category PKCS12
    */
    DGS_CORE.prototype.addPkcs12File = function (pkcs12_path, pkcs12_password, force) {
        if (pkcs12_password === void 0) { pkcs12_password = ""; }
        if (force === void 0) { force = false; }
        return this.callNative(this.libdgsapi.dgs_add_pkcs12_file, this.CORE, pkcs12_path, pkcs12_password, force);
    };
    /**
  * @brief Remove PKCS#12 file
  *
  * @category PKCS12
  */
    DGS_CORE.prototype.removePkcs12File = function (certificate_id) {
        return this.callNative(this.libdgsapi.dgs_remove_pkcs12_file, this.CORE, certificate_id);
    };
    /**
     * @brief  Executes verification of a single file
     *
     * JSON report format is the same as returned by verification flow
     *
     * @param filename File to verify
     * @param datafile Data file
     * @param verifydate Verify at date
  
     */
    DGS_CORE.prototype.verifyFile = function (filename, datafile, verifydate) {
        if (datafile === void 0) { datafile = ""; }
        if (verifydate === void 0) { verifydate = ""; }
        return this.callJsonNative(this.libdgsapi.dgs_verify_file, [this.CORE, filename, datafile, verifydate]);
    };
    /**
     * @brief extractFile Extracts signed file content
     *
     * @param signed_input_file
     * @param outdir Directory where a "filename.EXTRACTED" will be created and extracted content placed into
     *
     * @return 0 on success, a negative integer otherwise
     */
    DGS_CORE.prototype.extractFile = function (signed_input_file, outdir) {
        return this.callNative(this.libdgsapi.dgs_extract_file, this.CORE, signed_input_file, outdir);
    };
    /**
     * @brief extractFiles Extracts signed files content
     *
     * @param input_files Files to extract
     * @param output_dir Directory where a "filename.EXTRACTED" will be created and extracted content placed into
     *
     * @return 0 on success, a negative integer otherwise
     */
    DGS_CORE.prototype.extractFiles = function (json) {
        Logger_1.default.log("extractFiles", json);
        return this.callNative(this.libdgsapi.dgs_extract_files, this.CORE, (0, Helpers_1.sendJsonString)(json));
    };
    /**
     * @brief   Creates a verification report in HTML format
     *
      * @param filename File to verify
      * @param outfilename Output filename
      * @param datafile Data file (optional, NULL if none required)
      * @param at_date Verify at date (optional, NULL to use current time)
  
     */
    DGS_CORE.prototype.createHTMLverificationReport = function (filename, outfilename, datafile, at_date) {
        if (datafile === void 0) { datafile = ""; }
        if (at_date === void 0) { at_date = ""; }
        return this.callNative(this.libdgsapi.dgs_create_HTML_report, this.CORE, filename, datafile, at_date, outfilename);
    };
    /**
    * OAUTH  METHODS
    */
    /**
  * @brief Retrieves URL to start GoSign OAUTH login flow
  * @category OAUTH
  * @param callback For example: "diker://dike/OAUTH_AUTHORIZE"
  */
    DGS_CORE.prototype.getOauthUrl = function (callbackUrl, loginType) {
        return this.callJsonNative(this.libdgsapi.dgs_oauth_get_url, [this.CORE, callbackUrl, loginType]);
    };
    /**
  * @brief Retrieves data for GoSign Logged User
  * @category OAUTH
  * @param refresh true if client wants to refresh token
  */
    DGS_CORE.prototype.getOauthIdentity = function (refresh) {
        return this.callJsonNative(this.libdgsapi.dgs_oauth_get_identity, [this.CORE, refresh]);
    };
    DGS_CORE.prototype.selectOauthAssociations = function (associationUIDAs) {
        return this.callNative(this.libdgsapi.dgs_oauth_select_associations, this.CORE, (0, Helpers_1.sendJsonString)(associationUIDAs));
    };
    /**
  * @brief Closes GoSign OAUTH login flow
  * @category OAUTH
  * @param state State from GoSign oauth service
  * @param authorizationCode Authorization code from GoSign oauth service
  */
    DGS_CORE.prototype.getOauthAuthorize = function (state, authorizationCode) {
        return this.callNative(this.libdgsapi.dgs_oauth_authorize, this.CORE, state, authorizationCode);
    };
    /**
  * @brief Login GoSign user
  * @category OAUTH
  */
    DGS_CORE.prototype.getOauthLogin = function (username, password) {
        return this.callNative(this.libdgsapi.dgs_oauth_login, this.CORE, username, password);
    };
    /**
   * @brief Logout GoSign user
   * @category OAUTH
   */
    DGS_CORE.prototype.getOauthLogout = function () {
        return this.callNative(this.libdgsapi.dgs_oauth_logout, this.CORE);
    };
    /**
   * @brief Create authenticated URL to GoSign portal
   * @category GoSign
   */
    DGS_CORE.prototype.getGosignUrl = function (url_type, requestInfo) {
        return this.callJsonNative(this.libdgsapi.dgs_gosign_load_url, [this.CORE, url_type, (0, Helpers_1.sendJsonString)(requestInfo)]);
    };
    /**
     * @brief Retrieves ATL data
     * @category ATL
     * @param refresh true if client wants to refresh ATL
     */
    DGS_CORE.prototype.getATL = function (refresh) {
        if (refresh === void 0) { refresh = false; }
        return this.callJsonNative(this.libdgsapi.dgs_atl_get, [this.CORE, refresh]);
    };
    /***************
  TIMPESTAMP AUXILIARY
  ****************/
    /**
     * Associate a detached timestamp and its data file
   *
   * @brief Allowed combinations are:
   * - TST + DATA = TSD
   * - TSR + DATA = M7M
   * @category Timestamp Auxiliary
   */
    DGS_CORE.prototype.associateTimestamp = function (docfile, tsfile, outfile, outformat) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_associate_timestamp, this.CORE, docfile, tsfile, outfile, outformat)];
            });
        });
    };
    /**
   * Separate timestamp file
   * @brief Allowed combinations are:
  * TSD = TST + DATA
  * M7M = TSR + DATA
  
  *
   * @category Timestamp Auxiliary
   */
    DGS_CORE.prototype.separateTimestamp = function (input_tsfile, out_dir) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callJsonNative(this.libdgsapi.dgs_separate_timestamp, [this.CORE, input_tsfile, out_dir])];
            });
        });
    };
    /***************
    CERT CHRONO
    ****************/
    /**
    * @brief Get a snapshot of current certificate chronology
    * @category Certs Chrono
    **/
    DGS_CORE.prototype.chronoGetCertificates = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callJsonNative(this.libdgsapi.dgs_certchrono_get_certificates, [this.CORE])];
            });
        });
    };
    /**
    * @brief Remove one certificate from chronology
    * @category Certs Chrono
    **/
    DGS_CORE.prototype.chronoRemoveCertificate = function (certID) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_certchrono_remove_certificate, this.CORE, certID)];
            });
        });
    };
    /**
    * @brief Remove all certificates from chronology
    * @category Certs Chrono
    **/
    DGS_CORE.prototype.chronoRemoveCertificates = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_certchrono_remove_certificates, this.CORE)];
            });
        });
    };
    /**
    * @brief Remove not expired certificates from chronology
    * @category Certs Chrono
    **/
    DGS_CORE.prototype.chronoRemoveValidCertificates = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_certchrono_remove_valid_certificates, this.CORE)];
            });
        });
    };
    /**
    * @brief Remove expired certificates from chronology
    * @category Certs Chrono
    **/
    DGS_CORE.prototype.chronoRemoveExpiredCertificates = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_certchrono_remove_expired_certificates, this.CORE)];
            });
        });
    };
    /**
    * @brief Set lastreminded field to certificate identified by certID
    * @param certID CertID as returned in snapshot
    * @param date Date formatted YYYYMMDD or NEVER
    * @category Certs Chrono
    **/
    DGS_CORE.prototype.chronoSetLastReminded = function (certID, date) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_certchrono_set_last_reminded, this.CORE, certID, date)];
            });
        });
    };
    /**
    * @brief Set nextremind field to certificate identified by certID
    * @param certID CertID as returned in snapshot
    * @param date Date formatted YYYYMMDD or NEVER
    * @category Certs Chrono
    **/
    DGS_CORE.prototype.chronoSetNextRemind = function (certID, date) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_certchrono_set_next_remind, this.CORE, certID, date)];
            });
        });
    };
    /**
    * @brief Set lastreadyrenewdate field to certificate identified by certID
    * @param certID CertID as returned in snapshot
    * @param date Date formatted YYYYMMDD or NEVER
    * @category Certs Chrono
    **/
    DGS_CORE.prototype.chronoSetLastRenewNotify = function (certID, date) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_certchrono_set_last_renew_notify, this.CORE, certID, date)];
            });
        });
    };
    /**
    * @brief Set lastmailupdate field to certificate identified by certID
    * @param certID CertID as returned in snapshot
    * @param date Date formatted YYYYMMDD or NEVER
    * @category Certs Chrono
    **/
    DGS_CORE.prototype.chronoSetLastMailUpdate = function (certID, date) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_certchrono_set_last_mail_update, this.CORE, certID, date)];
            });
        });
    };
    /**
    * @brief Set mailupdateproposalcount field to certificate identified by certID
    * @param certID CertID as returned in snapshot
    * @param count Counter
    * @category Certs Chrono
    **/
    DGS_CORE.prototype.chronoSetMailUpdateCount = function (certID, count) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_certchrono_set_mail_update_count, this.CORE, certID, count)];
            });
        });
    };
    /**
    * @brief Set renewstatus field to certificate identified by certID
    * @param certID CertID as returned in snapshot
    * @param status:RenewStatus Certificate renewal status
    * @category Certs Chrono
    **/
    DGS_CORE.prototype.chronoSetCertRenewStatus = function (certID, status) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_certchrono_set_cert_renew_status, this.CORE, certID, status)];
            });
        });
    };
    /**
   * @brief Creates a zipfile with given paths
   * @category Utility
   */
    DGS_CORE.prototype.makeZip = function (json) {
        Logger_1.default.log("makeZip", json);
        return this.callNative(this.libdgsapi.dgs_makezip, this.CORE, (0, Helpers_1.sendJsonString)(json));
    };
    /**
     * @brief Reads core session params
     * @category Utility
     * @returns SessionParams object
     S*/
    DGS_CORE.prototype.getSessionParams = function () {
        Logger_1.default.log("getSessionParams");
        return this.callJsonNative(this.libdgsapi.dgs_core_session_params);
    };
    /**
     * @brief Checks PDF for signing with given path
     * @category Utility
     * @returns configuration object
     */
    DGS_CORE.prototype.checkPDF = function (paths) {
        Logger_1.default.log("checkPDF", paths);
        return this.callJsonNative(this.libdgsapi.dgs_check_pdf, [this.CORE, (0, Helpers_1.sendJsonString)(paths)]);
    };
    /**
     * @brief Combine two images (signature and background) for PAdES signature
     * @param signature_file Path to signature image
     * @param output_file Path to output combined image
     * @param params Optional combine parameters
     * @category Utility
     */
    DGS_CORE.prototype.pdfImageCombine = function (signature_file, output_file, params) {
        Logger_1.default.log("pdfImageCombine", signature_file, output_file, params);
        return this.callNative(this.libdgsapi.dgs_pdfimage_combine, this.CORE, signature_file, output_file, (0, Helpers_1.sendJsonString)(params));
    };
    /**
     * @brief Check connection
     * @category Utility
     */
    DGS_CORE.prototype.checkConnection = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.callNative(this.libdgsapi.dgs_check_connection, this.CORE)];
            });
        });
    };
    /**
     * @brief Get system URL
     * @category Utility
     */
    DGS_CORE.prototype.getUrl = function (url_type) {
        return this.callJsonNative(this.libdgsapi.dgs_get_url, [this.CORE, url_type]);
    };
    /**
     * @brief Retrieves URL to start EID Gateway OAUTH login flow
     * @category EID Gateway
     * @param callback For example: "diker://dike/OAUTH_AUTHORIZE_EID"
     * @param configurationType EID Gateway login profile (SPID, CNS, ...)
     */
    DGS_CORE.prototype.getEIDGUrl = function (callbackUrl, configurationType) {
        return this.callJsonNative(this.libdgsapi.dgs_eid_get_url, [this.CORE, callbackUrl, configurationType]);
    };
    /**
     * @brief Closes EID Gateway OAUTH login flow
     * @category EID Gateway
     * @param state State from EID Gateway oauth service
     * @param authorizationCode Authorization code from EID Gateway oauth service
     */
    DGS_CORE.prototype.getEIDGAuthorize = function (state, authorizationCode) {
        return this.callJsonNative(this.libdgsapi.dgs_eid_authorize, [this.CORE, state, authorizationCode]);
    };
    /**
     * @brief Check Coupon code
     * @category Generic
     * @param type Coupon type
     * @param coupon Coupon code
     */
    DGS_CORE.prototype.getCheckCoupon = function (type, coupon) {
        return this.callNative(this.libdgsapi.dgs_check_coupon, this.CORE, type, coupon);
    };
    /**
     * @brief Gets user oneshot emission informations
     * @category EID Gateway
     * @param identifier User identifier
     */
    DGS_CORE.prototype.getEIDGOneshotCount = function (identifier) {
        return this.callJsonNative(this.libdgsapi.dgs_eid_oneshot_count, [this.CORE, identifier]);
    };
    /**
     * @brief Emits oneshot signing certificate
     * @category EID Gateway
     * @param authorize EIDGSigner object from from EID Gateway authorization service
     * @param clausole Contract
     * @param numFirme Number of signatures
     * @param email Customer email
     * @param coupon Coupon code
     * @param identifier User identifier
     */
    DGS_CORE.prototype.getEIDGOneshotEmission = function (authorize, clausole, numFirme, email, coupon, identifier) {
        return this.callJsonNative(this.libdgsapi.dgs_eid_oneshot_emission, [this.CORE, (0, Helpers_1.sendJsonString)(authorize), clausole, numFirme, email, coupon, identifier]);
    };
    /**
     * @brief Register certstore certificates
     * @category Utility
     * @param certificates List of certificates PEM
     */
    DGS_CORE.prototype.registerCertstore = function (certificates) {
        return this.callNative(this.libdgsapi.dgs_certstore_register, this.CORE, (0, Helpers_1.sendJsonString)(certificates));
    };
    /**
     * @brief Save verbose logs
     * @category Utility
     * @param p7ePath Output encrypted zip file
     */
    DGS_CORE.prototype.saveVerboseLogs = function (p7ePath) {
        return this.callNative(this.libdgsapi.dgs_save_verbose_logs, this.CORE, p7ePath);
    };
    /**
     * @brief generateQualifiedVerifyReport Generate report using qualified validation
     * @category Qualified Validation
     *
     * @param signed_file Path to signed document
     * @param original_file Path to original document (for detached signature)
     * @param payment_type Type of payment (coupon, identifier, ...)
     * @param payment_code Code of payment (coupon, identifier, ...)
     */
    DGS_CORE.prototype.generateQualifiedVerifyReport = function (signed_file, original_file, paymentType, paymentCode) {
        return this.callJsonNative(this.libdgsapi.dgs_qualified_verify_generate_report, [this.CORE, signed_file, original_file, paymentType, paymentCode]);
    };
    /**
     * @brief signQualifiedVerifyReport Generate report using qualified validation
     * @category Qualified Validation
     *
     * @param to_sign_file Path to report PDF
     * @param signed_file Path for output signed PDF file
     * @param payment_type Type of payment (coupon, identifier, ...)
     * @param payment_code Code of payment (coupon, identifier, ...)
     */
    DGS_CORE.prototype.signQualifiedVerifyReport = function (to_sign_file, etsi_xml_report, signed_file, paymentType, paymentCode) {
        return this.callNative(this.libdgsapi.dgs_qualified_verify_sign_report, this.CORE, to_sign_file, etsi_xml_report, signed_file, paymentType, paymentCode);
    };
    /**
     * @brief getQualifiedVerifyCount Count qualified validation credits
     * @category Qualified Validation
     *
     * @param identifier User identifier
     */
    DGS_CORE.prototype.getQualifiedVerifyCount = function (identifier) {
        return this.callJsonNative(this.libdgsapi.dgs_qualified_verify_count, [this.CORE, identifier]);
    };
    /***********************************************************************
    ***********************************************************************
     PRIVATE METHODS
     ***********************************************************************
     ***********************************************************************/
    /**
     * Destroy Core lib
     * @param coreInstance the core lib instance
     */
    DGS_CORE.prototype.destroy = function () {
        this.callNative(this.libdgsapi.dgs_core_destroy).catch(function (e) {
            console.warn("destroy", e);
        });
        Logger_1.default.log("destroy");
        this.CORE = null;
    };
    /**
     * Return the json from the method
     * @param libMethod the core lib method
     * the method should accept (CORE, snapshotResultPointer)
     * @returns the json data
     */
    DGS_CORE.prototype.read_json_value = function (libMethod, params) {
        if (params === void 0) { params = [this.CORE]; }
        return __awaiter(this, void 0, void 0, function () {
            var _this = this;
            return __generator(this, function (_a) {
                return [2 /*return*/, new Promise(function (resolve, reject) { return __awaiter(_this, void 0, void 0, function () {
                        var snapshotResultPointer, result, snapshotResult, jsonData, e_2;
                        return __generator(this, function (_a) {
                            switch (_a.label) {
                                case 0:
                                    snapshotResultPointer = ref.alloc(types_1.default.pointerOfPointer);
                                    _a.label = 1;
                                case 1:
                                    _a.trys.push([1, 3, , 4]);
                                    return [4 /*yield*/, this.callNative.apply(this, __spreadArray(__spreadArray([libMethod], params, false), [snapshotResultPointer], false))];
                                case 2:
                                    result = _a.sent();
                                    snapshotResult = snapshotResultPointer.deref();
                                    jsonData = this.libdgsapi.dgs_json_value(snapshotResult);
                                    Logger_1.default.log("DGS_CORE -> json_value -> jsonData", jsonData);
                                    this.libdgsapi.dgs_json_value_free(snapshotResult);
                                    //Logger.log("DGS_CORE -> json_value -> jsonFree", jsonFree)
                                    resolve(JSON.parse(jsonData));
                                    return [3 /*break*/, 4];
                                case 3:
                                    e_2 = _a.sent();
                                    Logger_1.default.error("ERRORE", e_2);
                                    reject(e_2);
                                    return [3 /*break*/, 4];
                                case 4: return [2 /*return*/];
                            }
                        });
                    }); })];
            });
        });
    };
    /**
     * Return error message by error code
     * @param responseCode the int response code
     */
    DGS_CORE.prototype.getErrorMessage = function (responseCode) {
        var error = this.libdgsapi.dgs_err_str(responseCode);
        if (error !== "OK")
            Logger_1.default.error("getErrorByCode", error);
        if (error === 'Unknown error') {
            error = error_codes_1.ErrorCodes[responseCode];
        }
        return error;
    };
    return DGS_CORE;
}());
exports.default = DGS_CORE;
//# sourceMappingURL=Dgs.core.js.map