"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var rxjs_1 = require("rxjs");
var flows_1 = require("./types/flows");
/**
  * Flow Object returned by {@link flowStart}
  * <br/>
  *
  * # Flow API

  The flow API implements processes modelled as a finite state machine (FSM).
  Once the flow is initialized, using the CORE.{@link flowStart} method <br>
  the API allows to read its current state and post events to transition between states, until the FSM reaches its final state.
  Once a final state is reached, flow is completed and no longer accepts any events. States may allow one ore more event types to be posted.

  ## Remote sign bind flow

  There are several kinds of remote sign account, depending on their backend system, and the binding process may require different interaction with the user.

  ![RS BIND](/assets/images/flows/rsbind.png)

  #### {@link FlowStateType}.DGS_STATE_BIND_WAIT_CREDENTIALS

  This is the intial state. Waits for the user to input username and password.

  Accepted events:

  - {@link FlowEvents}.RsCredentialInserted

  #### {@link FlowStateType}.DGS_STATE_BIND_WAIT_OTP

  Waits for the user to insert an OTP

  Accepted events:

  - {@link FlowEvent}.DGS_EVT_OTP_INSERTED

  #### {@link FlowStateType}.DGS_STATE_BIND_DONE

  This is the final state. Bind operation has been completed. <br>
  If operation was successful result code is 0, and list of Subject Names (SN) of bound certifices is returned in the state data.

  ## Timestamp bind flow


  * @category FlowActions
  * @example
  *  ```javascript
  * //Create a new Flow of type  DGS_FLOW_RS_BIND
  * const FlowRsBind = await CORE_INSTANCE.flowStart(FlowType.DGS_FLOW_RS_BIND);
  * //Subscribe to state changes and complete event
  * FlowRsBind.FlowData$.subscribe({
  *   next: async (data) => {
  *     console.log("new state data", data);
  *     //check current state and send events based on it
  *     if (data.state_type === FlowStateType.DGS_STATE_BIND_WAIT_CREDENTIALS) {
  *         FlowRsBind.send(FlowEvent.DGS_EVT_CREDENTIAL_INSERTED, { username, password })
  *     }
  *     if (data.state_type === FlowStateType.DGS_STATE_BIND_WAIT_OTP) {
  *       FlowRsBind.send(FlowEvent.DGS_EVT_OTP_INSERTED, { otp })
  *     }
  *   },
  *   error: (err) => {
  *    console.error("Flow error", err);
  *   },
  *   complete: () => {
  *     console.log("Flow completed")
  *   },
  * })
  *  ```
  * @example TS BIND example
  * ![TS BIND](/assets/images/flows/tsbind.png)
  *
  *  ## SIGN flow
  *
  * ![SIGN](/assets/images/flows/sign.png)
  *
  * #### {@link FlowStateType}.DGS_STATE_SIGN_WAIT_SIGN_PARAMS
  *
  * This is the intial state. Waits for signature parameters
  *
  * Accepted events:
  *
  * - {@link FlowEvents}.SignatureParametersInserted
  *
  * #### {@link FlowStateType}.DGS_STATE_SIGN_WAIT_OTP
  *
  * Waiting for the user to insert an OTP (remote sign with direct authorization mode)
  *
  * Accepted events:
  *
  * - {@link FlowEvent}.OTPInserted
  * - {@link FlowEvent}.ResendOtp
  *
  * #### {@link FlowStateType}.DGS_STATE_SIGN_WAIT_AUTHORIZATION
  *
  * Waiting for the current block of files to be authorized (remote sign with implicit authorization mode)
  *
  * Accepted events:
  *
  * - {@link FlowEvent}.PollAuthorization
  * - {@link FlowEvent}.ResendOtp
  *
  * #### {@link FlowStateType}.DGS_STATE_READY_TO_SIGN
  *
  * Next block of signature operation items is ready to be processed
  *
  * Accepted events:
  *
  * - {@link FlowEvents}.StartSign
  *
  * #### {@link FlowStateType}.DGS_STATE_SIGN_DONE
  *
  * This is the final state. Sign operation has been completed. <br/>
  * Operation overall result, can be read from "result" state data field. <br/>
  * If a fatal error occurred (result is ALL_KO), its code can be read from "result_code" state field. <br/>
  * Result for individual items of operation are stored into file_results array.
  *
  *
  * ### Signing with local devices
  *
  * Local signing devices are: smartcard, pkcs#12 file, windows certstore certificates.
  * Both hash to sign computing and signing is executed on the user machine.
  *
  * The signature flow for local devices is:
  *
  * ![SIGN](/assets/images/flows/sign_local.png)[sign_local.png]
  *
  * Once all signature parameters (files to sign, pin, etc) are posted, no further user interaction is required.
  *
  * ### Signing with remote devices
  *
  * When signing with a remote device, the hash to sign is computed locally (on the user machine) and signed remotely (on remote signature backend).
  * Input files are grouped in fixed subsets, whose size "N" depends on the license (usually, N=1 for unlicensed, N=10 with a PRO license).
  * Signature of each subset must be authorized separately (e.g. ask for an OTP or display a QRCODE every N=10 file to sign).
  *
  * Depending on remote sign account and the available authenticators, user may choose between two signing authorization modes:
  *
  * - Direct authorization (SMS, time-based OTP generator): user is prompetd to type an OTP, which can be deliverd via SMS or generated from mobile application (time-based)
  * - Implicit authorization (QRCODE, Push notification): user authorizes the transaction from its mobile device, without interacting with the desktop application, which instead must poll in background for the authorization to be completed.
  *
  * List of available authenticators is returned by the certificates snapshot API. If the list is empty, direct authentication is implied, and the authenticator field of SignParameters object can be omitted.
  *
  * ### Remote sign with direct authorization
  *
  * Used when the authenticator field of SignParameters is one of (SMSP, OTPS) or it is left blank (defaults to SMSP).
  * For each block of file, user must type an OTP. Client can request the delivery of another OTP posting a ResendOTP event.
  *
  * ![SIGN](/assets/images/flows/sign_remote_direct.png)[sign_remote_direct.png]
  *
  * ### Remote sign with implicit authorization
  *
  * Used when the authenticator field of SignParameters is one of (QRCODE, FIDO). <br/>
  * Both modes requires the user to authorize the transaction for its mobile device with MyInfocert app. <br/>
  * For QRCODE, shooting the qrcode image; for FIDO, receiving a push notification on the app.
  *
  * Client must poll, posting the PollAuthorization event, until block transaction is authorized. <br/>
  * Note: Poll should interleaved with a relatively long time interval, between 2 and 5 seconds.
  * Client can request the generation of another QRCODE or the delivery of another push notification posting a ResendOTP event.
  *
  * ![SIGN](/assets/images/flows/sign_remote_implicit.png)[sign_remote_implicit.png]
  *
  * ### Counter Signature
  *
  * To enable Counter signature set {@link SignatureParametersInserted.counter} to true . <br/>
  * then for each {@link SigningFile} specify a {@link CounterSignData} object with :
  * - {@link CounterSignData.signatureId}  as found in verification report from {@link Signature.signature_id}
  * - {@link CounterSignData.signerPEM} PEM certificate of signature to countersign from Signature.signer_x509.{@link IDevices.X509.PEM} <br/>
  *
  * @note Counter Signature is supported only for CADES or XADES signed files
  *
  * ### Reading sign operation progress
  *
  * Operation progress (current/total counters) is reported while processing the StartSign event from READY_TO_SIGN state.
  * Progress state data messages   are emitted through the {@link Messages$} public observable queue, filterable throught operation id
  *
  * @example
  * Example of JSON payload for a {@link DGS_STATE_SIGN_WAIT_SIGN_PARAMS} with a single visible pades signature :
  *  ```typescript
  * if (data.state_type === FlowStateType.DGS_STATE_SIGN_WAIT_SIGN_PARAMS) {
  *
  *  const signParams : FlowEvents.SignatureParametersInserted = {
  *    "certificate_id": "DS3",
  *    "counter": false,
  *    "files": [
  *      {
  *        "input": "c:/../test_flow.pdf",
  *        "output": "c:/../test_flow_output.pdf",
  *        "padesParams": [
  *          {
  *            "contactInfo": "contactInfo",
  *            "image": "",
  *            "locality": "locality",
  *            "reason": "test firma",
  *            "showDateTime": true,
  *            "signField": "",
  *            "signer": "Magico",
  *            "isVisible": true,
  *            "page": 0,
  *            "height": 75,
  *            "width": 150,
  *            "x": 10,
  *            "y": 10
  *          }
  *        ],
  *        "signerInfoCertificate": "",
  *        "signingTime": "",
  *        "xadesAddSignTime": false,
  *        "xadesSignatureId": ""
  *      }
  *    ],
  *    "language": "it",
  *    "ltv": false,
  *    "pin": "12345678",
  *    "pkgFormat": 1,
  *    "selected_reader": 1,
  *    "signFormat": 1,
  *    "timestamp": false
  *  }
  *
  * FlowRsBind.send(FlowEvent.DGS_EVT_SIGNATURE_PARAMS_INSERTED, signParams);
  *
  *}
  *  ```
 # VERIFY flow

![VERIFY_FSM](/assets/images/flows/verify_fsm.png)

![VERIFY_SEQ](/assets/images/flows/verify_seq.png)

## {@link FlowStateType}.DGS_STATE_VERIFY_WAIT_PARAMS
This is the intial state. Waits for verify operation parameters
Accepted events:
- {@link FlowEvents}.VerifyWaitParamters

## {@link FlowStateType}.DGS_STATE_VERIFY_WAIT_DETACHED_SRC
One ore more input files are detached timstamp/signature.<br/>
Client must specify data source file for each of them (.p7s, .tsd, .xml)
Accepted events:
- {@link FlowEvents}.VerifyDetachedSources

## {@link FlowStateType}.DGS_STATE_VERIFY_WAIT_TSL
One ore more countries TSL are missing, which are reported as state data. Client must specifiy which one to add.
Accepted events:
- {@link FlowEvents}.VerifyAddTSL


## {@link FlowStateType}.DGS_STATE_VERIFY_DONE
Final state. Verify operation has been completed. <br/>

## Checking verification results

First thing to check is {@link VerifyDoneState}.fatal_errcode; if it is != DGS_OK, it means total failure (e.g. there is not internet connection); none of the input file has been processed.

If no fatal error occurred, verification report of each file can be read from {@link VerifyDoneState}.results array

### Checking file verification report

Verification result for a single file is stored in a {@link FileVerificationResult} object.

Before parsing individual signature/timestamp reports, client must check {@link FileVerificationResult}.error_code; if it is != DGS_OK, file could not be processed (e.g. it does not exist, could not be read etc).

If there was no error processing the file, found signatures and timestamps are stored in the {@link FileVerificationResult}.signatures and {@link FileVerificationResult}.timestamps respectively.

### Signatures

Signature report is stored int a {@link Signature} object.

* {@link Signature}.level: signature verification level, as defined in {@link VerificationLevel}.
* {@link Signature}.error_code: Error code (empty if no error)
* {@link Signature}.error_message: Description of the error code (empty if no error)

#### Signatures with timestamp

{@link Signature} object might have an attacched timestamp, stored in {@link Signature}.timestamp.

If signature has an attacched timestamp, client must consider level/error_code/error_message stored into the Signature object, i.e. Signature+Timestamp level/error_code/error_message stored the "worst" of the two (e.g a good signature and a bad timestamp results in an invalid signature)

#### Countersignature

{@link Signature} object might have one ore more counterisignatures, stored in {@link Signature}.countersignatures.

Each countersignature is store into a  {@link Signature} object; their level/error_code/error_message are independent from the containing Signature, i.e they do not affect countersigned signature levels.

### Timestamps

Timestamp report is stored int a {@link Timestamp} object.

* {@link Timestamp}.level: Timestamp verification level, as defined in {@link VerificationLevel}.
* {@link Timestamp}.error_code: Error code (empty if no error)
* {@link Timestamp}.error_message: Description of the error code (empty if no error)

### Warning and notices

Both Signature/Timestamp objects have an array of {@link VerifyWarnings} objects, which contains warning and/or notices which must be displayed.

Here is a list of  {@link VerifyWarnings} and their meaning:

| CODE                     |  LEVEL  |                                                                           SHORT DESCRIPTION |                                                                                                                                                                                                                             EXTENDED DESCRIPTION |
| ------------------------ | :-----: | ------------------------------------------------------------------------------------------: | -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------: |
| QSCD_ESEAL               | NOTICE  |                       QSCD eSeal - Sigillo qualificato su dispositivo sicuro conforme EIDAS |
| KEYSAGE_BF               | WARNING |                                              Firma non conforme alla delibera AgID 147/2019 |                           L'utilizzo della chiave di firma e' diverso da 'non ripudio'. La firma e' valida, ma potrebbe non essere riconosciuta in Italia in base alla Determina AgID 147 del 4 giugno 2019 e alla norma eIDAS ETSI EN 319 412-2 |
| KEYSAGE_CDE              | WARNING |                                                                      - same as KEYSAGE_BF - |                                                                                                                                                                                                                           - same as KEYSAGE_BF - |
| NOT_CADES_COMPLIANT      | WARNING |                                                                          Firma non conforme |                                                                                                                          Firma non conforme - La firma e' valida ma il formato della firma non soddisfa i requisiti minimi dei regolamenti eIDAS |
| NOT_PADES_COMPLIANT      | WARNING |                                                                    Firma PAdES non conforme |                                                                                                                                                                                             La firma non rispetta la decisione europea 2015/1506 |
| PADES_BASIC              | WARNING |                                                                           Firma PAdES-Basic |                                                                                                                                                                                             La firma non rispetta la decisione europea 2015/1506 |
| PDF_SIGNED_SIGNINTIME    | WARNING |                                                                    Firma PAdES non conforme |                                                                                                                               La firma e' valida ma il formato della firma PDF contiene elementi non conformi ai requisiti dei regolamenti eIDAS |
| OBSOLETE_DIGEST          | WARNING |                                              Firma non conforme alla delibera AgID 147/2019 |                                   La firma e' stata verificata correttamente ma il formato utilizzato non e' piu' conforme ai requisiti minimi di sicurezza dei regolamento eIDAS. In alcuni paesi questa firma potrebbe non essere riconosciuta |
| KEY_NOT_ON_SECURE_DEVICE | WARNING |                                    Certificato di firma NON residente su dispositivo sicuro |                                                                                                                                                                                Firma apposta con certificato NON residente su dispositivo sicuro |
| CAROOT_NOT_TRUSTED       | WARNING |                       La verifica e' stata effettuata usando una RootCA inclusa nella firma |                                                                                                                                                                                                                                                - |
| TS_OBSOLETE_DIGEST       | WARNING |                                              Marca non conforme alla delibera AgID 147/2019 |                                                                                                                                                             La marca temporale e' stata apposta usando un algoritmo di digest deprecato/obsoleto |
| TS_NATIONAL_LEVEL        | WARNING |                                                     Marca valida solo nei confini nazionali | La marca temporale e' stata apposta da una servizio TSP Non-Qualificato. La marca e' quindi pienamente valida solo nel paese di appartenenza del TSP. Per ottenere marche temporali valide in tutta la EU ti consigliamo di acquistarle sul sito |
| REVCHECK_FAILED          | WARNING |                                                      Verifica dello stato di revoca fallito |                                                                                                                                                                         Verificare la connnessione internet o rivedere le impostazioni del proxy |
| CA_CERT_EXPIRED          | WARNING | Il certificato di CA utilizzato nella verifica e' SCADUTO in data %signature.cacertexpired% |                                                                                                                                                                                                                                                - |
| CERT_EXPIRED             | WARNING |                                                        Certificato scaduto/revocato/sospeso |                                                                                                                                                                                                                                                - |


Some of these warning requires the client to prompt the user for further actions on the specified file.

#### Verify file at specified date (CERT_EXPIRED)

Signing certificate is expired, and if the signature does not contain a timestamp, it cannot be validated.
Client must prompt the user to re-execute verification of the file at the signing time.

#### Retry operation (REVCHECK_FAILED)

Signature is formally valid, but revocation checks failed due to internet connection issues.
Client must prompt the user to re-execute verification.



 ## Timestamp flow

  Timestamp one or more file
<br>
  ![TIMSTAMP BIND](/assets/images/flows/timestamp_fsm.png)

  #### {@link FlowStateType}.DGS_STATE_TS_WAIT_PARAMS

  This is the intial state. Waits for the user to specify files and format.

  Accepted events:

  - {@link FlowEvents}.TimestampParamsInserted

  #### {@link FlowStateType}.DGS_STATE_TS_DONE

   This is the final state. TimeStamp operation has been completed. <br>
  If fatal_error != 0 there was an error which prevented the operation on all files <br>
otherwise individual files error code is stored within results array

## Update check flow

  Check and download available updates

<br>

  ![UPDATE CHECK](/assets/images/flows/updatecheck.png)

  #### {@link FlowStateType}.DGS_STATE_UPDATECHECK_WAIT_REQUEST

  This is the intial state. Waits for the user to start update check operation

  Accepted events:

  - {@link FlowEvents}.UpdateCheckRequested

  This event has 2 fields:
    * "version" : The current application version
    * "auto_download": (optional, default=true) immediately download the update package, if any

  #### {@link FlowStateType}.DGS_STATE_UPDATECHECK_WAIT_START

  Optional intermediate step: UpdateCheckRequested.auto_download=false AND an updated version was
  found. Ask user download consent.

  Accepted events:

  - {@link FlowEvents}.UpdateStartRequested

  #### {@link FlowStateType}.UpdateDownloadRequested

  #### {@link FlowStateType}.DGS_STATE_UPDATECHECK_DONE

  This is the final state. <br>
  If fatal_error != 0 there was an error which prevented the operation to complete <br>
  Otherwise:
  * If an update was found, is returned in the "updateinfo" field. Update info includes new version number and path to downloaded package
  * If an update was not found, "updateinfo" field is absent

  */
var Flow = /** @class */ (function () {
    /**@hidden */
    function Flow(methods, flow, logger, isWeb) {
        //this.logger.log("flow", this.flow, "this.isWeb", this.isWeb)
        //this.FlowSubject = new Subject()
        if (isWeb === void 0) { isWeb = false; }
        this.methods = methods;
        this.flow = flow;
        this.logger = logger;
        this.isWeb = isWeb;
        this.FlowSubject = new rxjs_1.Subject();
        this.isAborting = false;
        this.calledFree = false;
        this.sendInProgress = false;
        // setInterval(() => {
        //   this.FlowSubject.next({ data: "test", age: new Date() })
        // }, 5000)
        if (this.isWeb) {
            this.FlowSubject = new rxjs_1.ReplaySubject(1);
        }
        else {
        }
        this.FlowData$ = this.FlowSubject.asObservable();
        this.getState();
    }
    Flow.prototype.getUpdatedState = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.getState()];
            });
        });
    };
    Flow.prototype.getState = function () {
        var _a;
        return __awaiter(this, void 0, void 0, function () {
            var newState;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        if (!this.isAborting) return [3 /*break*/, 1];
                        this.state = {
                            state_type: flows_1.FlowStateType.DGS_STATE_ABORTED,
                            state_data: {},
                            is_final: true
                        };
                        return [3 /*break*/, 3];
                    case 1:
                        if (!this.flow) {
                            return [2 /*return*/, this.FlowSubject.error(new Error("Flow not found!"))];
                        }
                        return [4 /*yield*/, this.methods.flowState(this.flow)];
                    case 2:
                        newState = _b.sent();
                        this.state = this.formatState(newState);
                        _b.label = 3;
                    case 3:
                        this.logger.log("flow state", this.state);
                        // if (this.isStateError(this.state)) {
                        //   this.FlowSubject.error(this.state)
                        // } else {
                        //   this.FlowSubject.next(this.state)
                        // }
                        this.FlowSubject.next(this.state);
                        //last state
                        if ((_a = this.state) === null || _a === void 0 ? void 0 : _a.is_final) {
                            this.logger.log("flow state complete", this.state);
                            this.FlowSubject.complete();
                            this.free();
                        }
                        return [2 /*return*/, this.state];
                }
            });
        });
    };
    /**
     * Method to send new {@link flowEvent}
     * @param flowEvent
     * @param FlowEventTypes the json Event payload
     */
    Flow.prototype.send = function (flowEvent, json) {
        if (json === void 0) { json = {}; }
        return __awaiter(this, void 0, void 0, function () {
            var systemError_1;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!this.flow) {
                            return [2 /*return*/, this.FlowSubject.error(new Error("Flow not found!"))];
                        }
                        this.sendInProgress = true;
                        _a.label = 1;
                    case 1:
                        _a.trys.push([1, 3, , 4]);
                        //@ts-ignore
                        return [4 /*yield*/, this.methods.flowPostEvent(this.flow, flowEvent, json)];
                    case 2:
                        //@ts-ignore
                        _a.sent();
                        this.sendInProgress = false;
                        return [3 /*break*/, 4];
                    case 3:
                        systemError_1 = _a.sent();
                        return [2 /*return*/, this.FlowSubject.error(systemError_1)];
                    case 4: return [4 /*yield*/, this.getState()];
                    case 5: return [2 /*return*/, _a.sent()];
                }
            });
        });
    };
    Flow.prototype.formatState = function (state) {
        var _a;
        if (((_a = state.state_data) === null || _a === void 0 ? void 0 : _a.result) !== undefined) {
            state.state_data.message = this.methods.getErrorMessage(state.state_data.result);
        }
        return state;
    };
    // private isStateError(state: FlowState) {
    //   let isError = false;
    //   if (state.state_data?.result !== undefined) {
    //     if (state.state_data.result !== 0) {
    //       isError = true;
    //     }
    //   }
    //   this.logger.log("flow isStateError", isError);
    //   return isError;
    // }
    /**
     * @hidden
     */
    Flow.prototype.free = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        this.logger.log("Free Flow");
                        if (!this.flow) return [3 /*break*/, 2];
                        if (!!this.calledFree) return [3 /*break*/, 2];
                        this.calledFree = true;
                        return [4 /*yield*/, this.methods.flowFree(this.flow)];
                    case 1:
                        _a.sent();
                        this.flow = 0;
                        _a.label = 2;
                    case 2: return [2 /*return*/];
                }
            });
        });
    };
    /**
     * Method to abort a  flowEvent
     * after called the operation will be interrupted and the flow is destroyed (no more operations are permitted!)
     * @param FlowEventTypes the json Event payload
     */
    Flow.prototype.abort = function () {
        return __awaiter(this, void 0, void 0, function () {
            var e_1;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        this.logger.log("flow aborting...");
                        if (!this.flow)
                            return [2 /*return*/, Promise.resolve()];
                        _a.label = 1;
                    case 1:
                        _a.trys.push([1, 3, , 4]);
                        this.logger.log("called native abort");
                        return [4 /*yield*/, this.methods.flowAbort(this.flow)];
                    case 2:
                        _a.sent();
                        return [3 /*break*/, 4];
                    case 3:
                        e_1 = _a.sent();
                        this.logger.error(e_1);
                        return [3 /*break*/, 4];
                    case 4:
                        this.isAborting = true;
                        this.FlowSubject.complete();
                        if (!this.sendInProgress) {
                            this.logger.log("flow this.sendInProgress...");
                            return [2 /*return*/, this.getState()];
                        }
                        else {
                            return [2 /*return*/, Promise.resolve({})];
                        }
                        return [2 /*return*/];
                }
            });
        });
    };
    return Flow;
}());
exports.default = Flow;
//# sourceMappingURL=FlowProcess.js.map