"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Logger = void 0;
/**
 * @ignore
 */
var slash = require('slash');
var util = require('util');
var winston = require("winston");
var Constant_1 = require("./Constant");
var createLogger = winston.createLogger, format = winston.format, transports = winston.transports;
var combine = format.combine, colorize = format.colorize, timestamp = format.timestamp, printf = format.printf, padLevels = format.padLevels;
var fileOptions = {
    maxsize: 10 * 1000 * 1000,
    maxFiles: 10,
    //tailable: true
};
var logFormat = printf(function (info) {
    return "".concat(info.timestamp, " [").concat(info.level, "] ").concat(info.message);
});
var Winston = createLogger({
    level: "debug",
    format: combine(format.timestamp({ format: 'YYYY-MM-DD HH:mm:ss' }), //2021:03:19 12:17:46
    format.errors({ stack: true }), format.uncolorize(), logFormat),
    // defaultMeta: {
    //   //service: 'user-service'
    // },
    // transports: [
    // ]
});
/**@hidden */
var Logger = /** @class */ (function () {
    function Logger() {
        var _this = this;
        this.enabled = true;
        this.init = function (homepath, debug) {
            if (homepath === void 0) { homepath = Constant_1.HomeDir; }
            if (debug === void 0) { debug = false; }
            if (debug)
                console.log("Logger init", { homepath: homepath, debug: debug });
            _this.enabled = debug;
            if (_this.enabled) {
                var consoleTransport = new transports.Console({
                    format: combine(format.timestamp(), format.errors({ stack: true }), format.colorize(), logFormat)
                });
                Winston.add(consoleTransport);
            }
            var fileLogsPath = slash(homepath + '/wrapper.log');
            var fileLogs = new transports.File(__assign(__assign({}, fileOptions), { filename: fileLogsPath, silent: !_this.enabled }));
            Winston.add(fileLogs);
            var fileErrorPath = slash(homepath + '/wrapper-errors.log');
            var fileError = new transports.File(__assign(__assign({}, fileOptions), { filename: fileErrorPath, level: 'error', handleExceptions: true, silent: !_this.enabled }));
            Winston.add(fileError);
            _this.log({ level: "debug", message: "initialized Logger with", label: "Logger" });
        };
        this.log = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            return /*this.enabled &&*/ Winston.log({ level: "debug", message: argumentsToString(args) });
        };
        this.warn = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            return /*this.enabled &&*/ Winston.log({ level: "warn", message: argumentsToString(args) });
        };
        this.info = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            return /*this.enabled &&*/ Winston.log({ level: "info", message: argumentsToString(args) });
        };
        this.error = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            return Winston.error({ level: "error", message: argumentsToString(args) });
        };
    }
    return Logger;
}());
exports.Logger = Logger;
exports.default = new Logger();
// pass in input object and returns string with spaces
function argumentsToString(input, type) {
    if (type === void 0) { type = ""; }
    var str = '';
    // convert arguments object to array
    var args = Array.prototype.slice.call(input);
    // iterate through args and check for objects for proper string representation
    for (var k in args) {
        // proper spacing if the argument is an emoji
        if (typeof args[k] === 'object') {
            // if the argument is an object use the inspect utility on it
            args[k] = util.inspect(args[k], false, null, true);
            // after an object arguments add 1 space
            str += args[k] + ' ';
        }
        else {
            // everything else will have 1 space
            str += args[k] + ' ';
        }
    }
    // trim white space from the end of a string
    str = str.replace(/\s*$/, '');
    // return string
    return str;
}
//# sourceMappingURL=Logger.js.map