const Platform = require("os").type();
const Arch = process.env.npm_config_arch;
const execSync = require('child_process').execSync;
const npm = require('npm-programmatic');
const path = require("path");
const fs = require("fs");
const util = require('util');
const folder = __dirname; //process.cwd();

const exec = util.promisify(require('child_process').exec);



var moduleToInstall = getModuleToInstall();


function getModuleToInstall() {

    let _moduleToInstall;
    switch (Platform) {
        //Mac
        case "Darwin":
            _moduleToInstall = "@ice/dike-core-osx";
            break;

            //Windows
        case "Windows_NT":
            _moduleToInstall = "@ice/dike-core-win" + (Arch == "x64" ? "64" : "");
            break;

            //Linux
        case "Linux":
            _moduleToInstall = "@ice/dike-core-linux";
            break;

        default:
            _moduleToInstall = " ";
            break;
    }

    return _moduleToInstall;
}

console.log("Platform", Platform, "moduleToInstall", moduleToInstall)






async function PostInstall() {
    console.log("PostInstall ");
    moduleToInstall = getModuleToInstall();
    const latestVersion = await getLatestVersion(moduleToInstall);
    const installedVersion = await getInstalledVersion(moduleToInstall);

    console.log("PostInstall", { installedVersion, latestVersion })
    if (checkDikeModuleInstalledPath(moduleToInstall)) {
        console.error(moduleToInstall + " already installed");




        if (latestVersion != installedVersion) {
            console.log(`latest version ${installedVersion} NOT installed`)
            installModule(moduleToInstall, latestVersion);
        } else {
            console.log(`latest version ${installedVersion} already installed`)
        }
       

        process.exit(0);

    } else {
        console.error(moduleToInstall + " not found");
        // 
        installModule(moduleToInstall, latestVersion)
            .catch(e => {
                process.exit(e)
            })
            .finally(() => {
                process.exit(0);
            })
    }

}

async function installModule(moduleToInstall, version = "latest") {
    const installCommand = moduleToInstall + "@" + version;
    console.log("Installing module..", installCommand, folder)
    await npm.install([installCommand], {
            cwd: folder,
            output: true,
            save: true,
            ignoreScripts: true,
            maxBuffer: 1024 * 1024

        })
        .then(function() {
            console.log("Installed package " + moduleToInstall);
            return true
        })
        .catch(function(e) {
            console.log("Unable to install package");
            return e
        });

}


// checks if module is available to load
function checkDikeModuleInstalledPath(moduleToInstall) {
    const dikeApiModulePath = path.join(
        process.cwd(),
        "node_modules/",
        moduleToInstall
    );
    //console.log("isModuleAvailableSync -> dikeApiModulePath", dikeApiModulePath)
    if (fs.existsSync(dikeApiModulePath) === true) {
        console.log("dikeApiModule found", dikeApiModulePath)
        return dikeApiModulePath;
    } else {
        console.log("dikeApiModule NOT installed in path", dikeApiModulePath)
        return false
    }

}

 



async function getLatestVersion(moduleToInstall) {
    const { stdout, stderr } = await exec(`npm view ${moduleToInstall} version`);
    //console.log("lsExample -> stderr", stderr)
    //console.log("lsExample -> stdout", stdout)
    if (stderr) {
        console.error(stderr);
        //throw stderr;
        return "*";
    }
    const latestVersion = stdout
    console.log("getLatestVersion -> latestVersion", latestVersion)
    return latestVersion.trim();

}


async function getInstalledVersion(moduleToInstall) {
    let installedVersion = false;
    try {
        installedVersion = require(`${moduleToInstall}/package.json`).version;
    } catch (err) {
        console.error(err);
        return "";
    }

    console.log("getinstalledVersion -> installedVersion", installedVersion)
    return installedVersion.trim();

}


PostInstall();
